/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#ifndef _XIG_COMMON_H_
#define _XIG_COMMON_H_

#include <glib-object.h>

G_BEGIN_DECLS

#define MAXIMUM_REQUEST_LENGTH 65535

typedef enum
{
    Failed       = 0,
    Success      = 1,
    Authenticate = 2
} ConnectResponseCode;

typedef enum
{
    XIG_REQUEST_CreateWindow            = 1,
    XIG_REQUEST_ChangeWindowAttributes  = 2,
    XIG_REQUEST_GetWindowAttributes     = 3,
    XIG_REQUEST_DestroyWindow           = 4,
    XIG_REQUEST_DestroySubwindows       = 5,
    XIG_REQUEST_ChangeSaveSet           = 6,
    XIG_REQUEST_ReparentWindow          = 7,
    XIG_REQUEST_MapWindow               = 8,
    XIG_REQUEST_MapSubwindows           = 9,
    XIG_REQUEST_UnmapWindow             = 10,
    XIG_REQUEST_UnmapSubwindows         = 11,
    XIG_REQUEST_ConfigureWindow         = 12,
    XIG_REQUEST_CirculateWindow         = 13,
    XIG_REQUEST_GetGeometry             = 14,
    XIG_REQUEST_QueryTree               = 15,
    XIG_REQUEST_InternAtom              = 16,
    XIG_REQUEST_GetAtomName             = 17,
    XIG_REQUEST_ChangeProperty          = 18,
    XIG_REQUEST_DeleteProperty          = 19,
    XIG_REQUEST_GetProperty             = 20,
    XIG_REQUEST_ListProperties          = 21,
    XIG_REQUEST_SetSelectionOwner       = 22,
    XIG_REQUEST_GetSelectionOwner       = 23,
    XIG_REQUEST_ConvertSelection        = 24,
    XIG_REQUEST_SendEvent               = 25,
    XIG_REQUEST_GrabPointer             = 26,
    XIG_REQUEST_UngrabPointer           = 27,
    XIG_REQUEST_GrabButton              = 28,
    XIG_REQUEST_UngrabButton            = 29,
    XIG_REQUEST_ChangeActivePointerGrab = 30,
    XIG_REQUEST_GrabKeyboard            = 31,
    XIG_REQUEST_UngrabKeyboard          = 32,
    XIG_REQUEST_GrabKey                 = 33,
    XIG_REQUEST_UngrabKey               = 34,
    XIG_REQUEST_AllowEvents             = 35,
    XIG_REQUEST_GrabServer              = 36,
    XIG_REQUEST_UngrabServer            = 37,
    XIG_REQUEST_QueryPointer            = 38,
    XIG_REQUEST_GetMotionEvents         = 39,
    XIG_REQUEST_TranslateCoordinates    = 40,
    XIG_REQUEST_WarpPointer             = 41,
    XIG_REQUEST_SetInputFocus           = 42,
    XIG_REQUEST_GetInputFocus           = 43,
    XIG_REQUEST_QueryKeymap             = 44,
    XIG_REQUEST_OpenFont                = 45,
    XIG_REQUEST_CloseFont               = 46,
    XIG_REQUEST_QueryFont               = 47,
    XIG_REQUEST_QueryTextExtents        = 48,
    XIG_REQUEST_ListFonts               = 49,
    XIG_REQUEST_ListFontsWithInfo       = 50,
    XIG_REQUEST_SetFontPath             = 51,
    XIG_REQUEST_GetFontPath             = 52,
    XIG_REQUEST_CreatePixmap            = 53,
    XIG_REQUEST_FreePixmap              = 54,
    XIG_REQUEST_CreateGC                = 55,
    XIG_REQUEST_ChangeGC                = 56,
    XIG_REQUEST_CopyGC                  = 57,
    XIG_REQUEST_SetDashes               = 58,
    XIG_REQUEST_SetClipRectangles       = 59,
    XIG_REQUEST_FreeGC                  = 60,
    XIG_REQUEST_ClearArea               = 61,
    XIG_REQUEST_CopyArea                = 62,
    XIG_REQUEST_CopyPlane               = 63,
    XIG_REQUEST_PolyPoint               = 64,
    XIG_REQUEST_PolyLine                = 65,
    XIG_REQUEST_PolySegment             = 66,
    XIG_REQUEST_PolyRectangle           = 67,
    XIG_REQUEST_PolyArc                 = 68,
    XIG_REQUEST_FillPoly                = 69,
    XIG_REQUEST_PolyFillRectangle       = 70,
    XIG_REQUEST_PolyFillArc             = 71,
    XIG_REQUEST_PutImage                = 72,
    XIG_REQUEST_GetImage                = 73,
    XIG_REQUEST_PolyText8               = 74,
    XIG_REQUEST_PolyText16              = 75,
    XIG_REQUEST_ImageText8              = 76,
    XIG_REQUEST_ImageText16             = 77,
    XIG_REQUEST_CreateColormap          = 78,
    XIG_REQUEST_FreeColormap            = 79,
    XIG_REQUEST_CopyColormapAndFree     = 80,
    XIG_REQUEST_InstallColormap         = 81,
    XIG_REQUEST_UninstallColormap       = 82,
    XIG_REQUEST_ListInstalledColormaps  = 83,
    XIG_REQUEST_AllocColor              = 84,
    XIG_REQUEST_AllocNamedColor         = 85,
    XIG_REQUEST_AllocColorCells         = 86,
    XIG_REQUEST_AllocColorPlanes        = 87,
    XIG_REQUEST_FreeColors              = 88,
    XIG_REQUEST_StoreColors             = 89,
    XIG_REQUEST_StoreNamedColor         = 90,
    XIG_REQUEST_QueryColors             = 91,
    XIG_REQUEST_LookupColor             = 92,
    XIG_REQUEST_CreateCursor            = 93,
    XIG_REQUEST_CreateGlyphCursor       = 94,
    XIG_REQUEST_FreeCursor              = 95,
    XIG_REQUEST_RecolorCursor           = 96,
    XIG_REQUEST_QueryBestSize           = 97,
    XIG_REQUEST_QueryExtension          = 98,
    XIG_REQUEST_ListExtensions          = 99,
    XIG_REQUEST_ChangeKeyboardMapping   = 100,
    XIG_REQUEST_GetKeyboardMapping      = 101,
    XIG_REQUEST_ChangeKeyboardControl   = 102,
    XIG_REQUEST_GetKeyboardControl      = 103,
    XIG_REQUEST_Bell                    = 104,
    XIG_REQUEST_ChangePointerControl    = 105,
    XIG_REQUEST_GetPointerControl       = 106,
    XIG_REQUEST_SetScreenSaver          = 107,
    XIG_REQUEST_GetScreenSaver          = 108,
    XIG_REQUEST_ChangeHosts             = 109,
    XIG_REQUEST_ListHosts               = 110,
    XIG_REQUEST_SetAccessControl        = 111,
    XIG_REQUEST_SetCloseDownMode        = 112,
    XIG_REQUEST_KillClient              = 113,
    XIG_REQUEST_RotateProperties        = 114,
    XIG_REQUEST_ForceScreenSaver        = 115,
    XIG_REQUEST_SetPointerMapping       = 116,
    XIG_REQUEST_GetPointerMapping       = 117,
    XIG_REQUEST_SetModifierMapping      = 118,
    XIG_REQUEST_GetModifierMapping      = 119,
    XIG_REQUEST_NoOperation             = 127,
    XIG_REQUEST_BIGREQ                  = 128,
    XIG_REQUEST_SYNC                    = 129,
    XIG_REQUEST_RANDR                   = 130,
    XIG_REQUEST_XINERAMA                = 131,
    XIG_REQUEST_XKEYBOARD               = 132,
    XIG_REQUEST_RENDER                  = 133
} XigRequest; 

typedef enum
{
    XIG_RESPONSE_Error              = 0,
    XIG_RESPONSE_Reply              = 1,
    XIG_RESPONSE_KeyPress           = 2,
    XIG_RESPONSE_KeyRelease         = 3,
    XIG_RESPONSE_ButtonPress        = 4,
    XIG_RESPONSE_ButtonRelease      = 5,
    XIG_RESPONSE_MotionNotify       = 6,
    XIG_RESPONSE_EnterNotify        = 7,
    XIG_RESPONSE_LeaveNotify        = 8,
    XIG_RESPONSE_FocusIn            = 9,
    XIG_RESPONSE_FocusOut           = 10,
    XIG_RESPONSE_KeymapNotify       = 11,
    XIG_RESPONSE_Expose             = 12,
    XIG_RESPONSE_GraphicsExposure   = 13,
    XIG_RESPONSE_NoExposure         = 14,
    XIG_RESPONSE_VisibilityNotify   = 15,
    XIG_RESPONSE_CreateNotify       = 16,
    XIG_RESPONSE_DestroyNotify      = 17,
    XIG_RESPONSE_UnmapNotify        = 18,
    XIG_RESPONSE_MapNotify          = 19,
    XIG_RESPONSE_MapRequest         = 20,
    XIG_RESPONSE_ReparentNotify     = 21,
    XIG_RESPONSE_ConfigureNotify    = 22,
    XIG_RESPONSE_ConfigureRequest   = 23,
    XIG_RESPONSE_GravityNotify      = 24,
    XIG_RESPONSE_ResizeRequest      = 25,
    XIG_RESPONSE_CirculateNotify    = 26,
    XIG_RESPONSE_CirculateRequest   = 27,
    XIG_RESPONSE_PropertyNotify     = 28,
    XIG_RESPONSE_SelectionClear     = 29,
    XIG_RESPONSE_SelectionRequest   = 30,
    XIG_RESPONSE_SelectionNotify    = 31,
    XIG_RESPONSE_ColormapNotify     = 32,
    XIG_RESPONSE_ClientMessage      = 33,
    XIG_RESPONSE_MappingNotify      = 34
} XigResponse;

typedef enum
{
    Request        = 0,
    Value          = 2,
    Window         = 3,
    Pixmap         = 4,
    Atom           = 5,
    Cursor         = 6,
    Font           = 7,
    Match          = 8,
    Drawable       = 9,
    Access         = 10,
    Alloc          = 11,
    Colormap       = 12,
    GContext       = 13,
    IDChoice       = 14,
    Name           = 15,
    Length         = 16,
    Implementation = 17
} ErrorCode;

typedef enum
{
    BYTE_ORDER_MSB,
    BYTE_ORDER_LSB
} ByteOrder;

gsize pad (gsize length);

void read_padding (gsize length, gsize *offset);

guint8 read_card8 (const guint8 *buffer, gsize buffer_length, gsize *offset);

guint16 read_card16 (const guint8 *buffer, gsize buffer_length, ByteOrder byte_order, gsize *offset);

guint32 read_card32 (const guint8 *buffer, gsize buffer_length, ByteOrder byte_order, gsize *offset);

guint8 *read_string8 (const guint8 *buffer, gsize buffer_length, gsize string_length, gsize *offset);

gchar *read_string (const guint8 *buffer, gsize buffer_length, gsize string_length, gsize *offset);

gchar *read_padded_string (const guint8 *buffer, gsize buffer_length, gsize string_length, gsize *offset);

void write_card8 (guint8 *buffer, gsize buffer_length, guint8 value, gsize *offset);

void write_padding (guint8 *buffer, gsize buffer_length, gsize length, gsize *offset);

void write_card16 (guint8 *buffer, gsize buffer_length, ByteOrder byte_order, guint16 value, gsize *offset);

void write_card32 (guint8 *buffer, gsize buffer_length, ByteOrder byte_order, guint32 value, gsize *offset);

void write_string8 (guint8 *buffer, gsize buffer_length, const guint8 *value, gsize value_length, gsize *offset);

gsize padded_string_length (const gchar *value);

void write_string (guint8 *buffer, gsize buffer_length, const gchar *value, gsize *offset);

void write_padded_string (guint8 *buffer, gsize buffer_length, const gchar *value, gsize *offset);

G_END_DECLS

#endif /* _XIG_COMMON_H_ */
