/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#include "xig/xig-screen.h"
#include "xig-server-private.h"
#include "xig-screen-private.h"
#include "xig-visual-private.h"
#include "xig-window-private.h"
#include "xig-drawable-private.h"

G_DEFINE_TYPE (XigScreen, xig_screen, G_TYPE_OBJECT);

struct XigScreenPrivate
{
    XigServer *server;
    guint32 white_pixel;
    guint32 black_pixel;
    guint16 width_in_pixels;
    guint16 height_in_pixels;
    guint16 width_in_millimeters;
    guint16 height_in_millimeters;
    GList *visuals;
    XigWindow *root;
};

XigScreen *
_xig_screen_new (XigServer *server, guint32 white_pixel, guint32 black_pixel, guint16 width_in_pixels, guint16 height_in_pixels, guint16 width_in_millimeters, guint16 height_in_millimeters)
{
    XigScreen *screen = g_object_new (xig_screen_get_type (), NULL);
    screen->priv->server = server;
    screen->priv->white_pixel = white_pixel;
    screen->priv->black_pixel = black_pixel;
    screen->priv->width_in_pixels = width_in_pixels;
    screen->priv->height_in_pixels = height_in_pixels;
    screen->priv->width_in_millimeters = width_in_millimeters;
    screen->priv->height_in_millimeters = height_in_millimeters;
    return screen;
}

XigServer *
xig_screen_get_server (XigScreen *screen)
{
    return screen->priv->server;
}

guint32
xig_screen_get_white_pixel (XigScreen *screen)
{
    return screen->priv->white_pixel;
}

guint32
xig_screen_get_black_pixel (XigScreen *screen)
{
    return screen->priv->black_pixel;
}

guint16
xig_screen_get_width_in_pixels (XigScreen *screen)
{
    return screen->priv->width_in_pixels;
}

guint16
xig_screen_get_height_in_pixels (XigScreen *screen)
{
    return screen->priv->height_in_pixels;
}

guint16
xig_screen_get_width_in_millimeters (XigScreen *screen)
{
    return screen->priv->width_in_millimeters;
}

guint16
xig_screen_get_height_in_millimeters (XigScreen *screen)
{
    return screen->priv->height_in_millimeters;
}

XigVisual *
xig_screen_add_visual (XigScreen *screen, guint8 depth, XigVisualClassType class, guint8 bits_per_rgb_value, guint16 colormap_entries, guint32 red_mask, guint32 green_mask, guint32 blue_mask)
{
    XigVisual *visual;

    visual = _xig_visual_new (g_list_length (screen->priv->visuals) + 1, depth, class, bits_per_rgb_value, colormap_entries, red_mask, green_mask, blue_mask);
    screen->priv->visuals = g_list_append (screen->priv->visuals, visual);

    return visual;
}

GList *
xig_screen_get_visuals (XigScreen *screen)
{
    return screen->priv->visuals;
}

XigWindow *
xig_screen_add_root (XigScreen *screen, XigVisual *visual)
{
    XigWindow *root;

    g_return_val_if_fail (screen->priv->root == NULL, NULL);

    root = screen->priv->root = _xig_window_new (screen->priv->server, NULL, _xig_server_get_drawable_id (screen->priv->server), NULL, XIG_WINDOW_CLASS_InputOutput, 0, 0, xig_screen_get_width_in_pixels (screen), xig_screen_get_height_in_pixels (screen), 0, visual);
    _xig_server_add_window (screen->priv->server, root);

    return root;
}

XigWindow *
xig_screen_get_root (XigScreen *screen)
{
    return screen->priv->root;
}

static void
xig_screen_init (XigScreen *screen)
{
    screen->priv = G_TYPE_INSTANCE_GET_PRIVATE (screen, xig_screen_get_type (), XigScreenPrivate);
}

static void
xig_screen_class_init (XigScreenClass *klass)
{
    g_type_class_add_private (klass, sizeof (XigScreenPrivate));
}
