/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#ifndef _XIG_CLIENT_H_
#define _XIG_CLIENT_H_

#include <glib-object.h>
#include <gio/gio.h>

typedef struct XigClient XigClient;

#include "xig-client-codec.h"

#define XIG_CLIENT_TYPE           (xig_client_get_type())
#define XIG_IS_CLIENT(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XIG_CLIENT_TYPE))
#define XIG_CLIENT(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), XIG_CLIENT_TYPE, XigClient))
#define XIG_CLIENT_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), XIG_CLIENT_TYPE, XigClientClass))
#define XIG_CLIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XIG_CLIENT_TYPE, XigClientClass))

typedef struct XigClientPrivate XigClientPrivate;

struct XigClient
{
   XigClientCodec    parent_instance;
   XigClientPrivate *priv;
};

typedef struct
{
   XigClientCodecClass parent_class;
   void (*disconnected)(XigClient *client);
} XigClientClass;

GType xig_client_get_type (void);

XigClient *xig_client_new (void);

XigClient *xig_client_new_from_environment (GError **error);

void xig_client_connect (XigClient *client, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data);

gboolean xig_client_connect_finish (XigClient *client, GAsyncResult *res, GError **error);

gboolean xig_client_connect_sync (XigClient *client, GError **error);

const gchar *xig_client_get_vendor (XigClient *client);

GInetAddress *xig_client_get_server_address (XigClient *client);

void xig_client_disconnect (XigClient *client);

G_END_DECLS

#endif /* _XIG_CLIENT_H_ */
