/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#ifndef _XIG_CODEC_H_
#define _XIG_CODEC_H_

#include <glib-object.h>

typedef struct XigCodec XigCodec;

#include "xig-events.h"

#define XIG_CODEC_TYPE           (xig_codec_get_type ())
#define XIG_IS_CODEC(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XIG_CODEC_TYPE))
#define XIG_CODEC(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), XIG_CODEC_TYPE, XigCodec))
#define XIG_CODEC_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), XIG_CODEC_TYPE, XigCodecClass))
#define XIG_CODEC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XIG_CODEC_TYPE, XigCodecClass))

typedef struct XigCodecPrivate XigCodecPrivate;

struct XigCodec
{
    GObject parent_instance;
};

typedef struct
{
    GObjectClass parent_class;
    void (*feed_data)(XigCodec *codec, const guint8 *data, gsize data_length);
    void (*write)(XigCodec *codec, const guint8 *data, gsize data_length);
    void (*connect)(XigCodec *codec, XigConnect *message);
    void (*failed)(XigCodec *codec, XigFailed *message);
    void (*authenticate)(XigCodec *codec, XigAuthenticate *message);
    void (*success)(XigCodec *codec, XigSuccess *message);
    void (*error)(XigCodec *codec, XigError *message);
    void (*key_press)(XigCodec *codec, XigKeyPress *message);
    void (*button_press)(XigCodec *codec, XigButtonPress *message);
    void (*motion_notify)(XigCodec *codec, XigMotionNotify *message);
    void (*enter_notify)(XigCodec *codec, XigEnterNotify *message);
    void (*focus_in)(XigCodec *codec, XigFocusIn *message);
    void (*keymap_notify)(XigCodec *codec, XigKeymapNotify *message);
    void (*expose)(XigCodec *codec, XigExpose *message);
    void (*graphics_exposure)(XigCodec *codec, XigGraphicsExposure *message);
    void (*no_exposure)(XigCodec *codec, XigNoExposure *message);
    void (*visibility_notify)(XigCodec *codec, XigVisibilityNotify *message);
    void (*create_notify)(XigCodec *codec, XigCreateNotify *message);
    void (*destroy_notify)(XigCodec *codec, XigDestroyNotify *message);
    void (*unmap_notify)(XigCodec *codec, XigUnmapNotify *message);
    void (*map_notify)(XigCodec *codec, XigMapNotify *message);
    void (*map_request)(XigCodec *codec, XigMapRequest *message);
    void (*reparent_notify)(XigCodec *codec, XigReparentNotify *message);
    void (*configure_notify)(XigCodec *codec, XigConfigureNotify *message);
    void (*configure_request)(XigCodec *codec, XigConfigureRequest *message);
    void (*gravity_notify)(XigCodec *codec, XigGravityNotify *message);
    void (*resize_request)(XigCodec *codec, XigResizeRequest *message);
    void (*circulate_notify)(XigCodec *codec, XigCirculateNotify *message);
    void (*circulate_request)(XigCodec *codec, XigCirculateRequest *message);
    void (*property_notify)(XigCodec *codec, XigPropertyNotify *message);
    void (*selection_clear)(XigCodec *codec, XigSelectionClear *message);
    void (*selection_request)(XigCodec *codec, XigSelectionRequest *message);
    void (*selection_notify)(XigCodec *codec, XigSelectionNotify *message);
    void (*colormap_notify)(XigCodec *codec, XigColormapNotify *message);
    void (*client_message)(XigCodec *codec, XigClientMessage *message);
    void (*mapping_notify)(XigCodec *codec, XigMappingNotify *message);
    void (*create_window)(XigCodec *codec, XigCreateWindow *message);
    void (*change_window_attributes)(XigCodec *codec, XigChangeWindowAttributes *message);
    void (*get_window_attributes)(XigCodec *codec, XigGetWindowAttributes *message);
    void (*get_window_attributes_reply)(XigCodec *codec, XigGetWindowAttributesReply *message);
    void (*destroy_window)(XigCodec *codec, XigDestroyWindow *message);
    void (*destroy_subwindows)(XigCodec *codec, XigDestroySubwindows *message);
    void (*change_save_set)(XigCodec *codec, XigChangeSaveSet *message);
    void (*reparent_window)(XigCodec *codec, XigReparentWindow *message);
    void (*map_window)(XigCodec *codec, XigMapWindow *message);
    void (*map_subwindows)(XigCodec *codec, XigMapSubwindows *message);
    void (*unmap_window)(XigCodec *codec, XigUnmapWindow *message);
    void (*unmap_subwindows)(XigCodec *codec, XigUnmapSubwindows *message);
    void (*configure_window)(XigCodec *codec, XigConfigureWindow *message);
    void (*circulate_window)(XigCodec *codec, XigCirculateWindow *message);
    void (*get_geometry)(XigCodec *codec, XigGetGeometry *message);
    void (*get_geometry_reply)(XigCodec *codec, XigGetGeometryReply *message);
    void (*query_tree)(XigCodec *codec, XigQueryTree *message);
    void (*query_tree_reply)(XigCodec *codec, XigQueryTreeReply *message);
    void (*intern_atom)(XigCodec *codec, XigInternAtom *message);
    void (*intern_atom_reply)(XigCodec *codec, XigInternAtomReply *message);
    void (*get_atom_name)(XigCodec *codec, XigGetAtomName *message);
    void (*get_atom_name_reply)(XigCodec *codec, XigGetAtomNameReply *message);
    void (*change_property)(XigCodec *codec, XigChangeProperty *message);
    void (*delete_property)(XigCodec *codec, XigDeleteProperty *message);
    void (*get_property)(XigCodec *codec, XigGetProperty *message);
    void (*get_property_reply)(XigCodec *codec, XigGetPropertyReply *message);
    void (*list_properties)(XigCodec *codec, XigListProperties *message);
    void (*list_properties_reply)(XigCodec *codec, XigListPropertiesReply *message);
    void (*set_selection_owner)(XigCodec *codec, XigSetSelectionOwner *message);
    void (*get_selection_owner)(XigCodec *codec, XigGetSelectionOwner *message);
    void (*get_selection_owner_reply)(XigCodec *codec, XigGetSelectionOwnerReply *message);
    void (*convert_selection)(XigCodec *codec, XigConvertSelection *message);
    void (*send_event)(XigCodec *codec, XigSendEvent *message);
    void (*grab_pointer)(XigCodec *codec, XigGrabPointer *message);
    void (*grab_pointer_reply)(XigCodec *codec, XigGrabPointerReply *message);
    void (*ungrab_pointer)(XigCodec *codec, XigUngrabPointer *message);
    void (*grab_button)(XigCodec *codec, XigGrabButton *message);
    void (*ungrab_button)(XigCodec *codec, XigUngrabButton *message);
    void (*change_active_pointer_grab)(XigCodec *codec, XigChangeActivePointerGrab *message);
    void (*grab_keyboard)(XigCodec *codec, XigGrabKeyboard *message);
    void (*grab_keyboard_reply)(XigCodec *codec, XigGrabKeyboardReply *message);
    void (*ungrab_keyboard)(XigCodec *codec, XigUngrabKeyboard *message);
    void (*grab_key)(XigCodec *codec, XigGrabKey *message);
    void (*ungrab_key)(XigCodec *codec, XigUngrabKey *message);
    void (*allow_events)(XigCodec *codec, XigAllowEvents *message);
    void (*grab_server)(XigCodec *codec, XigGrabServer *message);
    void (*ungrab_server)(XigCodec *codec, XigUngrabServer *message);
    void (*query_pointer)(XigCodec *codec, XigQueryPointer *message);
    void (*query_pointer_reply)(XigCodec *codec, XigQueryPointerReply *message);
    void (*get_motion_events)(XigCodec *codec, XigGetMotionEvents *message);
    void (*get_motion_events_reply)(XigCodec *codec, XigGetMotionEventsReply *message);
    void (*translate_coordinates)(XigCodec *codec, XigTranslateCoordinates *message);
    void (*translate_coordinates_reply)(XigCodec *codec, XigTranslateCoordinatesReply *message);
    void (*warp_pointer)(XigCodec *codec, XigWarpPointer *message);
    void (*set_input_focus)(XigCodec *codec, XigSetInputFocus *message);
    void (*get_input_focus)(XigCodec *codec, XigGetInputFocus *message);
    void (*get_input_focus_reply)(XigCodec *codec, XigGetInputFocusReply *message);
    void (*query_keymap)(XigCodec *codec, XigQueryKeymap *message);
    void (*query_keymap_reply)(XigCodec *codec, XigQueryKeymapReply *message);
    void (*open_font)(XigCodec *codec, XigOpenFont *message);
    void (*close_font)(XigCodec *codec, XigCloseFont *message);
    void (*query_font)(XigCodec *codec, XigQueryFont *message);
    void (*query_font_reply)(XigCodec *codec, XigQueryFontReply *message);
    void (*query_text_extents)(XigCodec *codec, XigQueryTextExtents *message);
    void (*query_text_extents_reply)(XigCodec *codec, XigQueryTextExtentsReply *message);
    void (*list_fonts)(XigCodec *codec, XigListFonts *message);
    void (*list_fonts_reply)(XigCodec *codec, XigListFontsReply *message);
    void (*list_fonts_with_info)(XigCodec *codec, XigListFontsWithInfo *message);
    void (*list_fonts_with_info_reply)(XigCodec *codec, XigListFontsWithInfoReply *message);
    void (*set_font_path)(XigCodec *codec, XigSetFontPath *message);
    void (*get_font_path)(XigCodec *codec, XigGetFontPath *message);
    void (*get_font_path_reply)(XigCodec *codec, XigGetFontPathReply *message);
    void (*create_pixmap)(XigCodec *codec, XigCreatePixmap *message);
    void (*free_pixmap)(XigCodec *codec, XigFreePixmap *message);
    void (*create_gc)(XigCodec *codec, XigCreateGC *message);
    void (*change_gc)(XigCodec *codec, XigChangeGC *message);
    void (*copy_gc)(XigCodec *codec, XigCopyGC *message);
    void (*set_dashes)(XigCodec *codec, XigSetDashes *message);
    void (*set_clip_rectangles)(XigCodec *codec, XigSetClipRectangles *message);
    void (*free_gc)(XigCodec *codec, XigFreeGC *message);
    void (*clear_area)(XigCodec *codec, XigClearArea *message);
    void (*copy_area)(XigCodec *codec, XigCopyArea *message);
    void (*copy_plane)(XigCodec *codec, XigCopyPlane *message);
    void (*poly_point)(XigCodec *codec, XigPolyPoint *message);
    void (*poly_line)(XigCodec *codec, XigPolyLine *message);
    void (*poly_segment)(XigCodec *codec, XigPolySegment *message);
    void (*poly_rectangle)(XigCodec *codec, XigPolyRectangle *message);
    void (*poly_arc)(XigCodec *codec, XigPolyArc *message);
    void (*fill_poly)(XigCodec *codec, XigFillPoly *message);
    void (*poly_fill_rectangle)(XigCodec *codec, XigPolyFillRectangle *message);
    void (*poly_fill_arc)(XigCodec *codec, XigPolyFillArc *message);
    void (*put_image)(XigCodec *codec, XigPutImage *message);
    void (*get_image)(XigCodec *codec, XigGetImage *message);
    void (*get_image_reply)(XigCodec *codec, XigGetImageReply *message);
    void (*poly_text8)(XigCodec *codec, XigPolyText8 *message);
    void (*poly_text16)(XigCodec *codec, XigPolyText16 *message);
    void (*image_text8)(XigCodec *codec, XigImageText8 *message);
    void (*image_text16)(XigCodec *codec, XigImageText16 *message);
    void (*create_colormap)(XigCodec *codec, XigCreateColormap *message);
    void (*free_colormap)(XigCodec *codec, XigFreeColormap *message);
    void (*copy_colormap_and_free)(XigCodec *codec, XigCopyColormapAndFree *message);
    void (*install_colormap)(XigCodec *codec, XigInstallColormap *message);
    void (*uninstall_colormap)(XigCodec *codec, XigUninstallColormap *message);
    void (*list_installed_colormaps)(XigCodec *codec, XigListInstalledColormaps *message);
    void (*list_installed_colormaps_reply)(XigCodec *codec, XigListInstalledColormapsReply *message);
    void (*alloc_color)(XigCodec *codec, XigAllocColor *message);
    void (*alloc_color_reply)(XigCodec *codec, XigAllocColorReply *message);
    void (*alloc_named_color)(XigCodec *codec, XigAllocNamedColor *message);
    void (*alloc_named_color_reply)(XigCodec *codec, XigAllocNamedColorReply *message);
    void (*alloc_color_cells)(XigCodec *codec, XigAllocColorCells *message);
    void (*alloc_color_cells_reply)(XigCodec *codec, XigAllocColorCellsReply *message);
    void (*alloc_color_planes)(XigCodec *codec, XigAllocColorPlanes *message);
    void (*alloc_color_planes_reply)(XigCodec *codec, XigAllocColorPlanesReply *message);
    void (*free_colors)(XigCodec *codec, XigFreeColors *message);
    void (*store_colors)(XigCodec *codec, XigStoreColors *message);
    void (*store_named_color)(XigCodec *codec, XigStoreNamedColor *message);
    void (*query_colors)(XigCodec *codec, XigQueryColors *message);
    void (*query_colors_reply)(XigCodec *codec, XigQueryColorsReply *message);
    void (*lookup_color)(XigCodec *codec, XigLookupColor *message);
    void (*lookup_color_reply)(XigCodec *codec, XigLookupColorReply *message);
    void (*create_cursor)(XigCodec *codec, XigCreateCursor *message);
    void (*create_glyph_cursor)(XigCodec *codec, XigCreateGlyphCursor *message);
    void (*free_cursor)(XigCodec *codec, XigFreeCursor *message);
    void (*recolor_cursor)(XigCodec *codec, XigRecolorCursor *message);
    void (*query_best_size)(XigCodec *codec, XigQueryBestSize *message);
    void (*query_best_size_reply)(XigCodec *codec, XigQueryBestSizeReply *message);
    void (*query_extension)(XigCodec *codec, XigQueryExtension *message);
    void (*query_extension_reply)(XigCodec *codec, XigQueryExtensionReply *message);
    void (*list_extensions)(XigCodec *codec, XigListExtensions *message);
    void (*list_extensions_reply)(XigCodec *codec, XigListExtensionsReply *message);
    void (*change_keyboard_mapping)(XigCodec *codec, XigChangeKeyboardMapping *message);
    void (*get_keyboard_mapping)(XigCodec *codec, XigGetKeyboardMapping *message);
    void (*get_keyboard_mapping_reply)(XigCodec *codec, XigGetKeyboardMappingReply *message);
    void (*change_keyboard_control)(XigCodec *codec, XigChangeKeyboardControl *message);
    void (*get_keyboard_control)(XigCodec *codec, XigGetKeyboardControl *message);
    void (*get_keyboard_control_reply)(XigCodec *codec, XigGetKeyboardControlReply *message);
    void (*bell)(XigCodec *codec, XigBell *message);
    void (*change_pointer_control)(XigCodec *codec, XigChangePointerControl *message);
    void (*get_pointer_control)(XigCodec *codec, XigGetPointerControl *message);
    void (*get_pointer_control_reply)(XigCodec *codec, XigGetPointerControlReply *message);
    void (*set_screen_saver)(XigCodec *codec, XigSetScreenSaver *message);
    void (*get_screen_saver)(XigCodec *codec, XigGetScreenSaver *message);
    void (*get_screen_saver_reply)(XigCodec *codec, XigGetScreenSaverReply *message);
    void (*change_hosts)(XigCodec *codec, XigChangeHosts *message);
    void (*list_hosts)(XigCodec *codec, XigListHosts *message);
    void (*list_hosts_reply)(XigCodec *codec, XigListHostsReply *message);
    void (*set_access_control)(XigCodec *codec, XigSetAccessControl *message);
    void (*set_close_down_mode)(XigCodec *codec, XigSetCloseDownMode *message);
    void (*kill_client)(XigCodec *codec, XigKillClient *message);
    void (*rotate_properties)(XigCodec *codec, XigRotateProperties *message);
    void (*force_screen_saver)(XigCodec *codec, XigForceScreenSaver *message);
    void (*set_pointer_mapping)(XigCodec *codec, XigSetPointerMapping *message);
    void (*set_pointer_mapping_reply)(XigCodec *codec, XigSetPointerMappingReply *message);
    void (*get_pointer_mapping)(XigCodec *codec, XigGetPointerMapping *message);
    void (*get_pointer_mapping_reply)(XigCodec *codec, XigGetPointerMappingReply *message);
    void (*set_modifier_mapping)(XigCodec *codec, XigSetModifierMapping *message);
    void (*set_modifier_mapping_reply)(XigCodec *codec, XigSetModifierMappingReply *message);
    void (*get_modifier_mapping)(XigCodec *codec, XigGetModifierMapping *message);
    void (*get_modifier_mapping_reply)(XigCodec *codec, XigGetModifierMappingReply *message);
    void (*no_operation)(XigCodec *codec, XigNoOperation *message);
    void (*BIGREQ_enable)(XigCodec *codec, XigBIGREQEnable *message);
    void (*BIGREQ_enable_reply)(XigCodec *codec, XigBIGREQEnableReply *message);
    void (*SYNC_counter_notify)(XigCodec *codec, XigSYNCCounterNotify *message);
    void (*SYNC_alarm_notify)(XigCodec *codec, XigSYNCAlarmNotify *message);
    void (*SYNC_initialize)(XigCodec *codec, XigSYNCInitialize *message);
    void (*SYNC_initialize_reply)(XigCodec *codec, XigSYNCInitializeReply *message);
    void (*SYNC_list_system_counters)(XigCodec *codec, XigSYNCListSystemCounters *message);
    void (*SYNC_list_system_counters_reply)(XigCodec *codec, XigSYNCListSystemCountersReply *message);
    void (*SYNC_create_counter)(XigCodec *codec, XigSYNCCreateCounter *message);
    void (*SYNC_destroy_counter)(XigCodec *codec, XigSYNCDestroyCounter *message);
    void (*SYNC_query_counter)(XigCodec *codec, XigSYNCQueryCounter *message);
    void (*SYNC_query_counter_reply)(XigCodec *codec, XigSYNCQueryCounterReply *message);
    void (*SYNC_await)(XigCodec *codec, XigSYNCAwait *message);
    void (*SYNC_change_counter)(XigCodec *codec, XigSYNCChangeCounter *message);
    void (*SYNC_set_counter)(XigCodec *codec, XigSYNCSetCounter *message);
    void (*SYNC_create_alarm)(XigCodec *codec, XigSYNCCreateAlarm *message);
    void (*SYNC_change_alarm)(XigCodec *codec, XigSYNCChangeAlarm *message);
    void (*SYNC_destroy_alarm)(XigCodec *codec, XigSYNCDestroyAlarm *message);
    void (*SYNC_query_alarm)(XigCodec *codec, XigSYNCQueryAlarm *message);
    void (*SYNC_query_alarm_reply)(XigCodec *codec, XigSYNCQueryAlarmReply *message);
    void (*SYNC_set_priority)(XigCodec *codec, XigSYNCSetPriority *message);
    void (*SYNC_get_priority)(XigCodec *codec, XigSYNCGetPriority *message);
    void (*SYNC_get_priority_reply)(XigCodec *codec, XigSYNCGetPriorityReply *message);
    void (*SYNC_create_fence)(XigCodec *codec, XigSYNCCreateFence *message);
    void (*SYNC_trigger_fence)(XigCodec *codec, XigSYNCTriggerFence *message);
    void (*SYNC_reset_fence)(XigCodec *codec, XigSYNCResetFence *message);
    void (*SYNC_destroy_fence)(XigCodec *codec, XigSYNCDestroyFence *message);
    void (*SYNC_query_fence)(XigCodec *codec, XigSYNCQueryFence *message);
    void (*SYNC_query_fence_reply)(XigCodec *codec, XigSYNCQueryFenceReply *message);
    void (*SYNC_await_fence)(XigCodec *codec, XigSYNCAwaitFence *message);
    void (*RANDR_screen_change_notify)(XigCodec *codec, XigRANDRScreenChangeNotify *message);
    void (*RANDR_notify)(XigCodec *codec, XigRANDRNotify *message);
    void (*RANDR_query_version)(XigCodec *codec, XigRANDRQueryVersion *message);
    void (*RANDR_query_version_reply)(XigCodec *codec, XigRANDRQueryVersionReply *message);
    void (*RANDR_set_screen_config)(XigCodec *codec, XigRANDRSetScreenConfig *message);
    void (*RANDR_set_screen_config_reply)(XigCodec *codec, XigRANDRSetScreenConfigReply *message);
    void (*RANDR_select_input)(XigCodec *codec, XigRANDRSelectInput *message);
    void (*RANDR_get_screen_info)(XigCodec *codec, XigRANDRGetScreenInfo *message);
    void (*RANDR_get_screen_info_reply)(XigCodec *codec, XigRANDRGetScreenInfoReply *message);
    void (*RANDR_get_screen_size_range)(XigCodec *codec, XigRANDRGetScreenSizeRange *message);
    void (*RANDR_get_screen_size_range_reply)(XigCodec *codec, XigRANDRGetScreenSizeRangeReply *message);
    void (*RANDR_set_screen_size)(XigCodec *codec, XigRANDRSetScreenSize *message);
    void (*RANDR_get_screen_resources)(XigCodec *codec, XigRANDRGetScreenResources *message);
    void (*RANDR_get_screen_resources_reply)(XigCodec *codec, XigRANDRGetScreenResourcesReply *message);
    void (*RANDR_get_output_info)(XigCodec *codec, XigRANDRGetOutputInfo *message);
    void (*RANDR_get_output_info_reply)(XigCodec *codec, XigRANDRGetOutputInfoReply *message);
    void (*RANDR_list_output_properties)(XigCodec *codec, XigRANDRListOutputProperties *message);
    void (*RANDR_list_output_properties_reply)(XigCodec *codec, XigRANDRListOutputPropertiesReply *message);
    void (*RANDR_query_output_property)(XigCodec *codec, XigRANDRQueryOutputProperty *message);
    void (*RANDR_query_output_property_reply)(XigCodec *codec, XigRANDRQueryOutputPropertyReply *message);
    void (*RANDR_configure_output_property)(XigCodec *codec, XigRANDRConfigureOutputProperty *message);
    void (*RANDR_change_output_property)(XigCodec *codec, XigRANDRChangeOutputProperty *message);
    void (*RANDR_delete_output_property)(XigCodec *codec, XigRANDRDeleteOutputProperty *message);
    void (*RANDR_get_output_property)(XigCodec *codec, XigRANDRGetOutputProperty *message);
    void (*RANDR_get_output_property_reply)(XigCodec *codec, XigRANDRGetOutputPropertyReply *message);
    void (*RANDR_create_mode)(XigCodec *codec, XigRANDRCreateMode *message);
    void (*RANDR_create_mode_reply)(XigCodec *codec, XigRANDRCreateModeReply *message);
    void (*RANDR_destroy_mode)(XigCodec *codec, XigRANDRDestroyMode *message);
    void (*RANDR_add_output_mode)(XigCodec *codec, XigRANDRAddOutputMode *message);
    void (*RANDR_delete_output_mode)(XigCodec *codec, XigRANDRDeleteOutputMode *message);
    void (*RANDR_get_crtc_info)(XigCodec *codec, XigRANDRGetCrtcInfo *message);
    void (*RANDR_get_crtc_info_reply)(XigCodec *codec, XigRANDRGetCrtcInfoReply *message);
    void (*RANDR_set_crtc_config)(XigCodec *codec, XigRANDRSetCrtcConfig *message);
    void (*RANDR_set_crtc_config_reply)(XigCodec *codec, XigRANDRSetCrtcConfigReply *message);
    void (*RANDR_get_crtc_gamma_size)(XigCodec *codec, XigRANDRGetCrtcGammaSize *message);
    void (*RANDR_get_crtc_gamma_size_reply)(XigCodec *codec, XigRANDRGetCrtcGammaSizeReply *message);
    void (*RANDR_get_crtc_gamma)(XigCodec *codec, XigRANDRGetCrtcGamma *message);
    void (*RANDR_get_crtc_gamma_reply)(XigCodec *codec, XigRANDRGetCrtcGammaReply *message);
    void (*RANDR_set_crtc_gamma)(XigCodec *codec, XigRANDRSetCrtcGamma *message);
    void (*RANDR_get_screen_resources_current)(XigCodec *codec, XigRANDRGetScreenResourcesCurrent *message);
    void (*RANDR_get_screen_resources_current_reply)(XigCodec *codec, XigRANDRGetScreenResourcesCurrentReply *message);
    void (*RANDR_set_crtc_transform)(XigCodec *codec, XigRANDRSetCrtcTransform *message);
    void (*RANDR_get_crtc_transform)(XigCodec *codec, XigRANDRGetCrtcTransform *message);
    void (*RANDR_get_crtc_transform_reply)(XigCodec *codec, XigRANDRGetCrtcTransformReply *message);
    void (*RANDR_get_panning)(XigCodec *codec, XigRANDRGetPanning *message);
    void (*RANDR_get_panning_reply)(XigCodec *codec, XigRANDRGetPanningReply *message);
    void (*RANDR_set_panning)(XigCodec *codec, XigRANDRSetPanning *message);
    void (*RANDR_set_panning_reply)(XigCodec *codec, XigRANDRSetPanningReply *message);
    void (*RANDR_set_output_primary)(XigCodec *codec, XigRANDRSetOutputPrimary *message);
    void (*RANDR_get_output_primary)(XigCodec *codec, XigRANDRGetOutputPrimary *message);
    void (*RANDR_get_output_primary_reply)(XigCodec *codec, XigRANDRGetOutputPrimaryReply *message);
    void (*XINERAMA_query_version)(XigCodec *codec, XigXINERAMAQueryVersion *message);
    void (*XINERAMA_query_version_reply)(XigCodec *codec, XigXINERAMAQueryVersionReply *message);
    void (*XINERAMA_get_state)(XigCodec *codec, XigXINERAMAGetState *message);
    void (*XINERAMA_get_state_reply)(XigCodec *codec, XigXINERAMAGetStateReply *message);
    void (*XINERAMA_get_screen_count)(XigCodec *codec, XigXINERAMAGetScreenCount *message);
    void (*XINERAMA_get_screen_count_reply)(XigCodec *codec, XigXINERAMAGetScreenCountReply *message);
    void (*XINERAMA_get_screen_size)(XigCodec *codec, XigXINERAMAGetScreenSize *message);
    void (*XINERAMA_get_screen_size_reply)(XigCodec *codec, XigXINERAMAGetScreenSizeReply *message);
    void (*XINERAMA_is_active)(XigCodec *codec, XigXINERAMAIsActive *message);
    void (*XINERAMA_is_active_reply)(XigCodec *codec, XigXINERAMAIsActiveReply *message);
    void (*XINERAMA_query_screens)(XigCodec *codec, XigXINERAMAQueryScreens *message);
    void (*XINERAMA_query_screens_reply)(XigCodec *codec, XigXINERAMAQueryScreensReply *message);
    void (*XKB_new_keyboard_notify)(XigCodec *codec, XigXKBNewKeyboardNotify *message);
    void (*XKB_map_notify)(XigCodec *codec, XigXKBMapNotify *message);
    void (*XKB_state_notify)(XigCodec *codec, XigXKBStateNotify *message);
    void (*XKB_controls_notify)(XigCodec *codec, XigXKBControlsNotify *message);
    void (*XKB_indicator_state_notify)(XigCodec *codec, XigXKBIndicatorStateNotify *message);
    void (*XKB_indicator_map_notify)(XigCodec *codec, XigXKBIndicatorMapNotify *message);
    void (*XKB_names_notify)(XigCodec *codec, XigXKBNamesNotify *message);
    void (*XKB_compat_map_notify)(XigCodec *codec, XigXKBCompatMapNotify *message);
    void (*XKB_bell_notify)(XigCodec *codec, XigXKBBellNotify *message);
    void (*XKB_action_message)(XigCodec *codec, XigXKBActionMessage *message);
    void (*XKB_access_xnotify)(XigCodec *codec, XigXKBAccessXNotify *message);
    void (*XKB_extension_device_notify)(XigCodec *codec, XigXKBExtensionDeviceNotify *message);
    void (*XKB_use_extension)(XigCodec *codec, XigXKBUseExtension *message);
    void (*XKB_use_extension_reply)(XigCodec *codec, XigXKBUseExtensionReply *message);
    void (*XKB_select_events)(XigCodec *codec, XigXKBSelectEvents *message);
    void (*XKB_bell)(XigCodec *codec, XigXKBBell *message);
    void (*XKB_get_state)(XigCodec *codec, XigXKBGetState *message);
    void (*XKB_get_state_reply)(XigCodec *codec, XigXKBGetStateReply *message);
    void (*XKB_latch_lock_state)(XigCodec *codec, XigXKBLatchLockState *message);
    void (*XKB_get_controls)(XigCodec *codec, XigXKBGetControls *message);
    void (*XKB_get_controls_reply)(XigCodec *codec, XigXKBGetControlsReply *message);
    void (*XKB_set_controls)(XigCodec *codec, XigXKBSetControls *message);
    void (*XKB_get_map)(XigCodec *codec, XigXKBGetMap *message);
    void (*XKB_get_map_reply)(XigCodec *codec, XigXKBGetMapReply *message);
    void (*XKB_set_map)(XigCodec *codec, XigXKBSetMap *message);
    void (*XKB_get_compat_map)(XigCodec *codec, XigXKBGetCompatMap *message);
    void (*XKB_get_compat_map_reply)(XigCodec *codec, XigXKBGetCompatMapReply *message);
    void (*XKB_set_compat_map)(XigCodec *codec, XigXKBSetCompatMap *message);
    void (*XKB_get_indicator_state)(XigCodec *codec, XigXKBGetIndicatorState *message);
    void (*XKB_get_indicator_state_reply)(XigCodec *codec, XigXKBGetIndicatorStateReply *message);
    void (*XKB_get_indicator_map)(XigCodec *codec, XigXKBGetIndicatorMap *message);
    void (*XKB_get_indicator_map_reply)(XigCodec *codec, XigXKBGetIndicatorMapReply *message);
    void (*XKB_set_indicator_map)(XigCodec *codec, XigXKBSetIndicatorMap *message);
    void (*XKB_get_named_indicator)(XigCodec *codec, XigXKBGetNamedIndicator *message);
    void (*XKB_get_named_indicator_reply)(XigCodec *codec, XigXKBGetNamedIndicatorReply *message);
    void (*XKB_set_named_indicator)(XigCodec *codec, XigXKBSetNamedIndicator *message);
    void (*XKB_get_names)(XigCodec *codec, XigXKBGetNames *message);
    void (*XKB_get_names_reply)(XigCodec *codec, XigXKBGetNamesReply *message);
    void (*XKB_set_names)(XigCodec *codec, XigXKBSetNames *message);
    void (*XKB_get_geometry)(XigCodec *codec, XigXKBGetGeometry *message);
    void (*XKB_get_geometry_reply)(XigCodec *codec, XigXKBGetGeometryReply *message);
    void (*XKB_set_geometry)(XigCodec *codec, XigXKBSetGeometry *message);
    void (*XKB_per_client_flags)(XigCodec *codec, XigXKBPerClientFlags *message);
    void (*XKB_per_client_flags_reply)(XigCodec *codec, XigXKBPerClientFlagsReply *message);
    void (*XKB_list_components)(XigCodec *codec, XigXKBListComponents *message);
    void (*XKB_list_components_reply)(XigCodec *codec, XigXKBListComponentsReply *message);
    void (*XKB_get_kbd_by_name)(XigCodec *codec, XigXKBGetKbdByName *message);
    void (*XKB_get_kbd_by_name_reply)(XigCodec *codec, XigXKBGetKbdByNameReply *message);
    void (*XKB_get_device_info)(XigCodec *codec, XigXKBGetDeviceInfo *message);
    void (*XKB_get_device_info_reply)(XigCodec *codec, XigXKBGetDeviceInfoReply *message);
    void (*XKB_set_device_info)(XigCodec *codec, XigXKBSetDeviceInfo *message);
    void (*XKB_set_debugging_flags)(XigCodec *codec, XigXKBSetDebuggingFlags *message);
    void (*XKB_set_debugging_flags_reply)(XigCodec *codec, XigXKBSetDebuggingFlagsReply *message);
    void (*RENDER_query_version)(XigCodec *codec, XigRENDERQueryVersion *message);
    void (*RENDER_query_version_reply)(XigCodec *codec, XigRENDERQueryVersionReply *message);
    void (*RENDER_query_pict_formats)(XigCodec *codec, XigRENDERQueryPictFormats *message);
    void (*RENDER_query_pict_formats_reply)(XigCodec *codec, XigRENDERQueryPictFormatsReply *message);
    void (*RENDER_query_pict_index_values)(XigCodec *codec, XigRENDERQueryPictIndexValues *message);
    void (*RENDER_query_pict_index_values_reply)(XigCodec *codec, XigRENDERQueryPictIndexValuesReply *message);
    void (*RENDER_create_picture)(XigCodec *codec, XigRENDERCreatePicture *message);
    void (*RENDER_change_picture)(XigCodec *codec, XigRENDERChangePicture *message);
    void (*RENDER_set_picture_clip_rectangles)(XigCodec *codec, XigRENDERSetPictureClipRectangles *message);
    void (*RENDER_free_picture)(XigCodec *codec, XigRENDERFreePicture *message);
    void (*RENDER_composite)(XigCodec *codec, XigRENDERComposite *message);
    void (*RENDER_trapezoids)(XigCodec *codec, XigRENDERTrapezoids *message);
    void (*RENDER_triangles)(XigCodec *codec, XigRENDERTriangles *message);
    void (*RENDER_tri_strip)(XigCodec *codec, XigRENDERTriStrip *message);
    void (*RENDER_tri_fan)(XigCodec *codec, XigRENDERTriFan *message);
    void (*RENDER_create_glyph_set)(XigCodec *codec, XigRENDERCreateGlyphSet *message);
    void (*RENDER_reference_glyph_set)(XigCodec *codec, XigRENDERReferenceGlyphSet *message);
    void (*RENDER_free_glyph_set)(XigCodec *codec, XigRENDERFreeGlyphSet *message);
    void (*RENDER_add_glyphs)(XigCodec *codec, XigRENDERAddGlyphs *message);
    void (*RENDER_free_glyphs)(XigCodec *codec, XigRENDERFreeGlyphs *message);
    void (*RENDER_composite_glyphs8)(XigCodec *codec, XigRENDERCompositeGlyphs8 *message);
    void (*RENDER_composite_glyphs16)(XigCodec *codec, XigRENDERCompositeGlyphs16 *message);
    void (*RENDER_composite_glyphs32)(XigCodec *codec, XigRENDERCompositeGlyphs32 *message);
    void (*RENDER_fill_rectangles)(XigCodec *codec, XigRENDERFillRectangles *message);
    void (*RENDER_create_cursor)(XigCodec *codec, XigRENDERCreateCursor *message);
    void (*RENDER_set_picture_transform)(XigCodec *codec, XigRENDERSetPictureTransform *message);
    void (*RENDER_query_filters)(XigCodec *codec, XigRENDERQueryFilters *message);
    void (*RENDER_query_filters_reply)(XigCodec *codec, XigRENDERQueryFiltersReply *message);
    void (*RENDER_set_picture_filter)(XigCodec *codec, XigRENDERSetPictureFilter *message);
    void (*RENDER_create_anim_cursor)(XigCodec *codec, XigRENDERCreateAnimCursor *message);
    void (*RENDER_add_traps)(XigCodec *codec, XigRENDERAddTraps *message);
    void (*RENDER_create_solid_fill)(XigCodec *codec, XigRENDERCreateSolidFill *message);
    void (*RENDER_create_linear_gradient)(XigCodec *codec, XigRENDERCreateLinearGradient *message);
    void (*RENDER_create_radial_gradient)(XigCodec *codec, XigRENDERCreateRadialGradient *message);
    void (*RENDER_create_conical_gradient)(XigCodec *codec, XigRENDERCreateConicalGradient *message);
} XigCodecClass;

GType xig_codec_get_type (void);

XigCodec *xig_codec_new (void);

void xig_codec_feed_data (XigCodec *codec, const guint8 *data, gsize data_length);

void xig_codec_feed_connect (XigCodec *codec, XigConnect *message);

void xig_codec_feed_failed (XigCodec *codec, XigFailed *message);

void xig_codec_feed_authenticate (XigCodec *codec, XigAuthenticate *message);

void xig_codec_feed_success (XigCodec *codec, XigSuccess *message);

void xig_codec_feed_error (XigCodec *codec, XigError *message);

void xig_codec_feed_key_press (XigCodec *codec, XigKeyPress *message);

void xig_codec_feed_button_press (XigCodec *codec, XigButtonPress *message);

void xig_codec_feed_motion_notify (XigCodec *codec, XigMotionNotify *message);

void xig_codec_feed_enter_notify (XigCodec *codec, XigEnterNotify *message);

void xig_codec_feed_focus_in (XigCodec *codec, XigFocusIn *message);

void xig_codec_feed_keymap_notify (XigCodec *codec, XigKeymapNotify *message);

void xig_codec_feed_expose (XigCodec *codec, XigExpose *message);

void xig_codec_feed_graphics_exposure (XigCodec *codec, XigGraphicsExposure *message);

void xig_codec_feed_no_exposure (XigCodec *codec, XigNoExposure *message);

void xig_codec_feed_visibility_notify (XigCodec *codec, XigVisibilityNotify *message);

void xig_codec_feed_create_notify (XigCodec *codec, XigCreateNotify *message);

void xig_codec_feed_destroy_notify (XigCodec *codec, XigDestroyNotify *message);

void xig_codec_feed_unmap_notify (XigCodec *codec, XigUnmapNotify *message);

void xig_codec_feed_map_notify (XigCodec *codec, XigMapNotify *message);

void xig_codec_feed_map_request (XigCodec *codec, XigMapRequest *message);

void xig_codec_feed_reparent_notify (XigCodec *codec, XigReparentNotify *message);

void xig_codec_feed_configure_notify (XigCodec *codec, XigConfigureNotify *message);

void xig_codec_feed_configure_request (XigCodec *codec, XigConfigureRequest *message);

void xig_codec_feed_gravity_notify (XigCodec *codec, XigGravityNotify *message);

void xig_codec_feed_resize_request (XigCodec *codec, XigResizeRequest *message);

void xig_codec_feed_circulate_notify (XigCodec *codec, XigCirculateNotify *message);

void xig_codec_feed_circulate_request (XigCodec *codec, XigCirculateRequest *message);

void xig_codec_feed_property_notify (XigCodec *codec, XigPropertyNotify *message);

void xig_codec_feed_selection_clear (XigCodec *codec, XigSelectionClear *message);

void xig_codec_feed_selection_request (XigCodec *codec, XigSelectionRequest *message);

void xig_codec_feed_selection_notify (XigCodec *codec, XigSelectionNotify *message);

void xig_codec_feed_colormap_notify (XigCodec *codec, XigColormapNotify *message);

void xig_codec_feed_client_message (XigCodec *codec, XigClientMessage *message);

void xig_codec_feed_mapping_notify (XigCodec *codec, XigMappingNotify *message);

void xig_codec_feed_create_window (XigCodec *codec, XigCreateWindow *message);

void xig_codec_feed_change_window_attributes (XigCodec *codec, XigChangeWindowAttributes *message);

void xig_codec_feed_get_window_attributes (XigCodec *codec, XigGetWindowAttributes *message);

void xig_codec_feed_get_window_attributes_reply (XigCodec *codec, XigGetWindowAttributesReply *message);

void xig_codec_feed_destroy_window (XigCodec *codec, XigDestroyWindow *message);

void xig_codec_feed_destroy_subwindows (XigCodec *codec, XigDestroySubwindows *message);

void xig_codec_feed_change_save_set (XigCodec *codec, XigChangeSaveSet *message);

void xig_codec_feed_reparent_window (XigCodec *codec, XigReparentWindow *message);

void xig_codec_feed_map_window (XigCodec *codec, XigMapWindow *message);

void xig_codec_feed_map_subwindows (XigCodec *codec, XigMapSubwindows *message);

void xig_codec_feed_unmap_window (XigCodec *codec, XigUnmapWindow *message);

void xig_codec_feed_unmap_subwindows (XigCodec *codec, XigUnmapSubwindows *message);

void xig_codec_feed_configure_window (XigCodec *codec, XigConfigureWindow *message);

void xig_codec_feed_circulate_window (XigCodec *codec, XigCirculateWindow *message);

void xig_codec_feed_get_geometry (XigCodec *codec, XigGetGeometry *message);

void xig_codec_feed_get_geometry_reply (XigCodec *codec, XigGetGeometryReply *message);

void xig_codec_feed_query_tree (XigCodec *codec, XigQueryTree *message);

void xig_codec_feed_query_tree_reply (XigCodec *codec, XigQueryTreeReply *message);

void xig_codec_feed_intern_atom (XigCodec *codec, XigInternAtom *message);

void xig_codec_feed_intern_atom_reply (XigCodec *codec, XigInternAtomReply *message);

void xig_codec_feed_get_atom_name (XigCodec *codec, XigGetAtomName *message);

void xig_codec_feed_get_atom_name_reply (XigCodec *codec, XigGetAtomNameReply *message);

void xig_codec_feed_change_property (XigCodec *codec, XigChangeProperty *message);

void xig_codec_feed_delete_property (XigCodec *codec, XigDeleteProperty *message);

void xig_codec_feed_get_property (XigCodec *codec, XigGetProperty *message);

void xig_codec_feed_get_property_reply (XigCodec *codec, XigGetPropertyReply *message);

void xig_codec_feed_list_properties (XigCodec *codec, XigListProperties *message);

void xig_codec_feed_list_properties_reply (XigCodec *codec, XigListPropertiesReply *message);

void xig_codec_feed_set_selection_owner (XigCodec *codec, XigSetSelectionOwner *message);

void xig_codec_feed_get_selection_owner (XigCodec *codec, XigGetSelectionOwner *message);

void xig_codec_feed_get_selection_owner_reply (XigCodec *codec, XigGetSelectionOwnerReply *message);

void xig_codec_feed_convert_selection (XigCodec *codec, XigConvertSelection *message);

void xig_codec_feed_send_event (XigCodec *codec, XigSendEvent *message);

void xig_codec_feed_grab_pointer (XigCodec *codec, XigGrabPointer *message);

void xig_codec_feed_grab_pointer_reply (XigCodec *codec, XigGrabPointerReply *message);

void xig_codec_feed_ungrab_pointer (XigCodec *codec, XigUngrabPointer *message);

void xig_codec_feed_grab_button (XigCodec *codec, XigGrabButton *message);

void xig_codec_feed_ungrab_button (XigCodec *codec, XigUngrabButton *message);

void xig_codec_feed_change_active_pointer_grab (XigCodec *codec, XigChangeActivePointerGrab *message);

void xig_codec_feed_grab_keyboard (XigCodec *codec, XigGrabKeyboard *message);

void xig_codec_feed_grab_keyboard_reply (XigCodec *codec, XigGrabKeyboardReply *message);

void xig_codec_feed_ungrab_keyboard (XigCodec *codec, XigUngrabKeyboard *message);

void xig_codec_feed_grab_key (XigCodec *codec, XigGrabKey *message);

void xig_codec_feed_ungrab_key (XigCodec *codec, XigUngrabKey *message);

void xig_codec_feed_allow_events (XigCodec *codec, XigAllowEvents *message);

void xig_codec_feed_grab_server (XigCodec *codec, XigGrabServer *message);

void xig_codec_feed_ungrab_server (XigCodec *codec, XigUngrabServer *message);

void xig_codec_feed_query_pointer (XigCodec *codec, XigQueryPointer *message);

void xig_codec_feed_query_pointer_reply (XigCodec *codec, XigQueryPointerReply *message);

void xig_codec_feed_get_motion_events (XigCodec *codec, XigGetMotionEvents *message);

void xig_codec_feed_get_motion_events_reply (XigCodec *codec, XigGetMotionEventsReply *message);

void xig_codec_feed_translate_coordinates (XigCodec *codec, XigTranslateCoordinates *message);

void xig_codec_feed_translate_coordinates_reply (XigCodec *codec, XigTranslateCoordinatesReply *message);

void xig_codec_feed_warp_pointer (XigCodec *codec, XigWarpPointer *message);

void xig_codec_feed_set_input_focus (XigCodec *codec, XigSetInputFocus *message);

void xig_codec_feed_get_input_focus (XigCodec *codec, XigGetInputFocus *message);

void xig_codec_feed_get_input_focus_reply (XigCodec *codec, XigGetInputFocusReply *message);

void xig_codec_feed_query_keymap (XigCodec *codec, XigQueryKeymap *message);

void xig_codec_feed_query_keymap_reply (XigCodec *codec, XigQueryKeymapReply *message);

void xig_codec_feed_open_font (XigCodec *codec, XigOpenFont *message);

void xig_codec_feed_close_font (XigCodec *codec, XigCloseFont *message);

void xig_codec_feed_query_font (XigCodec *codec, XigQueryFont *message);

void xig_codec_feed_query_font_reply (XigCodec *codec, XigQueryFontReply *message);

void xig_codec_feed_query_text_extents (XigCodec *codec, XigQueryTextExtents *message);

void xig_codec_feed_query_text_extents_reply (XigCodec *codec, XigQueryTextExtentsReply *message);

void xig_codec_feed_list_fonts (XigCodec *codec, XigListFonts *message);

void xig_codec_feed_list_fonts_reply (XigCodec *codec, XigListFontsReply *message);

void xig_codec_feed_list_fonts_with_info (XigCodec *codec, XigListFontsWithInfo *message);

void xig_codec_feed_list_fonts_with_info_reply (XigCodec *codec, XigListFontsWithInfoReply *message);

void xig_codec_feed_set_font_path (XigCodec *codec, XigSetFontPath *message);

void xig_codec_feed_get_font_path (XigCodec *codec, XigGetFontPath *message);

void xig_codec_feed_get_font_path_reply (XigCodec *codec, XigGetFontPathReply *message);

void xig_codec_feed_create_pixmap (XigCodec *codec, XigCreatePixmap *message);

void xig_codec_feed_free_pixmap (XigCodec *codec, XigFreePixmap *message);

void xig_codec_feed_create_gc (XigCodec *codec, XigCreateGC *message);

void xig_codec_feed_change_gc (XigCodec *codec, XigChangeGC *message);

void xig_codec_feed_copy_gc (XigCodec *codec, XigCopyGC *message);

void xig_codec_feed_set_dashes (XigCodec *codec, XigSetDashes *message);

void xig_codec_feed_set_clip_rectangles (XigCodec *codec, XigSetClipRectangles *message);

void xig_codec_feed_free_gc (XigCodec *codec, XigFreeGC *message);

void xig_codec_feed_clear_area (XigCodec *codec, XigClearArea *message);

void xig_codec_feed_copy_area (XigCodec *codec, XigCopyArea *message);

void xig_codec_feed_copy_plane (XigCodec *codec, XigCopyPlane *message);

void xig_codec_feed_poly_point (XigCodec *codec, XigPolyPoint *message);

void xig_codec_feed_poly_line (XigCodec *codec, XigPolyLine *message);

void xig_codec_feed_poly_segment (XigCodec *codec, XigPolySegment *message);

void xig_codec_feed_poly_rectangle (XigCodec *codec, XigPolyRectangle *message);

void xig_codec_feed_poly_arc (XigCodec *codec, XigPolyArc *message);

void xig_codec_feed_fill_poly (XigCodec *codec, XigFillPoly *message);

void xig_codec_feed_poly_fill_rectangle (XigCodec *codec, XigPolyFillRectangle *message);

void xig_codec_feed_poly_fill_arc (XigCodec *codec, XigPolyFillArc *message);

void xig_codec_feed_put_image (XigCodec *codec, XigPutImage *message);

void xig_codec_feed_get_image (XigCodec *codec, XigGetImage *message);

void xig_codec_feed_get_image_reply (XigCodec *codec, XigGetImageReply *message);

void xig_codec_feed_poly_text8 (XigCodec *codec, XigPolyText8 *message);

void xig_codec_feed_poly_text16 (XigCodec *codec, XigPolyText16 *message);

void xig_codec_feed_image_text8 (XigCodec *codec, XigImageText8 *message);

void xig_codec_feed_image_text16 (XigCodec *codec, XigImageText16 *message);

void xig_codec_feed_create_colormap (XigCodec *codec, XigCreateColormap *message);

void xig_codec_feed_free_colormap (XigCodec *codec, XigFreeColormap *message);

void xig_codec_feed_copy_colormap_and_free (XigCodec *codec, XigCopyColormapAndFree *message);

void xig_codec_feed_install_colormap (XigCodec *codec, XigInstallColormap *message);

void xig_codec_feed_uninstall_colormap (XigCodec *codec, XigUninstallColormap *message);

void xig_codec_feed_list_installed_colormaps (XigCodec *codec, XigListInstalledColormaps *message);

void xig_codec_feed_list_installed_colormaps_reply (XigCodec *codec, XigListInstalledColormapsReply *message);

void xig_codec_feed_alloc_color (XigCodec *codec, XigAllocColor *message);

void xig_codec_feed_alloc_color_reply (XigCodec *codec, XigAllocColorReply *message);

void xig_codec_feed_alloc_named_color (XigCodec *codec, XigAllocNamedColor *message);

void xig_codec_feed_alloc_named_color_reply (XigCodec *codec, XigAllocNamedColorReply *message);

void xig_codec_feed_alloc_color_cells (XigCodec *codec, XigAllocColorCells *message);

void xig_codec_feed_alloc_color_cells_reply (XigCodec *codec, XigAllocColorCellsReply *message);

void xig_codec_feed_alloc_color_planes (XigCodec *codec, XigAllocColorPlanes *message);

void xig_codec_feed_alloc_color_planes_reply (XigCodec *codec, XigAllocColorPlanesReply *message);

void xig_codec_feed_free_colors (XigCodec *codec, XigFreeColors *message);

void xig_codec_feed_store_colors (XigCodec *codec, XigStoreColors *message);

void xig_codec_feed_store_named_color (XigCodec *codec, XigStoreNamedColor *message);

void xig_codec_feed_query_colors (XigCodec *codec, XigQueryColors *message);

void xig_codec_feed_query_colors_reply (XigCodec *codec, XigQueryColorsReply *message);

void xig_codec_feed_lookup_color (XigCodec *codec, XigLookupColor *message);

void xig_codec_feed_lookup_color_reply (XigCodec *codec, XigLookupColorReply *message);

void xig_codec_feed_create_cursor (XigCodec *codec, XigCreateCursor *message);

void xig_codec_feed_create_glyph_cursor (XigCodec *codec, XigCreateGlyphCursor *message);

void xig_codec_feed_free_cursor (XigCodec *codec, XigFreeCursor *message);

void xig_codec_feed_recolor_cursor (XigCodec *codec, XigRecolorCursor *message);

void xig_codec_feed_query_best_size (XigCodec *codec, XigQueryBestSize *message);

void xig_codec_feed_query_best_size_reply (XigCodec *codec, XigQueryBestSizeReply *message);

void xig_codec_feed_query_extension (XigCodec *codec, XigQueryExtension *message);

void xig_codec_feed_query_extension_reply (XigCodec *codec, XigQueryExtensionReply *message);

void xig_codec_feed_list_extensions (XigCodec *codec, XigListExtensions *message);

void xig_codec_feed_list_extensions_reply (XigCodec *codec, XigListExtensionsReply *message);

void xig_codec_feed_change_keyboard_mapping (XigCodec *codec, XigChangeKeyboardMapping *message);

void xig_codec_feed_get_keyboard_mapping (XigCodec *codec, XigGetKeyboardMapping *message);

void xig_codec_feed_get_keyboard_mapping_reply (XigCodec *codec, XigGetKeyboardMappingReply *message);

void xig_codec_feed_change_keyboard_control (XigCodec *codec, XigChangeKeyboardControl *message);

void xig_codec_feed_get_keyboard_control (XigCodec *codec, XigGetKeyboardControl *message);

void xig_codec_feed_get_keyboard_control_reply (XigCodec *codec, XigGetKeyboardControlReply *message);

void xig_codec_feed_bell (XigCodec *codec, XigBell *message);

void xig_codec_feed_change_pointer_control (XigCodec *codec, XigChangePointerControl *message);

void xig_codec_feed_get_pointer_control (XigCodec *codec, XigGetPointerControl *message);

void xig_codec_feed_get_pointer_control_reply (XigCodec *codec, XigGetPointerControlReply *message);

void xig_codec_feed_set_screen_saver (XigCodec *codec, XigSetScreenSaver *message);

void xig_codec_feed_get_screen_saver (XigCodec *codec, XigGetScreenSaver *message);

void xig_codec_feed_get_screen_saver_reply (XigCodec *codec, XigGetScreenSaverReply *message);

void xig_codec_feed_change_hosts (XigCodec *codec, XigChangeHosts *message);

void xig_codec_feed_list_hosts (XigCodec *codec, XigListHosts *message);

void xig_codec_feed_list_hosts_reply (XigCodec *codec, XigListHostsReply *message);

void xig_codec_feed_set_access_control (XigCodec *codec, XigSetAccessControl *message);

void xig_codec_feed_set_close_down_mode (XigCodec *codec, XigSetCloseDownMode *message);

void xig_codec_feed_kill_client (XigCodec *codec, XigKillClient *message);

void xig_codec_feed_rotate_properties (XigCodec *codec, XigRotateProperties *message);

void xig_codec_feed_force_screen_saver (XigCodec *codec, XigForceScreenSaver *message);

void xig_codec_feed_set_pointer_mapping (XigCodec *codec, XigSetPointerMapping *message);

void xig_codec_feed_set_pointer_mapping_reply (XigCodec *codec, XigSetPointerMappingReply *message);

void xig_codec_feed_get_pointer_mapping (XigCodec *codec, XigGetPointerMapping *message);

void xig_codec_feed_get_pointer_mapping_reply (XigCodec *codec, XigGetPointerMappingReply *message);

void xig_codec_feed_set_modifier_mapping (XigCodec *codec, XigSetModifierMapping *message);

void xig_codec_feed_set_modifier_mapping_reply (XigCodec *codec, XigSetModifierMappingReply *message);

void xig_codec_feed_get_modifier_mapping (XigCodec *codec, XigGetModifierMapping *message);

void xig_codec_feed_get_modifier_mapping_reply (XigCodec *codec, XigGetModifierMappingReply *message);

void xig_codec_feed_no_operation (XigCodec *codec, XigNoOperation *message);

void xig_codec_feed_BIGREQ_enable (XigCodec *codec, XigBIGREQEnable *message);

void xig_codec_feed_BIGREQ_enable_reply (XigCodec *codec, XigBIGREQEnableReply *message);

void xig_codec_feed_SYNC_counter_notify (XigCodec *codec, XigSYNCCounterNotify *message);

void xig_codec_feed_SYNC_alarm_notify (XigCodec *codec, XigSYNCAlarmNotify *message);

void xig_codec_feed_SYNC_initialize (XigCodec *codec, XigSYNCInitialize *message);

void xig_codec_feed_SYNC_initialize_reply (XigCodec *codec, XigSYNCInitializeReply *message);

void xig_codec_feed_SYNC_list_system_counters (XigCodec *codec, XigSYNCListSystemCounters *message);

void xig_codec_feed_SYNC_list_system_counters_reply (XigCodec *codec, XigSYNCListSystemCountersReply *message);

void xig_codec_feed_SYNC_create_counter (XigCodec *codec, XigSYNCCreateCounter *message);

void xig_codec_feed_SYNC_destroy_counter (XigCodec *codec, XigSYNCDestroyCounter *message);

void xig_codec_feed_SYNC_query_counter (XigCodec *codec, XigSYNCQueryCounter *message);

void xig_codec_feed_SYNC_query_counter_reply (XigCodec *codec, XigSYNCQueryCounterReply *message);

void xig_codec_feed_SYNC_await (XigCodec *codec, XigSYNCAwait *message);

void xig_codec_feed_SYNC_change_counter (XigCodec *codec, XigSYNCChangeCounter *message);

void xig_codec_feed_SYNC_set_counter (XigCodec *codec, XigSYNCSetCounter *message);

void xig_codec_feed_SYNC_create_alarm (XigCodec *codec, XigSYNCCreateAlarm *message);

void xig_codec_feed_SYNC_change_alarm (XigCodec *codec, XigSYNCChangeAlarm *message);

void xig_codec_feed_SYNC_destroy_alarm (XigCodec *codec, XigSYNCDestroyAlarm *message);

void xig_codec_feed_SYNC_query_alarm (XigCodec *codec, XigSYNCQueryAlarm *message);

void xig_codec_feed_SYNC_query_alarm_reply (XigCodec *codec, XigSYNCQueryAlarmReply *message);

void xig_codec_feed_SYNC_set_priority (XigCodec *codec, XigSYNCSetPriority *message);

void xig_codec_feed_SYNC_get_priority (XigCodec *codec, XigSYNCGetPriority *message);

void xig_codec_feed_SYNC_get_priority_reply (XigCodec *codec, XigSYNCGetPriorityReply *message);

void xig_codec_feed_SYNC_create_fence (XigCodec *codec, XigSYNCCreateFence *message);

void xig_codec_feed_SYNC_trigger_fence (XigCodec *codec, XigSYNCTriggerFence *message);

void xig_codec_feed_SYNC_reset_fence (XigCodec *codec, XigSYNCResetFence *message);

void xig_codec_feed_SYNC_destroy_fence (XigCodec *codec, XigSYNCDestroyFence *message);

void xig_codec_feed_SYNC_query_fence (XigCodec *codec, XigSYNCQueryFence *message);

void xig_codec_feed_SYNC_query_fence_reply (XigCodec *codec, XigSYNCQueryFenceReply *message);

void xig_codec_feed_SYNC_await_fence (XigCodec *codec, XigSYNCAwaitFence *message);

void xig_codec_feed_RANDR_screen_change_notify (XigCodec *codec, XigRANDRScreenChangeNotify *message);

void xig_codec_feed_RANDR_notify (XigCodec *codec, XigRANDRNotify *message);

void xig_codec_feed_RANDR_query_version (XigCodec *codec, XigRANDRQueryVersion *message);

void xig_codec_feed_RANDR_query_version_reply (XigCodec *codec, XigRANDRQueryVersionReply *message);

void xig_codec_feed_RANDR_set_screen_config (XigCodec *codec, XigRANDRSetScreenConfig *message);

void xig_codec_feed_RANDR_set_screen_config_reply (XigCodec *codec, XigRANDRSetScreenConfigReply *message);

void xig_codec_feed_RANDR_select_input (XigCodec *codec, XigRANDRSelectInput *message);

void xig_codec_feed_RANDR_get_screen_info (XigCodec *codec, XigRANDRGetScreenInfo *message);

void xig_codec_feed_RANDR_get_screen_info_reply (XigCodec *codec, XigRANDRGetScreenInfoReply *message);

void xig_codec_feed_RANDR_get_screen_size_range (XigCodec *codec, XigRANDRGetScreenSizeRange *message);

void xig_codec_feed_RANDR_get_screen_size_range_reply (XigCodec *codec, XigRANDRGetScreenSizeRangeReply *message);

void xig_codec_feed_RANDR_set_screen_size (XigCodec *codec, XigRANDRSetScreenSize *message);

void xig_codec_feed_RANDR_get_screen_resources (XigCodec *codec, XigRANDRGetScreenResources *message);

void xig_codec_feed_RANDR_get_screen_resources_reply (XigCodec *codec, XigRANDRGetScreenResourcesReply *message);

void xig_codec_feed_RANDR_get_output_info (XigCodec *codec, XigRANDRGetOutputInfo *message);

void xig_codec_feed_RANDR_get_output_info_reply (XigCodec *codec, XigRANDRGetOutputInfoReply *message);

void xig_codec_feed_RANDR_list_output_properties (XigCodec *codec, XigRANDRListOutputProperties *message);

void xig_codec_feed_RANDR_list_output_properties_reply (XigCodec *codec, XigRANDRListOutputPropertiesReply *message);

void xig_codec_feed_RANDR_query_output_property (XigCodec *codec, XigRANDRQueryOutputProperty *message);

void xig_codec_feed_RANDR_query_output_property_reply (XigCodec *codec, XigRANDRQueryOutputPropertyReply *message);

void xig_codec_feed_RANDR_configure_output_property (XigCodec *codec, XigRANDRConfigureOutputProperty *message);

void xig_codec_feed_RANDR_change_output_property (XigCodec *codec, XigRANDRChangeOutputProperty *message);

void xig_codec_feed_RANDR_delete_output_property (XigCodec *codec, XigRANDRDeleteOutputProperty *message);

void xig_codec_feed_RANDR_get_output_property (XigCodec *codec, XigRANDRGetOutputProperty *message);

void xig_codec_feed_RANDR_get_output_property_reply (XigCodec *codec, XigRANDRGetOutputPropertyReply *message);

void xig_codec_feed_RANDR_create_mode (XigCodec *codec, XigRANDRCreateMode *message);

void xig_codec_feed_RANDR_create_mode_reply (XigCodec *codec, XigRANDRCreateModeReply *message);

void xig_codec_feed_RANDR_destroy_mode (XigCodec *codec, XigRANDRDestroyMode *message);

void xig_codec_feed_RANDR_add_output_mode (XigCodec *codec, XigRANDRAddOutputMode *message);

void xig_codec_feed_RANDR_delete_output_mode (XigCodec *codec, XigRANDRDeleteOutputMode *message);

void xig_codec_feed_RANDR_get_crtc_info (XigCodec *codec, XigRANDRGetCrtcInfo *message);

void xig_codec_feed_RANDR_get_crtc_info_reply (XigCodec *codec, XigRANDRGetCrtcInfoReply *message);

void xig_codec_feed_RANDR_set_crtc_config (XigCodec *codec, XigRANDRSetCrtcConfig *message);

void xig_codec_feed_RANDR_set_crtc_config_reply (XigCodec *codec, XigRANDRSetCrtcConfigReply *message);

void xig_codec_feed_RANDR_get_crtc_gamma_size (XigCodec *codec, XigRANDRGetCrtcGammaSize *message);

void xig_codec_feed_RANDR_get_crtc_gamma_size_reply (XigCodec *codec, XigRANDRGetCrtcGammaSizeReply *message);

void xig_codec_feed_RANDR_get_crtc_gamma (XigCodec *codec, XigRANDRGetCrtcGamma *message);

void xig_codec_feed_RANDR_get_crtc_gamma_reply (XigCodec *codec, XigRANDRGetCrtcGammaReply *message);

void xig_codec_feed_RANDR_set_crtc_gamma (XigCodec *codec, XigRANDRSetCrtcGamma *message);

void xig_codec_feed_RANDR_get_screen_resources_current (XigCodec *codec, XigRANDRGetScreenResourcesCurrent *message);

void xig_codec_feed_RANDR_get_screen_resources_current_reply (XigCodec *codec, XigRANDRGetScreenResourcesCurrentReply *message);

void xig_codec_feed_RANDR_set_crtc_transform (XigCodec *codec, XigRANDRSetCrtcTransform *message);

void xig_codec_feed_RANDR_get_crtc_transform (XigCodec *codec, XigRANDRGetCrtcTransform *message);

void xig_codec_feed_RANDR_get_crtc_transform_reply (XigCodec *codec, XigRANDRGetCrtcTransformReply *message);

void xig_codec_feed_RANDR_get_panning (XigCodec *codec, XigRANDRGetPanning *message);

void xig_codec_feed_RANDR_get_panning_reply (XigCodec *codec, XigRANDRGetPanningReply *message);

void xig_codec_feed_RANDR_set_panning (XigCodec *codec, XigRANDRSetPanning *message);

void xig_codec_feed_RANDR_set_panning_reply (XigCodec *codec, XigRANDRSetPanningReply *message);

void xig_codec_feed_RANDR_set_output_primary (XigCodec *codec, XigRANDRSetOutputPrimary *message);

void xig_codec_feed_RANDR_get_output_primary (XigCodec *codec, XigRANDRGetOutputPrimary *message);

void xig_codec_feed_RANDR_get_output_primary_reply (XigCodec *codec, XigRANDRGetOutputPrimaryReply *message);

void xig_codec_feed_XINERAMA_query_version (XigCodec *codec, XigXINERAMAQueryVersion *message);

void xig_codec_feed_XINERAMA_query_version_reply (XigCodec *codec, XigXINERAMAQueryVersionReply *message);

void xig_codec_feed_XINERAMA_get_state (XigCodec *codec, XigXINERAMAGetState *message);

void xig_codec_feed_XINERAMA_get_state_reply (XigCodec *codec, XigXINERAMAGetStateReply *message);

void xig_codec_feed_XINERAMA_get_screen_count (XigCodec *codec, XigXINERAMAGetScreenCount *message);

void xig_codec_feed_XINERAMA_get_screen_count_reply (XigCodec *codec, XigXINERAMAGetScreenCountReply *message);

void xig_codec_feed_XINERAMA_get_screen_size (XigCodec *codec, XigXINERAMAGetScreenSize *message);

void xig_codec_feed_XINERAMA_get_screen_size_reply (XigCodec *codec, XigXINERAMAGetScreenSizeReply *message);

void xig_codec_feed_XINERAMA_is_active (XigCodec *codec, XigXINERAMAIsActive *message);

void xig_codec_feed_XINERAMA_is_active_reply (XigCodec *codec, XigXINERAMAIsActiveReply *message);

void xig_codec_feed_XINERAMA_query_screens (XigCodec *codec, XigXINERAMAQueryScreens *message);

void xig_codec_feed_XINERAMA_query_screens_reply (XigCodec *codec, XigXINERAMAQueryScreensReply *message);

void xig_codec_feed_XKB_new_keyboard_notify (XigCodec *codec, XigXKBNewKeyboardNotify *message);

void xig_codec_feed_XKB_map_notify (XigCodec *codec, XigXKBMapNotify *message);

void xig_codec_feed_XKB_state_notify (XigCodec *codec, XigXKBStateNotify *message);

void xig_codec_feed_XKB_controls_notify (XigCodec *codec, XigXKBControlsNotify *message);

void xig_codec_feed_XKB_indicator_state_notify (XigCodec *codec, XigXKBIndicatorStateNotify *message);

void xig_codec_feed_XKB_indicator_map_notify (XigCodec *codec, XigXKBIndicatorMapNotify *message);

void xig_codec_feed_XKB_names_notify (XigCodec *codec, XigXKBNamesNotify *message);

void xig_codec_feed_XKB_compat_map_notify (XigCodec *codec, XigXKBCompatMapNotify *message);

void xig_codec_feed_XKB_bell_notify (XigCodec *codec, XigXKBBellNotify *message);

void xig_codec_feed_XKB_action_message (XigCodec *codec, XigXKBActionMessage *message);

void xig_codec_feed_XKB_access_xnotify (XigCodec *codec, XigXKBAccessXNotify *message);

void xig_codec_feed_XKB_extension_device_notify (XigCodec *codec, XigXKBExtensionDeviceNotify *message);

void xig_codec_feed_XKB_use_extension (XigCodec *codec, XigXKBUseExtension *message);

void xig_codec_feed_XKB_use_extension_reply (XigCodec *codec, XigXKBUseExtensionReply *message);

void xig_codec_feed_XKB_select_events (XigCodec *codec, XigXKBSelectEvents *message);

void xig_codec_feed_XKB_bell (XigCodec *codec, XigXKBBell *message);

void xig_codec_feed_XKB_get_state (XigCodec *codec, XigXKBGetState *message);

void xig_codec_feed_XKB_get_state_reply (XigCodec *codec, XigXKBGetStateReply *message);

void xig_codec_feed_XKB_latch_lock_state (XigCodec *codec, XigXKBLatchLockState *message);

void xig_codec_feed_XKB_get_controls (XigCodec *codec, XigXKBGetControls *message);

void xig_codec_feed_XKB_get_controls_reply (XigCodec *codec, XigXKBGetControlsReply *message);

void xig_codec_feed_XKB_set_controls (XigCodec *codec, XigXKBSetControls *message);

void xig_codec_feed_XKB_get_map (XigCodec *codec, XigXKBGetMap *message);

void xig_codec_feed_XKB_get_map_reply (XigCodec *codec, XigXKBGetMapReply *message);

void xig_codec_feed_XKB_set_map (XigCodec *codec, XigXKBSetMap *message);

void xig_codec_feed_XKB_get_compat_map (XigCodec *codec, XigXKBGetCompatMap *message);

void xig_codec_feed_XKB_get_compat_map_reply (XigCodec *codec, XigXKBGetCompatMapReply *message);

void xig_codec_feed_XKB_set_compat_map (XigCodec *codec, XigXKBSetCompatMap *message);

void xig_codec_feed_XKB_get_indicator_state (XigCodec *codec, XigXKBGetIndicatorState *message);

void xig_codec_feed_XKB_get_indicator_state_reply (XigCodec *codec, XigXKBGetIndicatorStateReply *message);

void xig_codec_feed_XKB_get_indicator_map (XigCodec *codec, XigXKBGetIndicatorMap *message);

void xig_codec_feed_XKB_get_indicator_map_reply (XigCodec *codec, XigXKBGetIndicatorMapReply *message);

void xig_codec_feed_XKB_set_indicator_map (XigCodec *codec, XigXKBSetIndicatorMap *message);

void xig_codec_feed_XKB_get_named_indicator (XigCodec *codec, XigXKBGetNamedIndicator *message);

void xig_codec_feed_XKB_get_named_indicator_reply (XigCodec *codec, XigXKBGetNamedIndicatorReply *message);

void xig_codec_feed_XKB_set_named_indicator (XigCodec *codec, XigXKBSetNamedIndicator *message);

void xig_codec_feed_XKB_get_names (XigCodec *codec, XigXKBGetNames *message);

void xig_codec_feed_XKB_get_names_reply (XigCodec *codec, XigXKBGetNamesReply *message);

void xig_codec_feed_XKB_set_names (XigCodec *codec, XigXKBSetNames *message);

void xig_codec_feed_XKB_get_geometry (XigCodec *codec, XigXKBGetGeometry *message);

void xig_codec_feed_XKB_get_geometry_reply (XigCodec *codec, XigXKBGetGeometryReply *message);

void xig_codec_feed_XKB_set_geometry (XigCodec *codec, XigXKBSetGeometry *message);

void xig_codec_feed_XKB_per_client_flags (XigCodec *codec, XigXKBPerClientFlags *message);

void xig_codec_feed_XKB_per_client_flags_reply (XigCodec *codec, XigXKBPerClientFlagsReply *message);

void xig_codec_feed_XKB_list_components (XigCodec *codec, XigXKBListComponents *message);

void xig_codec_feed_XKB_list_components_reply (XigCodec *codec, XigXKBListComponentsReply *message);

void xig_codec_feed_XKB_get_kbd_by_name (XigCodec *codec, XigXKBGetKbdByName *message);

void xig_codec_feed_XKB_get_kbd_by_name_reply (XigCodec *codec, XigXKBGetKbdByNameReply *message);

void xig_codec_feed_XKB_get_device_info (XigCodec *codec, XigXKBGetDeviceInfo *message);

void xig_codec_feed_XKB_get_device_info_reply (XigCodec *codec, XigXKBGetDeviceInfoReply *message);

void xig_codec_feed_XKB_set_device_info (XigCodec *codec, XigXKBSetDeviceInfo *message);

void xig_codec_feed_XKB_set_debugging_flags (XigCodec *codec, XigXKBSetDebuggingFlags *message);

void xig_codec_feed_XKB_set_debugging_flags_reply (XigCodec *codec, XigXKBSetDebuggingFlagsReply *message);

void xig_codec_feed_RENDER_query_version (XigCodec *codec, XigRENDERQueryVersion *message);

void xig_codec_feed_RENDER_query_version_reply (XigCodec *codec, XigRENDERQueryVersionReply *message);

void xig_codec_feed_RENDER_query_pict_formats (XigCodec *codec, XigRENDERQueryPictFormats *message);

void xig_codec_feed_RENDER_query_pict_formats_reply (XigCodec *codec, XigRENDERQueryPictFormatsReply *message);

void xig_codec_feed_RENDER_query_pict_index_values (XigCodec *codec, XigRENDERQueryPictIndexValues *message);

void xig_codec_feed_RENDER_query_pict_index_values_reply (XigCodec *codec, XigRENDERQueryPictIndexValuesReply *message);

void xig_codec_feed_RENDER_create_picture (XigCodec *codec, XigRENDERCreatePicture *message);

void xig_codec_feed_RENDER_change_picture (XigCodec *codec, XigRENDERChangePicture *message);

void xig_codec_feed_RENDER_set_picture_clip_rectangles (XigCodec *codec, XigRENDERSetPictureClipRectangles *message);

void xig_codec_feed_RENDER_free_picture (XigCodec *codec, XigRENDERFreePicture *message);

void xig_codec_feed_RENDER_composite (XigCodec *codec, XigRENDERComposite *message);

void xig_codec_feed_RENDER_trapezoids (XigCodec *codec, XigRENDERTrapezoids *message);

void xig_codec_feed_RENDER_triangles (XigCodec *codec, XigRENDERTriangles *message);

void xig_codec_feed_RENDER_tri_strip (XigCodec *codec, XigRENDERTriStrip *message);

void xig_codec_feed_RENDER_tri_fan (XigCodec *codec, XigRENDERTriFan *message);

void xig_codec_feed_RENDER_create_glyph_set (XigCodec *codec, XigRENDERCreateGlyphSet *message);

void xig_codec_feed_RENDER_reference_glyph_set (XigCodec *codec, XigRENDERReferenceGlyphSet *message);

void xig_codec_feed_RENDER_free_glyph_set (XigCodec *codec, XigRENDERFreeGlyphSet *message);

void xig_codec_feed_RENDER_add_glyphs (XigCodec *codec, XigRENDERAddGlyphs *message);

void xig_codec_feed_RENDER_free_glyphs (XigCodec *codec, XigRENDERFreeGlyphs *message);

void xig_codec_feed_RENDER_composite_glyphs8 (XigCodec *codec, XigRENDERCompositeGlyphs8 *message);

void xig_codec_feed_RENDER_composite_glyphs16 (XigCodec *codec, XigRENDERCompositeGlyphs16 *message);

void xig_codec_feed_RENDER_composite_glyphs32 (XigCodec *codec, XigRENDERCompositeGlyphs32 *message);

void xig_codec_feed_RENDER_fill_rectangles (XigCodec *codec, XigRENDERFillRectangles *message);

void xig_codec_feed_RENDER_create_cursor (XigCodec *codec, XigRENDERCreateCursor *message);

void xig_codec_feed_RENDER_set_picture_transform (XigCodec *codec, XigRENDERSetPictureTransform *message);

void xig_codec_feed_RENDER_query_filters (XigCodec *codec, XigRENDERQueryFilters *message);

void xig_codec_feed_RENDER_query_filters_reply (XigCodec *codec, XigRENDERQueryFiltersReply *message);

void xig_codec_feed_RENDER_set_picture_filter (XigCodec *codec, XigRENDERSetPictureFilter *message);

void xig_codec_feed_RENDER_create_anim_cursor (XigCodec *codec, XigRENDERCreateAnimCursor *message);

void xig_codec_feed_RENDER_add_traps (XigCodec *codec, XigRENDERAddTraps *message);

void xig_codec_feed_RENDER_create_solid_fill (XigCodec *codec, XigRENDERCreateSolidFill *message);

void xig_codec_feed_RENDER_create_linear_gradient (XigCodec *codec, XigRENDERCreateLinearGradient *message);

void xig_codec_feed_RENDER_create_radial_gradient (XigCodec *codec, XigRENDERCreateRadialGradient *message);

void xig_codec_feed_RENDER_create_conical_gradient (XigCodec *codec, XigRENDERCreateConicalGradient *message);

G_END_DECLS

#endif /* _XIG_CODEC_H_ */
