/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#ifndef _XIG_EVENTS_H_
#define _XIG_EVENTS_H_

#include <glib-object.h>

G_BEGIN_DECLS

typedef enum
{
    XIG_EVENT_KeyPress             = 0x00000001,
    XIG_EVENT_KeyRelease           = 0x00000002,
    XIG_EVENT_ButtonPress          = 0x00000004,
    XIG_EVENT_ButtonRelease        = 0x00000008,
    XIG_EVENT_EnterWindow          = 0x00000010,
    XIG_EVENT_LeaveWindow          = 0x00000020,
    XIG_EVENT_PointerMotion        = 0x00000040,
    XIG_EVENT_PointerMotionHint    = 0x00000080,
    XIG_EVENT_Button1Motion        = 0x00000100,
    XIG_EVENT_Button2Motion        = 0x00000200,
    XIG_EVENT_Button3Motion        = 0x00000400,
    XIG_EVENT_Button4Motion        = 0x00000800,
    XIG_EVENT_Button5Motion        = 0x00001000,
    XIG_EVENT_ButtonMotion         = 0x00002000,
    XIG_EVENT_KeymapState          = 0x00004000,
    XIG_EVENT_Exposure             = 0x00008000,
    XIG_EVENT_VisibilityChange     = 0x00010000,
    XIG_EVENT_StructureNotify      = 0x00020000,
    XIG_EVENT_ResizeRedirect       = 0x00040000,
    XIG_EVENT_SubstructureNotify   = 0x00080000,
    XIG_EVENT_SubstructureRedirect = 0x00100000,
    XIG_EVENT_FocusChange          = 0x00200000,
    XIG_EVENT_PropertyChange       = 0x00400000,
    XIG_EVENT_ColormapChange       = 0x00800000,
    XIG_EVENT_OwnerGrabButton      = 0x01000000
} XigEvent;

enum
{
    XIG_GC_VALUE_MASK_function              = 0x00000001,
    XIG_GC_VALUE_MASK_plane_mask            = 0x00000002,
    XIG_GC_VALUE_MASK_foreground            = 0x00000004,
    XIG_GC_VALUE_MASK_background            = 0x00000008,
    XIG_GC_VALUE_MASK_line_width            = 0x00000010,
    XIG_GC_VALUE_MASK_line_style            = 0x00000020,
    XIG_GC_VALUE_MASK_cap_style             = 0x00000040,
    XIG_GC_VALUE_MASK_join_style            = 0x00000080,
    XIG_GC_VALUE_MASK_fill_style            = 0x00000100,
    XIG_GC_VALUE_MASK_fill_rule             = 0x00000200,
    XIG_GC_VALUE_MASK_tile                  = 0x00000400,
    XIG_GC_VALUE_MASK_stipple               = 0x00000800,
    XIG_GC_VALUE_MASK_tile_stipple_x_origin = 0x00001000,
    XIG_GC_VALUE_MASK_tile_stipple_y_origin = 0x00002000,
    XIG_GC_VALUE_MASK_font                  = 0x00004000,
    XIG_GC_VALUE_MASK_subwindow_mode        = 0x00008000,
    XIG_GC_VALUE_MASK_graphics_exposures    = 0x00010000,
    XIG_GC_VALUE_MASK_clip_x_origin         = 0x00020000,
    XIG_GC_VALUE_MASK_clip_y_origin         = 0x00040000,
    XIG_GC_VALUE_MASK_clip_mask             = 0x00080000,
    XIG_GC_VALUE_MASK_dash_offset           = 0x00100000,
    XIG_GC_VALUE_MASK_dashes                = 0x00200000,
    XIG_GC_VALUE_MASK_arc_mode              = 0x00400000
} XigGCValueMask;

typedef enum
{
    XIG_WINDOW_VALUE_MASK_background_pixmap     = 0x00000001,
    XIG_WINDOW_VALUE_MASK_background_pixel      = 0x00000002,
    XIG_WINDOW_VALUE_MASK_border_pixmap         = 0x00000004,
    XIG_WINDOW_VALUE_MASK_border_pixel          = 0x00000008,
    XIG_WINDOW_VALUE_MASK_bit_gravity           = 0x00000010,
    XIG_WINDOW_VALUE_MASK_win_gravity           = 0x00000020,
    XIG_WINDOW_VALUE_MASK_backing_store         = 0x00000040,
    XIG_WINDOW_VALUE_MASK_backing_planes        = 0x00000080,
    XIG_WINDOW_VALUE_MASK_backing_pixel         = 0x00000100,
    XIG_WINDOW_VALUE_MASK_override_redirect     = 0x00000200,
    XIG_WINDOW_VALUE_MASK_save_under            = 0x00000400,
    XIG_WINDOW_VALUE_MASK_event_mask            = 0x00000800,
    XIG_WINDOW_VALUE_MASK_do_not_propagate_mask = 0x00001000,
    XIG_WINDOW_VALUE_MASK_colormap              = 0x00002000,
    XIG_WINDOW_VALUE_MASK_cursor                = 0x00004000
} XigCreateWindowValueMask;

typedef enum
{
    XIG_CONFIGURE_WINDOW_VALUE_MASK_x            = 0x0001,
    XIG_CONFIGURE_WINDOW_VALUE_MASK_y            = 0x0002,
    XIG_CONFIGURE_WINDOW_VALUE_MASK_width        = 0x0004,
    XIG_CONFIGURE_WINDOW_VALUE_MASK_height       = 0x0008,
    XIG_CONFIGURE_WINDOW_VALUE_MASK_border_width = 0x0010,
    XIG_CONFIGURE_WINDOW_VALUE_MASK_sibling      = 0x0020,
    XIG_CONFIGURE_WINDOW_VALUE_MASK_stack_mode   = 0x0040
} XigConfigureWindowValueMask;

typedef enum
{
    XIG_CIRCULATE_DIRECTION_RAISE_LOWEST = 0,
    XIG_CIRCULATE_DIRECTION_LOWER_HIGHEST = 1
} XigCirculateDirection;

typedef enum
{
    XIG_CIRCULATE_PLACE_TOP = 0,
    XIG_CIRCULATE_PLACE_BOTTOM = 1
} XigCirculatePlace;

typedef enum
{
    XIG_WINDOW_ID_NONE         = 0,
    XIG_WINDOW_ID_POINTER_ROOT = 1
} XigWindowId;

typedef enum
{
    XIG_PIXMAP_ID_NONE            = 0,
    XIG_PIXMAP_ID_PARENT_RELATIVE = 1
} XigPixmapId;

typedef struct
{
    guint8 byte_order;
    guint16 protocol_major_version;
    guint16 protocol_minor_version;
    gchar *authorization_protocol_name;
    guint8 *authorization_protocol_data;
    gsize authorization_protocol_data_length;
} XigConnect;

typedef struct
{
    guint16 protocol_major_version;
    guint16 protocol_minor_version;
    gchar *reason;
} XigFailed;

typedef struct
{
    gchar *reason;
} XigAuthenticate;

typedef struct
{
    guint8 byte1;
    guint8 byte2;
} XigCHAR2B;

typedef struct
{
    gint16 x;
    gint16 y;
} XigPOINT;

typedef struct
{
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
} XigRECTANGLE;

typedef struct
{
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    gint16 angle1;
    gint16 angle2;
} XigARC;

typedef struct
{
    guint8 depth;
    guint8 bits_per_pixel;
    guint8 scanline_pad;
} XigFORMAT;

typedef struct
{
    guint32 visual_id;
    guint8 class;
    guint8 bits_per_rgb_value;
    guint16 colormap_entries;
    guint32 red_mask;
    guint32 green_mask;
    guint32 blue_mask;
} XigVISUALTYPE;

typedef struct
{
    guint8 depth;
    XigVISUALTYPE *visuals;
    gsize visuals_length;
} XigDEPTH;

typedef struct
{
    guint32 root;
    guint32 default_colormap;
    guint32 white_pixel;
    guint32 black_pixel;
    guint32 current_input_masks;
    guint16 width_in_pixels;
    guint16 height_in_pixels;
    guint16 width_in_millimeters;
    guint16 height_in_millimeters;
    guint16 min_installed_maps;
    guint16 max_installed_maps;
    guint32 root_visual;
    guint8 backing_stores;
    gboolean save_unders;
    guint8 root_depth;
    XigDEPTH *allowed_depths;
    gsize allowed_depths_length;
} XigSCREEN;

typedef struct
{
    guint16 protocol_major_version;
    guint16 protocol_minor_version;
    guint32 release_number;
    guint32 resource_id_base;
    guint32 resource_id_mask;
    guint32 motion_buffer_size;
    guint16 maximum_request_length;
    guint8 image_byte_order;
    guint8 bitmap_format_bit_order;
    guint8 bitmap_format_scanline_unit;
    guint8 bitmap_format_scanline_pad;
    guint8 min_keycode;
    guint8 max_keycode;
    gchar *vendor;
    XigFORMAT *pixmap_formats;
    gsize pixmap_formats_length;
    XigSCREEN *screens;
    gsize screens_length;
} XigSuccess;

// FIXME: Handle different error types
typedef struct
{
    guint16 sequence_number;
    guint8 type;
    guint32 data;
    guint16 major_opcode;
    guint16 minor_opcode;
} XigError;

typedef struct
{
    guint16 sequence_number;
    guint8 detail;
    guint32 time;
    guint32 root;
    guint32 event;
    guint32 child;
    gint16 root_x;
    gint16 root_y;
    gint16 event_x;
    gint16 event_y;
    guint16 state;
    gboolean same_screen;
} XigKeyPress;

typedef struct
{
    guint16 sequence_number;
    guint8 detail;
    guint32 time;
    guint32 root;
    guint32 event;
    guint32 child;
    gint16 root_x;
    gint16 root_y;
    gint16 event_x;
    gint16 event_y;
    guint16 state;
    gboolean same_screen;
} XigButtonPress;

typedef struct
{
    guint16 sequence_number;
    guint8 detail;
    guint32 time;
    guint32 root;
    guint32 event;
    guint32 child;
    gint16 root_x;
    gint16 root_y;
    gint16 event_x;
    gint16 event_y;
    guint16 state;
    gboolean same_screen;
} XigMotionNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 detail;
    guint32 time;
    guint32 root;
    guint32 event;
    guint32 child;
    gint16 root_x;
    gint16 root_y;
    gint16 event_x;
    gint16 event_y;
    guint16 state;
    guint8 mode;
    guint8 same_screen_focus;
} XigEnterNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 detail;
    guint32 event;
    guint8 mode;
} XigFocusIn;

typedef struct
{
    guint16 sequence_number;
    guint8 keys[31];
} XigKeymapNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint16 x;
    guint16 y;
    guint16 width;
    guint16 height;
    guint16 count;
} XigExpose;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint16 x;
    guint16 y;
    guint16 width;
    guint16 height;
    guint16 minor_opcode;
    guint16 count;
    guint8 major_opcode;
} XigGraphicsExposure;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint16 minor_opcode;
    guint8 major_opcode;
} XigNoExposure;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint8 state;
} XigVisibilityNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 parent;
    guint32 window;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint16 border_width;
    gboolean override_redirect;
} XigCreateNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
} XigDestroyNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
    gboolean from_configure;
} XigUnmapNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
    gboolean override_redirect;
} XigMapNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 parent;
    guint32 window;
} XigMapRequest;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
    guint32 parent;
    gint16 x;
    gint16 y;
    gboolean override_redirect;
} XigReparentNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
    guint32 above_sibling;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint16 border_width;
    gboolean override_redirect;
} XigConfigureNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 stack_mode;
    guint32 parent;
    guint32 window;
    guint32 sibling;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint16 border_width;
    guint16 value_mask;
} XigConfigureRequest;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
    gint16 x;
    gint16 y;
} XigGravityNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint16 width;
    guint16 height;
} XigResizeRequest;

typedef struct
{
    guint16 sequence_number;
    guint32 event;
    guint32 window;
    guint8 place;
} XigCirculateNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 parent;
    guint32 window;
    guint8 place;
} XigCirculateRequest;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 atom;
    guint32 time;
    guint8 state;
} XigPropertyNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint32 owner;
    guint32 selection;
} XigSelectionClear;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint32 owner;
    guint32 requestor;
    guint32 selection;
    guint32 target;
    guint32 property;
} XigSelectionRequest;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint32 requestor;
    guint32 selection;
    guint32 target;
    guint32 property;
} XigSelectionNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 colormap;
    gboolean new;
    guint8 state;
} XigColormapNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 format;
    guint32 window;
    guint32 type;
    guint8 data[20];
} XigClientMessage;

typedef struct
{
    guint16 sequence_number;
    guint8 request;
    guint8 first_keycode;
    guint8 count;
} XigMappingNotify;

#define XIG_WINDOW_CLASS_CopyFromParent 0
typedef struct
{
    guint16 sequence_number;
    guint8 depth;
    guint32 wid;
    guint32 parent;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint16 border_width;
    guint16 class;
    guint32 visual;
    guint32 value_mask;
    guint32 background_pixmap;
    guint32 background_pixel;
    guint32 border_pixmap;
    guint32 border_pixel;
    guint8 bit_gravity;
    guint8 win_gravity;
    guint8 backing_store;
    guint32 backing_planes;
    guint32 backing_pixel;
    gboolean override_redirect;
    gboolean save_under;
    guint32 event_mask;
    guint32 do_not_propagate_mask;
    guint32 colormap;
    guint32 cursor;
} XigCreateWindow;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 value_mask;
    guint32 background_pixmap;
    guint32 background_pixel;
    guint32 border_pixmap;
    guint32 border_pixel;
    guint8 bit_gravity;
    guint8 win_gravity;
    guint8 backing_store;
    guint32 backing_planes;
    guint32 backing_pixel;
    gboolean override_redirect;
    gboolean save_under;
    guint32 event_mask;
    guint32 do_not_propagate_mask;
    guint32 colormap;
    guint32 cursor;
} XigChangeWindowAttributes;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigGetWindowAttributes;

typedef struct
{
    guint16 sequence_number;
    guint8 backing_store;
    guint32 visual;
    guint16 class;
    guint8 bit_gravity;
    guint8 win_gravity;
    guint32 backing_planes;
    guint32 backing_pixel;
    gboolean save_under;
    gboolean map_is_installed;
    guint8 map_state;
    gboolean override_redirect;
    guint32 colormap;
    guint32 all_event_masks;
    guint32 your_event_mask;
    guint16 do_not_propagate_mask;
} XigGetWindowAttributesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigDestroyWindow;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigDestroySubwindows;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
    guint32 window;
} XigChangeSaveSet;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 parent;
    gint16 x;
    gint16 y;
} XigReparentWindow;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigMapWindow;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigMapSubwindows;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigUnmapWindow;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigUnmapSubwindows;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint16 value_mask;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint16 border_width;
    guint32 sibling;
    guint8 stack_mode;
} XigConfigureWindow;

typedef struct
{
    guint16 sequence_number;
    guint8 direction;
    guint32 window;
} XigCirculateWindow;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
} XigGetGeometry;

typedef struct
{
    guint16 sequence_number;
    guint8 depth;
    guint32 root;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint16 border_width;
} XigGetGeometryReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigQueryTree;

typedef struct
{
    guint16 sequence_number;
    guint32 root;
    guint32 parent;
    guint32 *children;
    gsize children_length;
} XigQueryTreeReply;

typedef struct
{
    guint16 sequence_number;
    gboolean only_if_exists;
    gchar *name;
} XigInternAtom;

typedef struct
{
    guint16 sequence_number;
    guint32 atom;
} XigInternAtomReply;

typedef struct
{
    guint16 sequence_number;
    guint32 atom;
} XigGetAtomName;

typedef struct
{
    guint16 sequence_number;
    gchar *name;
} XigGetAtomNameReply;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
    guint32 window;
    guint32 property;
    guint32 type;
    guint8 data_format;
    void *data;
    gsize data_length;
} XigChangeProperty;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 property;
} XigDeleteProperty;

typedef struct
{
    guint16 sequence_number;
    gboolean delete;
    guint32 window;
    guint32 property;
    guint32 type;
    guint32 long_offset;
    guint32 long_length;
} XigGetProperty;

typedef struct
{
    guint16 sequence_number;
    guint32 type;
    guint32 bytes_after;
    guint8 value_format;
    void *value;
    gsize value_length;
} XigGetPropertyReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigListProperties;

typedef struct
{
    guint16 sequence_number;
    guint32 *atoms;
    gsize atoms_length;
} XigListPropertiesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 owner;
    guint32 selection;
    guint32 time;
} XigSetSelectionOwner;

typedef struct
{
    guint16 sequence_number;
    guint32 selection;
} XigGetSelectionOwner;

typedef struct
{
    guint16 sequence_number;
    guint32 owner;
} XigGetSelectionOwnerReply;

typedef struct
{
    guint16 sequence_number;
    guint32 requestor;
    guint32 selection;
    guint32 target;
    guint32 property;
    guint32 time;
} XigConvertSelection;

typedef struct
{
    guint16 sequence_number;
    gboolean propagate;
    guint32 destination;
    guint32 event_mask;
    // FIXME: event
} XigSendEvent;

typedef struct
{
    guint16 sequence_number;
    gboolean owner_events;
    guint32 grab_window;
    guint16 event_mask;
    guint8 pointer_mode;
    guint8 keyboard_mode;
    guint32 confine_to;
    guint32 cursor;
    guint32 time;
} XigGrabPointer;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
} XigGrabPointerReply;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
} XigUngrabPointer;

typedef struct
{
    guint16 sequence_number;
    gboolean owner_events;
    guint32 grab_window;
    guint16 event_mask;
    guint8 pointer_mode;
    guint8 keyboard_mode;
    guint32 confine_to;
    guint32 cursor;
    guint8 button;
    guint16 modifiers;
} XigGrabButton;

typedef struct
{
    guint16 sequence_number;
    guint8 button;
    guint32 grab_window;
    guint16 modifiers;
} XigUngrabButton;

typedef struct
{
    guint16 sequence_number;
    guint32 cursor;
    guint32 time;
    guint16 event_mask;
} XigChangeActivePointerGrab;

typedef struct
{
    guint16 sequence_number;
    gboolean owner_events;
    guint32 grab_window;
    guint32 time;
    guint8 pointer_mode;
    guint8 keyboard_mode;
} XigGrabKeyboard;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
} XigGrabKeyboardReply;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
} XigUngrabKeyboard;

typedef struct
{
    guint16 sequence_number;
    gboolean owner_events;
    guint32 grab_window;
    guint16 modifiers;
    guint8 key;
    guint8 pointer_mode;
    guint8 keyboard_mode;
} XigGrabKey;

typedef struct
{
    guint16 sequence_number;
    guint8 key;
    guint32 grab_window;
    guint16 modifiers;
} XigUngrabKey;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
    guint32 time;
} XigAllowEvents;

typedef struct
{
    guint16 sequence_number;
} XigGrabServer;

typedef struct
{
    guint16 sequence_number;
} XigUngrabServer;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigQueryPointer;

typedef struct
{
    guint16 sequence_number;
    gboolean same_screen;
    guint32 root;
    guint32 child;
    gint16 root_x;
    gint16 root_y;
    gint16 win_x;
    gint16 win_y;
    guint16 mask;
} XigQueryPointerReply;

typedef struct
{
    guint32 time;
    gint16 x;
    gint16 y;
} XigTIMECOORD;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 start;
    guint32 stop;
} XigGetMotionEvents;

typedef struct
{
    guint16 sequence_number;
    XigTIMECOORD *events;
    gsize events_length;
} XigGetMotionEventsReply;

typedef struct
{
    guint16 sequence_number;
    guint32 src_window;
    guint32 dst_window;
    gint16 src_x;
    gint16 src_y;
} XigTranslateCoordinates;

typedef struct
{
    guint16 sequence_number;
    gboolean same_screen;
    guint32 child;
    gint16 dst_x;
    gint16 dst_y;
} XigTranslateCoordinatesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 src_window;
    guint32 dst_window;
    gint16 src_x;
    gint16 src_y;
    guint16 src_width;
    guint16 src_height;
    gint16 dst_x;
    gint16 dst_y;
} XigWarpPointer;

typedef struct
{
    guint16 sequence_number;
    guint8 revert_to;
    guint32 focus;
    guint32 time;
} XigSetInputFocus;

typedef struct
{
    guint16 sequence_number;
} XigGetInputFocus;

typedef struct
{
    guint16 sequence_number;
    guint8 revert_to;
    guint32 focus;
} XigGetInputFocusReply;

typedef struct
{
    guint16 sequence_number;
} XigQueryKeymap;

typedef struct
{
    guint16 sequence_number;
    guint8 keys[32];
} XigQueryKeymapReply;

typedef struct
{
    guint16 sequence_number;
    guint32 fid;
    gchar *name;
} XigOpenFont;

typedef struct
{
    guint16 sequence_number;
    guint32 font;
} XigCloseFont;

typedef struct
{
    guint32 name;
    guint32 value;
} XigFONTPROP;

typedef struct
{
    gint16 left_side_bearing;
    gint16 right_side_bearing;
    gint16 character_width;
    gint16 ascent;
    gint16 descent;
    guint16 attributes;
} XigCHARINFO;

typedef struct
{
    guint16 sequence_number;
    guint32 font;
} XigQueryFont;

typedef struct
{
    guint16 sequence_number;
    XigCHARINFO min_bounds;
    XigCHARINFO max_bounds;
    guint16 min_char_or_byte2;
    guint16 max_char_or_byte2;
    guint16 default_char;
    guint8 draw_direction;
    guint8 min_byte1;
    guint8 max_byte1;
    gboolean all_chars_exist;
    gint16 font_ascent;
    gint16 font_descent;
    XigFONTPROP *properties;
    gsize properties_length;
    XigCHARINFO *char_infos;
    gsize char_infos_length;
} XigQueryFontReply;

typedef struct
{
    guint16 sequence_number;
    guint32 font;
    guint16 *string;
    gsize string_length;
} XigQueryTextExtents;

typedef struct
{
    guint16 sequence_number;
    guint8 draw_direction;
    gint16 font_ascent;
    gint16 font_descent;
    gint16 overall_ascent;
    gint16 overall_descent;
    gint32 overall_width;
    gint32 overall_left;
    gint32 overall_right;
} XigQueryTextExtentsReply;

typedef struct
{
    guint16 sequence_number;
    guint16 max_names;
    gchar *pattern;
} XigListFonts;

typedef struct
{
    guint16 sequence_number;
    gchar **names;
} XigListFontsReply;

typedef struct
{
    guint16 sequence_number;
    guint16 max_names;
    gchar *pattern;
} XigListFontsWithInfo;

typedef struct
{
    guint16 sequence_number;
    XigCHARINFO min_bounds;
    XigCHARINFO max_bounds;
    guint16 min_char_or_byte2;
    guint16 max_char_or_byte2;
    guint16 default_char;
    guint8 draw_direction;
    guint8 min_byte1;
    guint8 max_byte1;
    gboolean all_chars_exist;
    gint16 font_ascent;
    gint16 font_descent;
    guint32 replies_hint;
    XigFONTPROP *properties;
    gsize properties_length;
    gchar *name;
} XigListFontsWithInfoReply;

typedef struct
{
    guint16 sequence_number;
    gchar **path;
} XigSetFontPath;

typedef struct
{
    guint16 sequence_number;
} XigGetFontPath;

typedef struct
{
    guint16 sequence_number;
    gchar **path;
} XigGetFontPathReply;

typedef struct
{
    guint16 sequence_number;
    guint8 depth;
    guint32 pid;
    guint32 drawable;
    guint16 width;
    guint16 height;
} XigCreatePixmap;

typedef struct
{
    guint16 sequence_number;
    guint32 pixmap;
} XigFreePixmap;

typedef struct
{
    guint16 sequence_number;
    guint32 cid;
    guint32 drawable;
    guint32 value_mask;
    guint8 function;
    guint32 plane_mask;
    guint32 foreground;
    guint32 background;
    guint16 line_width;
    guint8 line_style;
    guint8 cap_style;
    guint8 join_style;
    guint8 fill_style;
    guint8 fill_rule;
    guint32 tile;
    guint32 stipple;
    guint16 tile_stipple_x_origin;
    guint16 tile_stipple_y_origin;
    guint32 font;
    guint8 subwindow_mode;
    gboolean graphics_exposures;
    guint16 clip_x_origin;
    guint16 clip_y_origin;
    guint32 clip_mask;
    guint16 dash_offset;
    guint8 dashes;
    guint8 arc_mode;
} XigCreateGC;

typedef struct
{
    guint16 sequence_number;
    guint32 gc;
    guint32 value_mask;
    guint8 function;
    guint32 plane_mask;
    guint32 foreground;
    guint32 background;
    guint16 line_width;
    guint8 line_style;
    guint8 cap_style;
    guint8 join_style;
    guint8 fill_style;
    guint8 fill_rule;
    guint32 tile;
    guint32 stipple;
    guint16 tile_stipple_x_origin;
    guint16 tile_stipple_y_origin;
    guint32 font;
    guint8 subwindow_mode;
    gboolean graphics_exposures;
    guint16 clip_x_origin;
    guint16 clip_y_origin;
    guint32 clip_mask;
    guint16 dash_offset;
    guint8 dashes;
    guint8 arc_mode;
} XigChangeGC;

typedef struct
{
    guint16 sequence_number;
    guint32 src_gc;
    guint32 dst_gc;
    guint32 value_mask;
    guint8 function;
    guint32 plane_mask;
    guint32 foreground;
    guint32 background;
    guint16 line_width;
    guint8 line_style;
    guint8 cap_style;
    guint8 join_style;
    guint8 fill_style;
    guint8 fill_rule;
    guint32 tile;
    guint32 stipple;
    guint16 tile_stipple_x_origin;
    guint16 tile_stipple_y_origin;
    guint32 font;
    guint8 subwindow_mode;
    gboolean graphics_exposures;
    guint16 clip_x_origin;
    guint16 clip_y_origin;
    guint32 clip_mask;
    guint16 dash_offset;
    guint8 dashes;
    guint8 arc_mode;
} XigCopyGC;

typedef struct
{
    guint16 sequence_number;
    guint32 gc;
    guint16 dash_offset;
    guint8 *dashes;
    gsize dashes_length;
} XigSetDashes;

typedef struct
{
    guint16 sequence_number;
    guint8 ordering;
    guint32 gc;
    gint16 clip_x_origin;
    gint16 clip_y_origin;
    XigRECTANGLE *rectangles;
    gsize rectangles_length;
} XigSetClipRectangles;

typedef struct
{
    guint16 sequence_number;
    guint32 gc;
} XigFreeGC;

typedef struct
{
    guint16 sequence_number;
    gboolean exposures;
    guint32 window;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
} XigClearArea;

typedef struct
{
    guint16 sequence_number;
    guint32 src_drawable;
    guint32 dst_drawable;
    guint32 gc;
    gint16 src_x;
    gint16 src_y;
    gint16 dst_x;
    gint16 dst_y;
    guint16 width;
    guint16 height;
} XigCopyArea;

typedef struct
{
    guint16 sequence_number;
    guint32 src_drawable;
    guint32 dst_drawable;
    guint32 gc;
    gint16 src_x;
    gint16 src_y;
    gint16 dst_x;
    gint16 dst_y;
    guint16 width;
    guint16 height;
    guint32 bit_plane;
} XigCopyPlane;

typedef struct
{
    guint16 sequence_number;
    guint8 coordinate_mode;
    guint32 drawable;
    guint32 gc;
    XigPOINT *points;
    gsize points_length;
} XigPolyPoint;

typedef struct
{
    guint16 sequence_number;
    guint8 coordinate_mode;
    guint32 drawable;
    guint32 gc;
    XigPOINT *points;
    gsize points_length;
} XigPolyLine;

typedef struct
{
    gint16 x1;
    gint16 y1;
    gint16 x2;
    gint16 y2;
} XigSEGMENT;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    XigSEGMENT *segments;
    gsize segments_length;
} XigPolySegment;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    XigRECTANGLE *rectangles;
    gsize rectangles_length;
} XigPolyRectangle;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    XigARC *arcs;
    gsize arcs_length;
} XigPolyArc;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    guint8 shape;
    guint8 coordinate_mode;
    XigPOINT *points;
    gsize points_length;
} XigFillPoly;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    XigRECTANGLE *rectangles;
    gsize rectangles_length;
} XigPolyFillRectangle;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    XigARC *arcs;
    gsize arcs_length;
} XigPolyFillArc;

typedef struct
{
    guint16 sequence_number;
    guint8 format;
    guint32 drawable;
    guint32 gc;
    guint16 width;
    guint16 height;
    gint16 dst_x;
    gint16 dst_y;
    guint8 left_pad;
    guint8 depth;
    guint8 *data;
    gsize data_length;
} XigPutImage;

typedef struct
{
    guint16 sequence_number;
    guint8 format;
    guint32 drawable;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint32 plane_mask;
    const guint8 *data;
    gsize data_length;
} XigGetImage;

typedef struct
{
    guint16 sequence_number;
    guint8 depth;
    guint32 visual;
    guint8 *data;
    gsize data_length;
} XigGetImageReply;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    gint16 x;
    gint16 y;
    guint8 *items;
    gsize items_length;
} XigPolyText8;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    gint16 x;
    gint16 y;
    guint8 *items;
    gsize items_length;
} XigPolyText16;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    gint16 x;
    gint16 y;
    gchar *string;
} XigImageText8;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 gc;
    gint16 x;
    gint16 y;
    guint16 *string;
    gsize string_length;
} XigImageText16;

typedef struct
{
    guint16 sequence_number;
    guint8 alloc;
    guint32 mid;
    guint32 window;
    guint32 visual;
} XigCreateColormap;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
} XigFreeColormap;

typedef struct
{
    guint16 sequence_number;
    guint32 mid;
    guint32 src_cmap;
} XigCopyColormapAndFree;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
} XigInstallColormap;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
} XigUninstallColormap;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigListInstalledColormaps;

typedef struct
{
    guint16 sequence_number;
    guint32 *cmaps;
    gsize cmaps_length;
} XigListInstalledColormapsReply;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
    guint16 red;
    guint16 green;
    guint16 blue;
} XigAllocColor;

typedef struct
{
    guint16 sequence_number;
    guint16 red;
    guint16 green;
    guint16 blue;
    guint32 pixel;
} XigAllocColorReply;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
    gchar *name;
} XigAllocNamedColor;

typedef struct
{
    guint16 sequence_number;
    guint32 pixel;
    guint16 exact_red;
    guint16 exact_green;
    guint16 exact_blue;
    guint16 visual_red;
    guint16 visual_green;
    guint16 visual_blue;
} XigAllocNamedColorReply;

typedef struct
{
    guint16 sequence_number;
    gboolean contiguous;
    guint32 cmap;
    guint16 colors;
    guint16 planes;
} XigAllocColorCells;

typedef struct
{
    guint16 sequence_number;
    guint32 *pixels;
    gsize pixels_length;
    guint32 *masks;
    gsize masks_length;
} XigAllocColorCellsReply;

typedef struct
{
    guint16 sequence_number;
    gboolean contiguous;
    guint32 cmap;
    guint16 colors;
    guint16 reds;
    guint16 greens;
    guint16 blues;
} XigAllocColorPlanes;

typedef struct
{
    guint16 sequence_number;
    guint32 red_mask;
    guint32 green_mask;
    guint32 blue_mask;
    guint32 *pixels;
    gsize pixels_length;
} XigAllocColorPlanesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
    guint32 plane_mask;
    guint32 *pixels;
    gsize pixels_length;
} XigFreeColors;

typedef struct
{
    guint32 pixel;
    guint16 red;
    guint16 green;
    guint16 blue;
    gboolean do_red;
    gboolean do_green;
    gboolean do_blue; 
} XigCOLORITEM;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
    XigCOLORITEM *items;
    gsize items_length;
} XigStoreColors;

typedef struct
{
    guint16 sequence_number;
    gboolean do_red;
    gboolean do_green;
    gboolean do_blue;
    guint32 cmap;
    guint32 pixel;
    gchar *name;
} XigStoreNamedColor;

typedef struct
{
    guint16 red;
    guint16 green;
    guint16 blue;
} XigRGB;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
    guint32 *pixels;
    gsize pixels_length;
} XigQueryColors;

typedef struct
{
    guint16 sequence_number;
    XigRGB *colors;
    gsize colors_length;
} XigQueryColorsReply;

typedef struct
{
    guint16 sequence_number;
    guint32 cmap;
    gchar *name;
} XigLookupColor;

typedef struct
{
    guint16 sequence_number;
    guint16 exact_red;
    guint16 exact_green;
    guint16 exact_blue;
    guint16 visual_red;
    guint16 visual_green;
    guint16 visual_blue;
} XigLookupColorReply;

typedef struct
{
    guint16 sequence_number;
    guint32 cid;
    guint32 source;
    guint32 mask;
    guint16 fore_red;
    guint16 fore_green;
    guint16 fore_blue;
    guint16 back_red;
    guint16 back_green;
    guint16 back_blue;
    guint16 x;
    guint16 y;
} XigCreateCursor;

typedef struct
{
    guint16 sequence_number;
    guint32 cid;
    guint32 source_font;
    guint32 mask_font;
    guint16 source_char;
    guint16 mask_char;
    guint16 fore_red;
    guint16 fore_green;
    guint16 fore_blue;
    guint16 back_red;
    guint16 back_green;
    guint16 back_blue;
} XigCreateGlyphCursor;

typedef struct
{
    guint16 sequence_number;
    guint32 cursor;
} XigFreeCursor;

typedef struct
{
    guint16 sequence_number;
    guint32 cursor;
    guint16 fore_red;
    guint16 fore_green;
    guint16 fore_blue;
    guint16 back_red;
    guint16 back_green;
    guint16 back_blue;
} XigRecolorCursor;

typedef struct
{
    guint16 sequence_number;
    guint8 class;
    guint32 drawable;
    guint16 width;
    guint16 height;
} XigQueryBestSize;

typedef struct
{
    guint16 sequence_number;
    guint16 width;
    guint16 height;
} XigQueryBestSizeReply;

typedef struct
{
    guint16 sequence_number;
    gchar *name;
} XigQueryExtension;

typedef struct
{
    guint16 sequence_number;
    gboolean present;
    guint8 major_opcode;
    guint8 first_event;
    guint8 first_error;
} XigQueryExtensionReply;

typedef struct
{
    guint16 sequence_number;
} XigListExtensions;

typedef struct
{
    guint16 sequence_number;
    gchar **names;
} XigListExtensionsReply;

typedef struct
{
    guint16 sequence_number;
    guint8 keycode_count;
    guint8 first_keycode;
    guint8 keysyms_per_keycode;
    guint32 *keysyms;
    gsize keysyms_length;
} XigChangeKeyboardMapping;

typedef struct
{
    guint16 sequence_number;
    guint8 first_keycode;
    guint8 count;
} XigGetKeyboardMapping;

typedef struct
{
    guint16 sequence_number;
    guint8 keysyms_per_keycode;
    guint32 *keysyms;
    gsize keysyms_length;
} XigGetKeyboardMappingReply;

typedef enum
{
    XIG_KEYBOARD_CONTROL_key_click_percent = 0x0001,
    XIG_KEYBOARD_CONTROL_bell_percent      = 0x0002,
    XIG_KEYBOARD_CONTROL_bell_pitch        = 0x0004,
    XIG_KEYBOARD_CONTROL_bell_duration     = 0x0008,
    XIG_KEYBOARD_CONTROL_led               = 0x0010,
    XIG_KEYBOARD_CONTROL_led_mode          = 0x0020,
    XIG_KEYBOARD_CONTROL_key               = 0x0040,
    XIG_KEYBOARD_CONTROL_auto_repeat_mode  = 0x0080,
} XigKeyboardControlMask;

typedef struct
{
    guint16 sequence_number;
    guint16 value_mask;
    guint8 key_click_percent;
    guint8 bell_percent;
    guint16 bell_pitch;
    guint16 bell_duration;
    guint8 led;
    guint8 led_mode;
    guint8 key;
    guint8 auto_repeat_mode;
} XigChangeKeyboardControl;

typedef struct
{
    guint16 sequence_number;
} XigGetKeyboardControl;

typedef struct
{
    guint16 sequence_number;
    guint8 global_auto_repeat;
    guint32 led_mask;
    guint8 key_click_percent;
    guint8 bell_percent;
    guint16 bell_pitch;
    guint16 bell_duration;
    guint8 auto_repeats[32];
} XigGetKeyboardControlReply;

typedef struct
{
    guint16 sequence_number;
    gint8 percent;
} XigBell;

typedef struct
{
    guint16 sequence_number;
    gint16 acceleration_numerator;
    gint16 acceleration_denominator;
    gint16 threshold;
    gboolean do_acceleration;
    gboolean do_threshold;
} XigChangePointerControl;

typedef struct
{
    guint16 sequence_number;
} XigGetPointerControl;

typedef struct
{
    guint16 sequence_number;
    gint16 acceleration_numerator;
    gint16 acceleration_denominator;
    gint16 threshold;
    gboolean do_acceleration;
    gboolean do_threshold;
} XigGetPointerControlReply;

typedef struct
{
    guint16 sequence_number;
    gint16 timeout;
    gint16 interval;
    guint8 prefer_blanking;
    guint8 allow_exposures;
} XigSetScreenSaver;

typedef struct
{
    guint16 sequence_number;
} XigGetScreenSaver;

typedef struct
{
    guint16 sequence_number;
    gint16 timeout;
    gint16 interval;
    guint8 prefer_blanking;
    guint8 allow_exposures;
} XigGetScreenSaverReply;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
    guint8 family;
    guint8 *address;
    gsize address_length;
} XigChangeHosts;

typedef struct
{
    guint8 family;
    guint8 *address;
    gsize address_length;
} XigHOST;

typedef struct
{
    guint16 sequence_number;
} XigListHosts;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
    XigHOST *hosts;
    gsize hosts_length;
} XigListHostsReply;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
} XigSetAccessControl;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
} XigSetCloseDownMode;

typedef struct
{
    guint16 sequence_number;
    guint32 resource;
} XigKillClient;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    gint16 delta;
    guint32 *properties;
    gsize properties_length;
} XigRotateProperties;

typedef struct
{
    guint16 sequence_number;
    guint8 mode;
} XigForceScreenSaver;

typedef struct
{
    guint16 sequence_number;
    guint8 *map;
    gsize map_length;
} XigSetPointerMapping;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
} XigSetPointerMappingReply;

typedef struct
{
    guint16 sequence_number;
} XigGetPointerMapping;

typedef struct
{
    guint16 sequence_number;
    guint8 *map;
    gsize map_length;
} XigGetPointerMappingReply;

typedef struct
{
    guint16 sequence_number;
    guint8 keycodes_per_modifier;
    guint8 *keycodes;
    gsize keycodes_length;
} XigSetModifierMapping;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
} XigSetModifierMappingReply;

typedef struct
{
    guint16 sequence_number;
} XigGetModifierMapping;

typedef struct
{
    guint16 sequence_number;
    guint8 keycodes_per_modifier;
    guint32 *keycodes;
    gsize keycodes_length;
} XigGetModifierMappingReply;

typedef struct
{
    guint16 sequence_number;
} XigNoOperation;

typedef struct
{
    guint16 sequence_number;
} XigBIGREQEnable;

typedef struct
{
    guint16 sequence_number;
    guint32 maximum_request_length;
} XigBIGREQEnableReply;

typedef struct
{
    gint32 hi;
    guint32 lo;
} XigINT64;

typedef struct
{
    guint16 sequence_number;
    guint8 kind;
    guint32 counter;
    XigINT64 wait_value;
    XigINT64 counter_value;
    guint32 timestamp;
    guint16 count;
    gboolean destroyed;
} XigSYNCCounterNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 kind;
    guint32 alarm;
    XigINT64 counter_value;
    XigINT64 alarm_value;
    guint32 timestamp;
    guint8 state;
} XigSYNCAlarmNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 desired_major_version;
    guint8 desired_minor_version;
} XigSYNCInitialize;

typedef struct
{
    guint16 sequence_number;
    guint8 major_version;
    guint8 minor_version;
} XigSYNCInitializeReply;

typedef struct
{
    guint16 sequence_number;
} XigSYNCListSystemCounters;

typedef struct
{
    guint16 sequence_number;
    guint32 counters_len;
} XigSYNCListSystemCountersReply;

typedef struct
{
    guint16 sequence_number;
    guint32 id;
    XigINT64 initial_value;
} XigSYNCCreateCounter;

typedef struct
{
    guint16 sequence_number;
    guint32 counter;
} XigSYNCDestroyCounter;

typedef struct
{
    guint16 sequence_number;
    guint32 counter;
} XigSYNCQueryCounter;

typedef struct
{
    guint16 sequence_number;
    XigINT64 counter_value;
} XigSYNCQueryCounterReply;

typedef struct
{
    guint16 sequence_number;
} XigSYNCAwait;

typedef struct
{
    guint16 sequence_number;
    guint32 counter;
    XigINT64 amount;
} XigSYNCChangeCounter;

typedef struct
{
    guint16 sequence_number;
    guint32 counter;
    XigINT64 value;
} XigSYNCSetCounter;

typedef struct
{
    guint16 sequence_number;
    guint32 id;
} XigSYNCCreateAlarm;

typedef struct
{
    guint16 sequence_number;
    guint32 id;
} XigSYNCChangeAlarm;

typedef struct
{
    guint16 sequence_number;
    guint32 alarm;
} XigSYNCDestroyAlarm;

typedef struct
{
    guint16 sequence_number;
    guint32 alarm;
} XigSYNCQueryAlarm;

typedef struct
{
    guint32 counter;
    guint32 wait_type;
    XigINT64 wait_value;
    guint32 test_type;
} XigTRIGGER;

typedef struct
{
    guint16 sequence_number;
    XigTRIGGER trigger;
    XigINT64 delta;
    gboolean events;
    guint8 state;
} XigSYNCQueryAlarmReply;

typedef struct
{
    guint16 sequence_number;
    guint32 id;
    gint32 priority;
} XigSYNCSetPriority;

typedef struct
{
    guint16 sequence_number;
    guint32 id;
} XigSYNCGetPriority;

typedef struct
{
    guint16 sequence_number;
    gint32 priority;
} XigSYNCGetPriorityReply;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
    guint32 fence;
    gboolean initially_triggered;
} XigSYNCCreateFence;

typedef struct
{
    guint16 sequence_number;
    guint32 fence;
} XigSYNCTriggerFence;

typedef struct
{
    guint16 sequence_number;
    guint32 fence;
} XigSYNCResetFence;

typedef struct
{
    guint16 sequence_number;
    guint32 fence;
} XigSYNCDestroyFence;

typedef struct
{
    guint16 sequence_number;
    guint32 fence;
} XigSYNCQueryFence;

typedef struct
{
    guint16 sequence_number;
    gboolean triggered;
} XigSYNCQueryFenceReply;

typedef struct
{
    guint16 sequence_number;
} XigSYNCAwaitFence;

typedef struct
{
    guint16 sequence_number;
    guint8 rotation;
    guint32 timestamp;
    guint32 config_timestamp;
    guint32 root;
    guint32 request_window;
    guint16 size_id;
    guint16 subpixel_order;
    guint16 width;
    guint16 height;
    guint16 mwidth;
    guint16 mheight;
} XigRANDRScreenChangeNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 sub_code;
    //FIXMENotifyData u;
} XigRANDRNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 major_version;
    guint32 minor_version;
} XigRANDRQueryVersion;

typedef struct
{
    guint16 sequence_number;
    guint32 major_version;
    guint32 minor_version;
} XigRANDRQueryVersionReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 timestamp;
    guint32 config_timestamp;
    guint16 size_id;
    guint16 rotation;
    guint16 rate;
} XigRANDRSetScreenConfig;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
    guint32 new_timestamp;
    guint32 config_timestamp;
    guint32 root;
    guint16 subpixel_order;
} XigRANDRSetScreenConfigReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint16 enable;
} XigRANDRSelectInput;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigRANDRGetScreenInfo;

typedef struct
{
    guint16 sequence_number;
    guint8 rotations;
    guint32 root;
    guint32 timestamp;
    guint32 config_timestamp;
    guint16 n_sizes;
    guint16 size_id;
    guint16 rotation;
    guint16 rate;
    guint16 n_info;
} XigRANDRGetScreenInfoReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigRANDRGetScreenSizeRange;

typedef struct
{
    guint16 sequence_number;
    guint16 min_width;
    guint16 min_height;
    guint16 max_width;
    guint16 max_height;
} XigRANDRGetScreenSizeRangeReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint16 width;
    guint16 height;
    guint32 mm_width;
    guint32 mm_height;
} XigRANDRSetScreenSize;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigRANDRGetScreenResources;

typedef struct
{
    guint32 id;
    guint16 width_in_pixels;
    guint16 height_in_pixels;
    guint32 dot_clock;
    guint16 h_sync_start;
    guint16 h_sync_end;
    guint16 h_total;
    guint16 h_skew;
    guint16 v_sync_start;
    guint16 v_sync_end;
    guint16 v_total;
    gchar *name;
    guint32 mode_flags;
} XigRANDRMODEINFO;

typedef struct
{
    guint16 sequence_number;
    guint32 timestamp;
    guint32 config_timestamp;
    guint32 *crtcs;
    gsize crtcs_length;
    guint32 *outputs;
    gsize outputs_length;
    XigRANDRMODEINFO *modes;
    gsize modes_length;
} XigRANDRGetScreenResourcesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 config_timestamp;
} XigRANDRGetOutputInfo;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
    guint32 timestamp;
    guint32 crtc;
    guint32 mm_width;
    guint32 mm_height;
    guint8 connection;
    guint8 subpixel_order;
    guint16 num_crtcs;
    guint16 num_modes;
    guint16 num_preferred;
    guint16 num_clones;
    guint16 name_len;
} XigRANDRGetOutputInfoReply;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
} XigRANDRListOutputProperties;

typedef struct
{
    guint16 sequence_number;
    guint16 num_atoms;
} XigRANDRListOutputPropertiesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 property;
} XigRANDRQueryOutputProperty;

typedef struct
{
    guint16 sequence_number;
    gboolean pending;
    gboolean range;
    gboolean immutable;
} XigRANDRQueryOutputPropertyReply;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 property;
    gboolean pending;
    gboolean range;
} XigRANDRConfigureOutputProperty;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 property;
    guint32 type;
    guint8 format;
    guint8 mode;
    guint32 num_units;
} XigRANDRChangeOutputProperty;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 property;
} XigRANDRDeleteOutputProperty;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 property;
    guint32 type;
    guint32 long_offset;
    guint32 long_length;
    gboolean delete;
    gboolean pending;
} XigRANDRGetOutputProperty;

typedef struct
{
    guint16 sequence_number;
    guint8 format;
    guint32 type;
    guint32 bytes_after;
    guint32 num_items;
} XigRANDRGetOutputPropertyReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    //FIXMEModeInfo mode_info;
} XigRANDRCreateMode;

typedef struct
{
    guint16 sequence_number;
    guint32 mode;
} XigRANDRCreateModeReply;

typedef struct
{
    guint16 sequence_number;
    guint32 mode;
} XigRANDRDestroyMode;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 mode;
} XigRANDRAddOutputMode;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
    guint32 mode;
} XigRANDRDeleteOutputMode;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
    guint32 config_timestamp;
} XigRANDRGetCrtcInfo;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
    guint32 timestamp;
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
    guint32 mode;
    guint16 rotation;
    guint16 rotations;
    guint16 num_outputs;
    guint16 num_possible_outputs;
} XigRANDRGetCrtcInfoReply;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
    guint32 timestamp;
    guint32 config_timestamp;
    gint16 x;
    gint16 y;
    guint32 mode;
    guint16 rotation;
} XigRANDRSetCrtcConfig;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
    guint32 timestamp;
} XigRANDRSetCrtcConfigReply;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
} XigRANDRGetCrtcGammaSize;

typedef struct
{
    guint16 sequence_number;
    guint16 size;
} XigRANDRGetCrtcGammaSizeReply;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
} XigRANDRGetCrtcGamma;

typedef struct
{
    guint16 sequence_number;
    guint16 size;
} XigRANDRGetCrtcGammaReply;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
    guint16 size;
} XigRANDRSetCrtcGamma;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigRANDRGetScreenResourcesCurrent;

typedef struct
{
    guint16 sequence_number;
    guint32 timestamp;
    guint32 config_timestamp;
    guint32 *crtcs;
    gsize crtcs_length;
    guint32 *outputs;
    gsize outputs_length;
    XigRANDRMODEINFO *modes;
    gsize modes_length;
} XigRANDRGetScreenResourcesCurrentReply;

typedef struct
{
    gint32 matrix11;
    gint32 matrix12;
    gint32 matrix13;
    gint32 matrix21;
    gint32 matrix22;
    gint32 matrix23;
    gint32 matrix31;
    gint32 matrix32;
    gint32 matrix33;
} XigTRANSFORM;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
    XigTRANSFORM transform;
    guint16 filter_len;
} XigRANDRSetCrtcTransform;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
} XigRANDRGetCrtcTransform;

typedef struct
{
    guint16 sequence_number;
    XigTRANSFORM pending_transform;
    gboolean has_transforms;
    XigTRANSFORM current_transform;
    guint16 pending_len;
    guint16 pending_nparams;
    guint16 current_len;
    guint16 current_nparams;
} XigRANDRGetCrtcTransformReply;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
} XigRANDRGetPanning;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
    guint32 timestamp;
    guint16 left;
    guint16 top;
    guint16 width;
    guint16 height;
    guint16 track_left;
    guint16 track_top;
    guint16 track_width;
    guint16 track_height;
    gint16 border_left;
    gint16 border_top;
    gint16 border_right;
    gint16 border_bottom;
} XigRANDRGetPanningReply;

typedef struct
{
    guint16 sequence_number;
    guint32 crtc;
    guint32 timestamp;
    guint16 left;
    guint16 top;
    guint16 width;
    guint16 height;
    guint16 track_left;
    guint16 track_top;
    guint16 track_width;
    guint16 track_height;
    gint16 border_left;
    gint16 border_top;
    gint16 border_right;
    gint16 border_bottom;
} XigRANDRSetPanning;

typedef struct
{
    guint16 sequence_number;
    guint8 status;
    guint32 timestamp;
} XigRANDRSetPanningReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 output;
} XigRANDRSetOutputPrimary;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigRANDRGetOutputPrimary;

typedef struct
{
    guint16 sequence_number;
    guint32 output;
} XigRANDRGetOutputPrimaryReply;

typedef struct
{
    guint16 sequence_number;
    guint8 major;
    guint8 minor;
} XigXINERAMAQueryVersion;

typedef struct
{
    guint16 sequence_number;
    guint16 major;
    guint16 minor;
} XigXINERAMAQueryVersionReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigXINERAMAGetState;

typedef struct
{
    guint16 sequence_number;
    guint8 state;
    guint32 window;
} XigXINERAMAGetStateReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
} XigXINERAMAGetScreenCount;

typedef struct
{
    guint16 sequence_number;
    guint8 screen_count;
    guint32 window;
} XigXINERAMAGetScreenCountReply;

typedef struct
{
    guint16 sequence_number;
    guint32 window;
    guint32 screen;
} XigXINERAMAGetScreenSize;

typedef struct
{
    guint16 sequence_number;
    guint32 width;
    guint32 height;
    guint32 window;
    guint32 screen;
} XigXINERAMAGetScreenSizeReply;

typedef struct
{
    guint16 sequence_number;
} XigXINERAMAIsActive;

typedef struct
{
    guint16 sequence_number;
    gboolean is_active;
} XigXINERAMAIsActiveReply;

typedef struct
{
    guint16 sequence_number;
} XigXINERAMAQueryScreens;

typedef struct
{
    gint16 x;
    gint16 y;
    guint16 width;
    guint16 height;
} XigXINERAMAScreenInfo;

typedef struct
{
    guint16 sequence_number;
    XigXINERAMAScreenInfo *info;
    gsize info_length;
} XigXINERAMAQueryScreensReply;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 old_device_id;
    guint8 min_key_code;
    guint8 max_key_code;
    guint8 old_min_key_code;
    guint8 old_max_key_code;
    guint8 request_major;
    guint8 request_minor;
    guint16 changed;
} XigXKBNewKeyboardNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 ptr_btn_actions;
    guint16 changed;
    guint8 min_key_code;
    guint8 max_key_code;
    guint8 first_type;
    guint8 n_types;
    guint8 first_key_sym;
    guint8 n_key_syms;
    guint8 first_key_act;
    guint8 n_key_acts;
    guint8 first_key_behavior;
    guint8 n_key_behavior;
    guint8 first_key_explicit;
    guint8 n_key_explicit;
    guint8 first_mod_map_key;
    guint8 n_mod_map_keys;
    guint8 first_vmod_map_key;
    guint8 n_vmod_map_keys;
    guint16 virtual_mods;
} XigXKBMapNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 mods;
    guint8 base_mods;
    guint8 latched_mods;
    guint8 locked_mods;
    guint8 group;
    gint16 base_group;
    gint16 latched_group;
    guint8 locked_group;
    guint8 compat_state;
    guint8 grab_mods;
    guint8 compat_grab_mods;
    guint8 lookup_mods;
    guint8 compat_loockup_mods;
    guint16 ptr_btn_state;
    guint16 changed;
    guint8 keycode;
    guint8 event_type;
    guint8 request_major;
    guint8 request_minor;
} XigXKBStateNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 num_groups;
    guint32 changed_controls;
    guint32 enabled_controls;
    guint32 enabled_control_changes;
    guint8 keycode;
    guint8 event_type;
    guint8 request_major;
    guint8 request_minor;
} XigXKBControlsNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint32 state;
    guint32 state_changed;
} XigXKBIndicatorStateNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint32 state;
    guint32 map_changed;
} XigXKBIndicatorMapNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint16 changed;
    guint8 first_type;
    guint8 n_types;
    guint8 first_level_name;
    guint8 n_level_names;
    guint8 n_radio_groups;
    guint8 n_key_aliases;
    guint8 changed_group_names;
    guint16 changed_virtual_mods;
    guint8 first_key;
    guint8 n_keys;
    guint32 changed_indicators;
} XigXKBNamesNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 changed_groups;
    guint16 first_si;
    guint16 n_si;
    guint16 n_total_si;
} XigXKBCompatMapNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 bell_class;
    guint8 bell_id;
    guint8 percent;
    guint16 pitch;
    guint16 duration;
    guint32 name;
    guint32 window;
    gboolean event_only;
} XigXKBBellNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 keycode;
    gboolean press;
    gboolean key_event_follows;
    guint8 mods;
    guint8 group;
} XigXKBActionMessage;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint8 keycode;
    guint16 detailt;
    guint16 slow_keys_delay;
    guint16 debounce_delay;
} XigXKBAccessXNotify;

typedef struct
{
    guint16 sequence_number;
    guint32 time;
    guint8 device_id;
    guint16 reason;
    guint16 led_class;
    guint8 led_id;
    guint32 leds_defined;
    guint32 led_state;
    guint8 first_button;
    guint8 n_buttons;
    guint16 supported;
    guint16 unsupported;
} XigXKBExtensionDeviceNotify;

typedef struct
{
    guint16 sequence_number;
    guint8 wanted_major;
    guint8 wanted_minor;
} XigXKBUseExtension;

typedef struct
{
    guint16 sequence_number;
    gboolean supported;
    guint8 server_major;
    guint8 server_minor;
} XigXKBUseExtensionReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 affect_which;
    guint16 clear;
    guint16 select_all;
    guint16 affect_map;
    guint16 map;
} XigXKBSelectEvents;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 bell_class;
    guint16 bell_id;
    gint8 percent;
    gboolean force_sound;
    gboolean event_only;
    gint16 pitch;
    gint16 duration;
    guint32 name;
    guint32 window;
} XigXKBBell;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
} XigXKBGetState;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint8 mods;
    guint8 base_mods;
    guint8 latched_mods;
    guint8 locked_mods;
    guint8 group;
    guint8 locked_group;
    guint16 base_group;
    guint16 latched_group;
    guint8 compat_state;
    guint8 grab_mods;
    guint8 compat_grab_mods;
    guint8 lookup_mods;
    guint8 compat_lookup_mods;
    guint16 ptr_btn_state;
} XigXKBGetStateReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint8 affect_mod_locks;
    guint8 mod_locks;
    gboolean lock_group;
    guint8 group_lock;
    guint8 affect_mod_latches;
    gboolean latch_group;
    guint16 group_latch;
} XigXKBLatchLockState;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
} XigXKBGetControls;

typedef struct
{
    guint16 fbopt;
    guint16 skopt;
} XigAXOption;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint8 mouse_keys_dflt_btn;
    guint8 num_groups;
    guint8 groups_wrap;
    guint8 internal_mods_mask;
    guint8 ignore_lock_mods_mask;
    guint8 internal_mods_real_mods;
    guint8 ignore_lock_mods_real_mods;
    guint16 internal_mods_vmods;
    guint16 ignore_lock_mods_vmods;
    guint16 repeat_delay;
    guint16 repeat_interval;
    guint16 slow_keys_delay;
    guint16 debounce_delay;
    guint16 mouse_keys_delay;
    guint16 mouse_keys_interval;
    guint16 mouse_keys_time_to_max;
    guint16 mouse_keys_max_speed;
    gint16 mouse_keys_curve;
    XigAXOption access_xoption;
    guint16 access_xtimeout;
    XigAXOption access_xtimeout_options_mask;
    XigAXOption access_xtimeout_options_values;
    guint32 access_xtimeout_mask;
    guint32 access_xtimeout_values;
    guint32 enabled_controls;
} XigXKBGetControlsReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint8 affect_internal_real_mods;
    guint8 internal_real_mods;
    guint8 affect_ignore_lock_real_mods;
    guint8 ignore_lock_real_mods;
    guint16 affect_internal_virtual_mods;
    guint16 internal_virtual_mods;
    guint16 affect_ignore_lock_virtual_mods;
    guint16 ignore_lock_virtual_mods;
    guint8 mouse_keys_dflt_btn;
    guint8 groups_wrap;
    guint16 access_x_options;
    guint32 affect_enabled_controls;
    guint32 enabled_controls;
    guint32 change_controls;
    guint16 repeat_delay;
    guint16 repeat_interval;
    guint16 slow_keys_delay;
    guint16 debounce_delay;
    guint16 mouse_keys_delay;
    guint16 mouse_keys_interval;
    guint16 mouse_keys_time_to_max;
    guint16 mouse_keys_max_speed;
    gint16 mouse_keys_curve;
    guint16 access_x_timeout;
    guint32 access_x_timeout_mask;
    guint32 access_x_timeout_values;
    guint16 access_x_timeout_options_mask;
    guint16 access_x_timeout_options_values;
    guint8 per_key_repeat[32];
} XigXKBSetControls;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 full;
    guint16 partial;
    guint8 first_type;
    guint8 n_types;
    guint8 first_key_sym;
    guint8 n_key_syms;
    guint8 first_key_action;
    guint8 n_key_actions;
    guint8 first_key_behavior;
    guint8 n_key_behaviors;
    guint16 virtual_mods;
    guint8 first_key_explicit;
    guint8 n_key_explicit;
    guint8 first_mod_map_key;
    guint8 n_mod_map_keys;
    guint8 first_v_mod_map_key;
    guint8 n_v_mod_map_keys;
} XigXKBGetMap;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint8 min_key_code;
    guint8 max_key_code;
    guint16 present;
    guint8 first_type;
    guint8 n_types;
    guint8 total_types;
    guint8 first_key_sym;
    guint16 total_syms;
    guint8 n_key_syms;
    guint8 first_key_action;
    guint16 total_actions;
    guint8 n_key_actions;
    guint8 first_key_behavior;
    guint8 n_key_behaviors;
    guint8 total_key_behaviors;
    guint8 first_key_explicit;
    guint8 n_key_explicit;
    guint8 total_key_explicit;
    guint8 first_mod_map_key;
    guint8 n_mod_map_keys;
    guint8 total_mod_map_keys;
    guint8 first_vmod_map_key;
    guint8 n_vmod_map_keys;
    guint8 total_vmod_map_keys;
    guint16 virtual_mods;
} XigXKBGetMapReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 present;
    guint16 flags;
    guint8 min_key_code;
    guint8 max_key_code;
    guint8 first_type;
    guint8 n_types;
    guint8 first_key_sym;
    guint8 n_key_syms;
    guint16 total_syms;
    guint8 first_key_action;
    guint8 n_key_actions;
    guint16 total_actions;
    guint8 first_key_behavior;
    guint8 n_key_behaviors;
    guint8 total_key_behaviors;
    guint8 first_key_explicit;
    guint8 n_key_explicit;
    guint8 total_key_explicit;
    guint8 first_mod_map_key;
    guint8 n_mod_map_keys;
    guint8 total_mod_map_keys;
    guint8 first_vmod_map_key;
    guint8 n_vmod_map_keys;
    guint8 total_vmod_map_keys;
    guint16 virtual_mods;
} XigXKBSetMap;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint8 groups;
    gboolean get_all_si;
    guint16 first_si;
    guint16 n_si;
} XigXKBGetCompatMap;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint8 groups_rtrn;
    guint16 first_sirtrn;
    guint16 n_sirtrn;
    guint16 n_total_si;
} XigXKBGetCompatMapReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    gboolean recompute_actions;
    gboolean truncate_si;
    guint8 groups;
    guint16 first_si;
    guint16 n_si;
} XigXKBSetCompatMap;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
} XigXKBGetIndicatorState;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint32 state;
} XigXKBGetIndicatorStateReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint32 which;
} XigXKBGetIndicatorMap;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint32 which;
    guint32 real_indicators;
    guint8 n_indicators;
} XigXKBGetIndicatorMapReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint32 which;
} XigXKBSetIndicatorMap;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 led_class;
    guint16 led_id;
    guint32 indicator;
} XigXKBGetNamedIndicator;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint32 indicator;
    gboolean found;
    gboolean on;
    gboolean real_indicator;
    guint8 ndx;
    guint8 map_flags;
    guint8 map_which_groups;
    guint8 map_groups;
    guint8 map_which_mods;
    guint8 map_mods;
    guint8 map_real_mods;
    guint16 map_vmod;
    guint32 map_ctrls;
} XigXKBGetNamedIndicatorReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 led_class;
    guint16 led_id;
    guint32 indicator;
    gboolean set_state;
    gboolean on;
    gboolean set_map;
    gboolean create_map;
    guint8 map_flags;
    guint8 map_which_groups;
    guint8 map_groups;
    guint8 map_which_mods;
    guint8 map_real_mods;
    guint16 map_vmods;
    guint32 map_ctrls;
} XigXKBSetNamedIndicator;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint32 which;
} XigXKBGetNames;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint32 which;
    guint8 min_key_code;
    guint8 max_key_code;
    guint8 n_types;
    guint8 group_names;
    guint16 virtual_mods;
    guint8 first_key;
    guint8 n_keys;
    guint32 indicators;
    guint8 n_radio_groups;
    guint8 n_key_aliases;
    guint16 n_ktlevels;
} XigXKBGetNamesReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 virtual_mods;
    guint32 which;
    guint8 first_type;
    guint8 n_types;
    guint8 first_ktlevelt;
    guint8 n_ktlevels;
    guint32 indicators;
    guint8 group_names;
    guint8 n_radio_groups;
    guint8 first_key;
    guint8 n_keys;
    guint8 n_key_aliases;
    guint16 total_ktlevel_names;
} XigXKBSetNames;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint32 name;
} XigXKBGetGeometry;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint32 name;
    gboolean found;
    guint16 width_mm;
    guint16 height_mm;
    guint16 n_properties;
    guint16 n_colors;
    guint16 n_shapes;
    guint16 n_sections;
    guint16 n_doodads;
    guint16 n_key_aliases;
    guint8 base_color_ndx;
    guint8 label_color_ndx;
    guint16 *label_font;
    gsize label_font_length;
} XigXKBGetGeometryReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint8 n_shapes;
    guint8 n_sections;
    guint32 name;
    guint16 width_mm;
    guint16 height_mm;
    guint16 n_properties;
    guint16 n_colors;
    guint16 n_doodads;
    guint16 n_key_aliases;
    guint8 base_color_ndx;
    guint8 label_color_ndx;
    guint16 *label_font;
    gsize label_font_length;
} XigXKBSetGeometry;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint32 change;
    guint32 value;
    guint32 ctrls_to_change;
    guint32 auto_ctrls;
    guint32 auto_ctrls_values;
} XigXKBPerClientFlags;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint32 supported;
    guint32 value;
    guint32 auto_ctrls;
    guint32 auto_ctrls_values;
} XigXKBPerClientFlagsReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 max_names;
    guint8 keymaps_spec_len;
    guint8 keycodes_spec_len;
    guint8 types_spec_len;
    guint8 compat_map_spec_len;
    guint8 symbols_spec_len;
    guint8 geometry_spec_len;
} XigXKBListComponents;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint16 n_keymaps;
    guint16 n_keycodes;
    guint16 n_types;
    guint16 n_compat_maps;
    guint16 n_symbols;
    guint16 n_geometries;
    guint16 extra;
} XigXKBListComponentsReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 need;
    guint16 want;
    gboolean load;
    guint8 keymaps_spec_len;
    guint8 keycodes_spec_len;
    guint8 types_spec_len;
    guint8 compat_map_spec_len;
    guint8 symbols_spec_len;
    guint8 geometry_spec_len;
} XigXKBGetKbdByName;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint8 min_key_code;
    guint8 max_key_code;
    gboolean loaded;
    gboolean new_keyboard;
    guint16 found;
    guint16 reported;
} XigXKBGetKbdByNameReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint16 wanted;
    gboolean all_buttons;
    guint8 first_button;
    guint8 n_buttons;
    guint16 led_class;
    guint16 led_id;
} XigXKBGetDeviceInfo;

typedef struct
{
    guint16 sequence_number;
    guint8 device_id;
    guint16 present;
    guint16 supported;
    guint16 unsupported;
    guint16 n_device_led_fbs;
    guint8 first_btn_wanted;
    guint8 n_btns_wanted;
    guint8 first_btn_rtrn;
    guint8 n_btns_rtrn;
    guint8 total_btns;
    gboolean has_own_state;
    guint16 dflt_kbd_fb;
    guint16 dflt_led_fb;
    guint32 dev_type;
    guint16 name_len;
} XigXKBGetDeviceInfoReply;

typedef struct
{
    guint16 sequence_number;
    guint16 device_spec;
    guint8 first_btn;
    guint8 n_btns;
    guint16 change;
    guint16 n_device_led_fbs;
} XigXKBSetDeviceInfo;

typedef struct
{
    guint16 sequence_number;
    guint16 msg_length;
    guint32 affect_flags;
    guint32 flags;
    guint32 affect_ctrls;
    guint32 ctrls;
} XigXKBSetDebuggingFlags;

typedef struct
{
    guint16 sequence_number;
    guint32 current_flags;
    guint32 current_ctrls;
    guint32 supported_flags;
    guint32 supported_ctrls;
} XigXKBSetDebuggingFlagsReply;

typedef struct
{
    guint16 sequence_number;
    guint32 client_major_version;
    guint32 client_minor_version;
} XigRENDERQueryVersion;

typedef struct
{
    guint16 sequence_number;
    guint32 major_version;
    guint32 minor_version;
} XigRENDERQueryVersionReply;

typedef struct
{
    guint16 sequence_number;
} XigRENDERQueryPictFormats;

typedef struct
{
    guint16 sequence_number;
    guint32 num_formats;
    guint32 num_screens;
    guint32 num_depths;
    guint32 num_visuals;
    guint32 num_subpixel;
} XigRENDERQueryPictFormatsReply;

typedef struct
{
    guint16 sequence_number;
    guint32 format;
} XigRENDERQueryPictIndexValues;

typedef struct
{
    guint16 sequence_number;
    guint32 num_values;
} XigRENDERQueryPictIndexValuesReply;

typedef struct
{
    guint16 sequence_number;
    guint32 pid;
    guint32 drawable;
    guint32 format;
} XigRENDERCreatePicture;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
} XigRENDERChangePicture;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    gint16 clip_x_origin;
    gint16 clip_y_origin;
} XigRENDERSetPictureClipRectangles;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
} XigRENDERFreePicture;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 mask;
    guint32 dst;
    gint16 src_x;
    gint16 src_y;
    gint16 mask_x;
    gint16 mask_y;
    gint16 dst_x;
    gint16 dst_y;
    guint16 width;
    guint16 height;
} XigRENDERComposite;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    gint16 src_x;
    gint16 src_y;
} XigRENDERTrapezoids;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    gint16 src_x;
    gint16 src_y;
} XigRENDERTriangles;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    gint16 src_x;
    gint16 src_y;
} XigRENDERTriStrip;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    gint16 src_x;
    gint16 src_y;
} XigRENDERTriFan;

typedef struct
{
    guint16 sequence_number;
    guint32 gsid;
    guint32 format;
} XigRENDERCreateGlyphSet;

typedef struct
{
    guint16 sequence_number;
    guint32 gsid;
    guint32 existing;
} XigRENDERReferenceGlyphSet;

typedef struct
{
    guint16 sequence_number;
    guint32 glyphset;
} XigRENDERFreeGlyphSet;

typedef struct
{
    guint16 sequence_number;
    guint32 glyphset;
    guint32 glyphs_len;
} XigRENDERAddGlyphs;

typedef struct
{
    guint16 sequence_number;
    guint32 glyphset;
} XigRENDERFreeGlyphs;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    guint32 glyphset;
    gint16 src_x;
    gint16 src_y;
} XigRENDERCompositeGlyphs8;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    guint32 glyphset;
    gint16 src_x;
    gint16 src_y;
} XigRENDERCompositeGlyphs16;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 src;
    guint32 dst;
    guint32 mask_format;
    guint32 glyphset;
    gint16 src_x;
    gint16 src_y;
} XigRENDERCompositeGlyphs32;

typedef struct
{
    guint16 red;
    guint16 green;
    guint16 blue;
    guint16 alpha;
} XigCOLOR;

typedef struct
{
    guint16 sequence_number;
    guint8 op;
    guint32 dst;
    XigCOLOR color;
} XigRENDERFillRectangles;

typedef struct
{
    guint16 sequence_number;
    guint32 cid;
    guint32 source;
    guint16 x;
    guint16 y;
} XigRENDERCreateCursor;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    XigTRANSFORM transform;
} XigRENDERSetPictureTransform;

typedef struct
{
    guint16 sequence_number;
    guint32 drawable;
} XigRENDERQueryFilters;

typedef struct
{
    guint16 sequence_number;
    guint32 num_aliases;
    guint32 num_filters;
} XigRENDERQueryFiltersReply;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    guint16 filter_len;
} XigRENDERSetPictureFilter;

typedef struct
{
    guint16 sequence_number;
    guint32 cid;
} XigRENDERCreateAnimCursor;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    gint16 x_off;
    gint16 y_off;
} XigRENDERAddTraps;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    XigCOLOR color;
} XigRENDERCreateSolidFill;

typedef struct
{
    gint32 x;
    gint32 y;
} XigPOINTFIX;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    XigPOINTFIX p1;
    XigPOINTFIX p2;
    guint32 num_stops;
} XigRENDERCreateLinearGradient;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    XigPOINTFIX inner;
    XigPOINTFIX outer;
    gint32 inner_radius;
    gint32 outer_radius;
    guint32 num_stops;
} XigRENDERCreateRadialGradient;

typedef struct
{
    guint16 sequence_number;
    guint32 picture;
    XigPOINTFIX center;
    gint32 angle;
    guint32 num_stops;
} XigRENDERCreateConicalGradient;

G_END_DECLS

#endif /* _XIG_EVENTS_H_ */
