/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#ifndef _XIG_SERVER_H_
#define _XIG_SERVER_H_

#include <glib-object.h>
#include <gio/gio.h>

typedef struct XigServer XigServer;

#include "xig-screen.h"
#include "xig-pixmap-format.h"
#include "xig-remote-client.h"
#include "xig-window.h"
#include "xig-pixmap.h"

G_BEGIN_DECLS

typedef enum
{
    XIG_SERVER_IMAGE_BYTE_ORDER_LSBFirst = 0,
    XIG_SERVER_IMAGE_BYTE_ORDER_MSBFirst = 1
} XigServerImageByteOrder;

typedef enum
{
    XIG_SERVER_IMAGE_BYTE_ORDER_LeastSignificant = 0,
    XIG_SERVER_IMAGE_BYTE_ORDER_MostSignificant = 1
} XigServerBitmapFormatBitOrder;

typedef struct XigServerPrivate XigServerPrivate;

struct XigServer
{
   GObject         parent_instance;
   XigServerPrivate *priv;
};

typedef struct
{
   GObjectClass parent_class;
   void (*client_connected)(XigServer *server, XigRemoteClient *client);
   void (*client_disconnected)(XigServer *server, XigRemoteClient *client);
} XigServerClass;

GType xig_server_get_type (void);

XigServer *xig_server_new (const gchar *vendor, guint display_number);

const gchar *xig_server_get_vendor (XigServer *server);

guint xig_server_get_display_number (XigServer *server);

XigScreen *xig_server_add_screen (XigServer *server, guint32 white_pixel, guint32 black_pixel, guint16 width_in_pixels, guint16 height_in_pixels, guint16 width_in_millimeters, guint16 height_in_millimeters);

XigPixmapFormat *xig_server_add_pixmap_format (XigServer *server, guint8 depth, guint8 bits_per_pixel, guint8 scanline_pad);

void xig_server_set_listen_unix (XigServer *server, gboolean listen_unix);

void xig_server_set_listen_tcp (XigServer *server, gboolean listen_tcp);

void xig_server_set_motion_buffer_size (XigServer *server, guint32 size);

guint32 xig_server_get_motion_buffer_size (XigServer *server);

guint8 xig_server_get_min_keycode (XigServer *server);

guint8 xig_server_get_max_keycode (XigServer *server);

XigServerImageByteOrder xig_server_get_image_byte_order (XigServer *server);

XigServerBitmapFormatBitOrder xig_server_get_bitmap_format_bit_order (XigServer *server);

GList *xig_server_get_pixmap_formats (XigServer *server);

GList *xig_server_get_screens (XigServer *server);

XigScreen *xig_server_get_screen (XigServer *server, int number);

XigDrawable *xig_server_get_drawable (XigServer *server, guint32 drawable);

XigWindow *xig_server_get_root (XigServer *server, int screen);

XigWindow *xig_server_get_window (XigServer *server, guint32 wid);

XigWindow *xig_server_get_selection_owner (XigServer *server, const gchar *name);

XigRemoteClient *xig_server_get_resize_redirect_client (XigServer *server, XigWindow *window);

XigRemoteClient *xig_server_get_substructure_redirect_client (XigServer *server, XigWindow *window);

void xig_server_set_input_focus (XigServer *server, XigWindow *window, guint8 revert_to);

XigWindow *xig_server_get_input_focus (XigServer *server, guint8 *revert_to);

XigPixmap *xig_server_get_pixmap (XigServer *server, guint32 pid);

GList *xig_server_get_clients (XigServer *server);

guint32 xig_server_intern_atom (XigServer *server, const gchar *name, gboolean only_if_exists);

const gchar *xig_server_get_atom_name (XigServer *server, guint32 id);

const guint32 xig_server_get_atom_id (XigServer *server, const gchar *name);

gboolean xig_server_start (XigServer *server, GError **error);

void xig_server_stop (XigServer *server);

G_END_DECLS

#endif /* _XIG_SERVER_H_ */
