/*
 * Copyright (C) 2011 Canonical Ltd.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#ifndef _XIG_WINDOW_H_
#define _XIG_WINDOW_H_

typedef struct XigWindow XigWindow;

#include "xig-server.h"
#include "xig-drawable.h"
#include "xig-visual.h"
#include "xig-pixmap.h"
#include "xig-events.h"
#include "xig-remote-client.h"

G_BEGIN_DECLS

#define XIG_WINDOW_TYPE           (xig_window_get_type())
#define XIG_IS_WINDOW(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XIG_WINDOW_TYPE))
#define XIG_WINDOW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), XIG_WINDOW_TYPE, XigWindow))
#define XIG_WINDOW_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), XIG_WINDOW_TYPE, XigWindowClass))
#define XIG_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XIG_WINDOW_TYPE, XigWindowClass))

typedef struct XigWindowPrivate XigWindowPrivate;

typedef enum
{
    XIG_WINDOW_CLASS_InputOutput = 1,
    XIG_WINDOW_CLASS_InputOnly = 2
} XigWindowClassType;

typedef enum
{
    XIG_BIT_GRAVITY_Forget    = 0,
    XIG_BIT_GRAVITY_NorthWest = 1,
    XIG_BIT_GRAVITY_North     = 2,
    XIG_BIT_GRAVITY_NorthEast = 3,
    XIG_BIT_GRAVITY_West      = 4,
    XIG_BIT_GRAVITY_Center    = 5,
    XIG_BIT_GRAVITY_East      = 6,
    XIG_BIT_GRAVITY_SouthWest = 7,
    XIG_BIT_GRAVITY_South     = 8,
    XIG_BIT_GRAVITY_SouthEast = 9,
    XIG_BIT_GRAVITY_Static    = 10
} XigBitGravity;

typedef enum
{
    XIG_WIN_GRAVITY_Unmap     = 0,
    XIG_WIN_GRAVITY_NorthWest = 1,
    XIG_WIN_GRAVITY_North     = 2,
    XIG_WIN_GRAVITY_NorthEast = 3,
    XIG_WIN_GRAVITY_West      = 4,
    XIG_WIN_GRAVITY_Center    = 5,
    XIG_WIN_GRAVITY_East      = 6,
    XIG_WIN_GRAVITY_SouthWest = 7,
    XIG_WIN_GRAVITY_South     = 8,
    XIG_WIN_GRAVITY_SouthEast = 9,
    XIG_WIN_GRAVITY_Static    = 10 
} XigWinGravity;

typedef enum
{
    XIG_WINDOW_STACK_MODE_ABOVE     = 0,
    XIG_WINDOW_STACK_MODE_BELOW     = 1,
    XIG_WINDOW_STACK_MODE_TOP_IF    = 2,
    XIG_WINDOW_STACK_MODE_BOTTOM_IF = 3,
    XIG_WINDOW_STACK_MODE_OPPOSITE  = 4
} XigWindowStackMode;

typedef enum
{
    XIG_CHANGE_PROPERTY_MODE_REPLACE = 0,
    XIG_CHANGE_PROPERTY_MODE_PREPEND = 1,
    XIG_CHANGE_PROPERTY_MODE_APPEND  = 2
} XigChangePropertyMode;

typedef struct
{
    gchar *name;
    gchar *type;
    guint8 format;
    guint8 *data;
    gsize data_length;
} XigWindowProperty;

struct XigWindow
{
   XigDrawable       parent_instance;
   XigWindowPrivate *priv;
};

typedef struct
{
   XigDrawableClass parent_class;
   void (*create_notify)(XigWindow *window, XigWindow *child);
   void (*destroy_notify)(XigWindow *window);
   void (*child_destroy_notify)(XigWindow *window, XigWindow *child);
   void (*unmap_notify)(XigWindow *window);
   void (*child_unmap_notify)(XigWindow *window, XigWindow *child);
   void (*map_notify)(XigWindow *window);
   void (*child_map_notify)(XigWindow *window, XigWindow *child);
   void (*reparent_notify)(XigWindow *window);
   void (*child_reparent_notify)(XigWindow *window, XigWindow *child);
   void (*configure_notify)(XigWindow *window);
   void (*child_configure_notify)(XigWindow *window, XigWindow *child);
   void (*circulate_notify)(XigWindow *window);
   void (*child_circulate_notify)(XigWindow *window, XigWindow *child);
   void (*property_notify)(XigWindow *window, const gchar *name);
} XigWindowClass;

GType xig_window_get_type (void);

XigServer *xig_window_get_server (XigWindow *window);

XigRemoteClient *xig_window_get_client (XigWindow *window);

guint32 xig_window_get_id (XigWindow *window);

XigWindowClassType xig_window_get_class (XigWindow *window);

gint16 xig_window_get_x (XigWindow *window);

gint16 xig_window_get_y (XigWindow *window);

guint16 xig_window_get_width (XigWindow *window);

guint16 xig_window_get_height (XigWindow *window);

guint16 xig_window_get_border_width (XigWindow *window);

XigVisual *xig_window_get_visual (XigWindow *window);

XigPixmap *xig_window_get_background_pixmap (XigWindow *window);

guint32 xig_window_get_background_pixel (XigWindow *window);

XigPixmap *xig_window_get_border_pixmap (XigWindow *window);

guint32 xig_window_get_border_pixel (XigWindow *window);

XigBitGravity xig_window_get_bit_gravity (XigWindow *window);

XigWinGravity xig_window_get_win_gravity (XigWindow *window);

guint8 xig_window_get_backing_store (XigWindow *window);

guint32 xig_window_get_backing_planes (XigWindow *window);

guint32 xig_window_get_backing_pixel (XigWindow *window);

gboolean xig_window_get_override_redirect (XigWindow *window);

gboolean xig_window_get_save_under (XigWindow *window);

GHashTable *xig_window_get_properties (XigWindow *window);

XigWindowProperty *xig_window_get_property (XigWindow *window, const gchar *name);

GList *xig_window_get_children (XigWindow *window);

gboolean xig_window_is_root (XigWindow *window);

XigWindow *xig_window_get_root (XigWindow *window);

XigWindow *xig_window_get_parent (XigWindow *window);

XigWindow *xig_window_get_window_below (XigWindow *window);

XigWindow *xig_window_get_window_above (XigWindow *window);

gboolean xig_window_has_child (XigWindow *window, XigWindow *child);

gboolean xig_window_get_is_on_bottom (XigWindow *window);

gboolean xig_window_get_is_on_top (XigWindow *window);

gboolean xig_window_has_sibling (XigWindow *window, XigWindow *sibling);

gboolean xig_window_get_mapped (XigWindow *window);

// FIXME: Use varargs
XigWindow *xig_window_add_child (XigWindow *window,
                                 XigRemoteClient *client,
                                 guint32 wid,
                                 XigWindowClassType class,
                                 gint16 x,
                                 gint16 y,
                                 guint16 width,
                                 guint16 height,
                                 guint16 border_width,
                                 XigVisual *visual,
                                 XigCreateWindowValueMask value_mask,
                                 XigPixmap *background_pixmap,
                                 guint32 background_pixel,
                                 XigPixmap *border_pixmap,
                                 guint32 border_pixel,
                                 XigBitGravity bit_gravity,
                                 XigWinGravity win_gravity,
                                 guint8 backing_store,
                                 guint32 backing_planes,
                                 guint32 backing_pixel,
                                 gboolean override_redirect,
                                 gboolean save_under);

void xig_window_change_attributes (XigWindow *window,
                                   XigCreateWindowValueMask value_mask,
                                   XigPixmap *background_pixmap,
                                   guint32 background_pixel,
                                   XigPixmap *border_pixmap,
                                   guint32 border_pixel,
                                   XigBitGravity bit_gravity,
                                   XigWinGravity win_gravity,
                                   guint8 backing_store,
                                   guint32 backing_planes,
                                   guint32 backing_pixel,
                                   gboolean override_redirect,
                                   gboolean save_under);

void xig_window_reparent (XigWindow *window, XigWindow *parent, gint16 x, gint16 y);

void xig_window_map (XigWindow *window, XigRemoteClient *client);

void xig_window_unmap (XigWindow *window);

void xig_window_configure (XigWindow *window, XigRemoteClient *client, gint16 x, gint16 y, guint16 width, guint16 height, guint16 border_width, XigWindow *sibling, XigWindowStackMode stack_mode, XigConfigureWindowValueMask value_mask);

void xig_window_circulate (XigWindow *window, XigRemoteClient *client, XigCirculateDirection direction);

XigWindowProperty *xig_window_replace_property (XigWindow *window, const gchar *name, const gchar *type, guint8 format, guint8 *data, gsize data_length);

XigWindowProperty *xig_window_append_property (XigWindow *window, const gchar *name, guint8 *data, gsize data_length);

XigWindowProperty *xig_window_prepend_property (XigWindow *window, const gchar *name, guint8 *data, gsize data_length);

void xig_window_delete_property (XigWindow *window, const gchar *name);

void xig_window_destroy (XigWindow *window);

void xig_window_destroy_subwindows (XigWindow *window);

G_END_DECLS

#endif /* _XIG_WINDOW_H_ */
