/*
 * Copyright (C) 2011 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3 as published by
 * the Free Software Foundation. See http://www.gnu.org/copyleft/lgpl.html the
 * full text of the license.
 */

#include <string.h>

#include "xig/xig-codec.h"

G_DEFINE_TYPE (XigCodec, xig_codec, G_TYPE_OBJECT);

enum
{
    CONNECT,
    FAILED,
    AUTHENTICATE,
    SUCCESS,
    ERROR,
    KEY_PRESS,
    BUTTON_PRESS,
    MOTION_NOTIFY,
    ENTER_NOTIFY,
    FOCUS_IN,
    KEYMAP_NOTIFY,
    EXPOSE,
    GRAPHICS_EXPOSURE,
    NO_EXPOSURE,
    VISIBILITY_NOTIFY,
    CREATE_NOTIFY,
    DESTROY_NOTIFY,
    UNMAP_NOTIFY,
    MAP_NOTIFY,
    MAP_REQUEST,
    REPARENT_NOTIFY,
    CONFIGURE_NOTIFY,
    CONFIGURE_REQUEST,
    GRAVITY_NOTIFY,
    RESIZE_REQUEST,
    CIRCULATE_NOTIFY,
    CIRCULATE_REQUEST,
    PROPERTY_NOTIFY,
    SELECTION_CLEAR,
    SELECTION_REQUEST,
    SELECTION_NOTIFY,
    COLORMAP_NOTIFY,
    CLIENT_MESSAGE,
    MAPPING_NOTIFY,
    CREATE_WINDOW,
    CHANGE_WINDOW_ATTRIBUTES,
    GET_WINDOW_ATTRIBUTES,
    GET_WINDOW_ATTRIBUTES_REPLY,
    DESTROY_WINDOW,
    DESTROY_SUBWINDOWS,
    CHANGE_SAVE_SET,
    REPARENT_WINDOW,
    MAP_WINDOW,
    MAP_SUBWINDOWS,
    UNMAP_WINDOW,
    UNMAP_SUBWINDOWS,
    CONFIGURE_WINDOW,
    CIRCULATE_WINDOW,
    GET_GEOMETRY,
    GET_GEOMETRY_REPLY,
    QUERY_TREE,
    QUERY_TREE_REPLY,
    INTERN_ATOM,
    INTERN_ATOM_REPLY,
    GET_ATOM_NAME,
    GET_ATOM_NAME_REPLY,
    CHANGE_PROPERTY,
    DELETE_PROPERTY,
    GET_PROPERTY,
    GET_PROPERTY_REPLY,
    LIST_PROPERTIES,
    LIST_PROPERTIES_REPLY,
    SET_SELECTION_OWNER,
    GET_SELECTION_OWNER,
    GET_SELECTION_OWNER_REPLY,
    CONVERT_SELECTION,
    SEND_EVENT,
    GRAB_POINTER,
    GRAB_POINTER_REPLY,
    UNGRAB_POINTER,
    GRAB_BUTTON,
    UNGRAB_BUTTON,
    CHANGE_ACTIVE_POINTER_GRAB,
    GRAB_KEYBOARD,
    GRAB_KEYBOARD_REPLY,
    UNGRAB_KEYBOARD,
    GRAB_KEY,
    UNGRAB_KEY,
    ALLOW_EVENTS,
    GRAB_SERVER,
    UNGRAB_SERVER,
    QUERY_POINTER,
    QUERY_POINTER_REPLY,
    GET_MOTION_EVENTS,
    GET_MOTION_EVENTS_REPLY,
    TRANSLATE_COORDINATES,
    TRANSLATE_COORDINATES_REPLY,
    WARP_POINTER,
    SET_INPUT_FOCUS,
    GET_INPUT_FOCUS,
    GET_INPUT_FOCUS_REPLY,
    QUERY_KEYMAP,
    QUERY_KEYMAP_REPLY,
    OPEN_FONT,
    CLOSE_FONT,
    QUERY_FONT,
    QUERY_FONT_REPLY,
    QUERY_TEXT_EXTENTS,
    QUERY_TEXT_EXTENTS_REPLY,
    LIST_FONTS,
    LIST_FONTS_REPLY,
    LIST_FONTS_WITH_INFO,
    LIST_FONTS_WITH_INFO_REPLY,
    SET_FONT_PATH,
    GET_FONT_PATH,
    GET_FONT_PATH_REPLY,
    CREATE_PIXMAP,
    FREE_PIXMAP,
    CREATE_GC,
    CHANGE_GC,
    COPY_GC,
    SET_DASHES,
    SET_CLIP_RECTANGLES,
    FREE_GC,
    CLEAR_AREA,
    COPY_AREA,
    COPY_PLANE,
    POLY_POINT,
    POLY_LINE,
    POLY_SEGMENT,
    POLY_RECTANGLE,
    POLY_ARC,
    FILL_POLY,
    POLY_FILL_RECTANGLE,
    POLY_FILL_ARC,
    PUT_IMAGE,
    GET_IMAGE,
    GET_IMAGE_REPLY,
    POLY_TEXT8,
    POLY_TEXT16,
    IMAGE_TEXT8,
    IMAGE_TEXT16,
    CREATE_COLORMAP,
    FREE_COLORMAP,
    COPY_COLORMAP_AND_FREE,
    INSTALL_COLORMAP,
    UNINSTALL_COLORMAP,
    LIST_INSTALLED_COLORMAPS,
    LIST_INSTALLED_COLORMAPS_REPLY,
    ALLOC_COLOR,
    ALLOC_COLOR_REPLY,
    ALLOC_NAMED_COLOR,
    ALLOC_NAMED_COLOR_REPLY,
    ALLOC_COLOR_CELLS,
    ALLOC_COLOR_CELLS_REPLY,
    ALLOC_COLOR_PLANES,
    ALLOC_COLOR_PLANES_REPLY,
    FREE_COLORS,
    STORE_COLORS,
    STORE_NAMED_COLOR,
    QUERY_COLORS,
    QUERY_COLORS_REPLY,
    LOOKUP_COLOR,
    LOOKUP_COLOR_REPLY,
    CREATE_CURSOR,
    CREATE_GLYPH_CURSOR,
    FREE_CURSOR,
    RECOLOR_CURSOR,
    QUERY_BEST_SIZE,
    QUERY_BEST_SIZE_REPLY,
    QUERY_EXTENSION,
    QUERY_EXTENSION_REPLY,
    LIST_EXTENSIONS,
    LIST_EXTENSIONS_REPLY,
    CHANGE_KEYBOARD_MAPPING,
    GET_KEYBOARD_MAPPING,
    GET_KEYBOARD_MAPPING_REPLY,
    CHANGE_KEYBOARD_CONTROL,
    GET_KEYBOARD_CONTROL,
    GET_KEYBOARD_CONTROL_REPLY,
    BELL,
    CHANGE_POINTER_CONTROL,
    GET_POINTER_CONTROL,
    GET_POINTER_CONTROL_REPLY,
    SET_SCREEN_SAVER,
    GET_SCREEN_SAVER,
    GET_SCREEN_SAVER_REPLY,
    CHANGE_HOSTS,
    LIST_HOSTS,
    LIST_HOSTS_REPLY,
    SET_ACCESS_CONTROL,
    SET_CLOSE_DOWN_MODE,
    KILL_CLIENT,
    ROTATE_PROPERTIES,
    FORCE_SCREEN_SAVER,
    SET_POINTER_MAPPING,
    SET_POINTER_MAPPING_REPLY,
    GET_POINTER_MAPPING,
    GET_POINTER_MAPPING_REPLY,
    SET_MODIFIER_MAPPING,
    SET_MODIFIER_MAPPING_REPLY,
    GET_MODIFIER_MAPPING,
    GET_MODIFIER_MAPPING_REPLY,
    NO_OPERATION,
    BIGREQ_ENABLE,
    BIGREQ_ENABLE_REPLY,
    SYNC_COUNTER_NOTIFY,
    SYNC_ALARM_NOTIFY,
    SYNC_INITIALIZE,
    SYNC_INITIALIZE_REPLY,
    SYNC_LIST_SYSTEM_COUNTERS,
    SYNC_LIST_SYSTEM_COUNTERS_REPLY,
    SYNC_CREATE_COUNTER,
    SYNC_DESTROY_COUNTER,
    SYNC_QUERY_COUNTER,
    SYNC_QUERY_COUNTER_REPLY,
    SYNC_AWAIT,
    SYNC_CHANGE_COUNTER,
    SYNC_SET_COUNTER,
    SYNC_CREATE_ALARM,
    SYNC_CHANGE_ALARM,
    SYNC_DESTROY_ALARM,
    SYNC_QUERY_ALARM,
    SYNC_QUERY_ALARM_REPLY,
    SYNC_SET_PRIORITY,
    SYNC_GET_PRIORITY,
    SYNC_GET_PRIORITY_REPLY,
    SYNC_CREATE_FENCE,
    SYNC_TRIGGER_FENCE,
    SYNC_RESET_FENCE,
    SYNC_DESTROY_FENCE,
    SYNC_QUERY_FENCE,
    SYNC_QUERY_FENCE_REPLY,
    SYNC_AWAIT_FENCE,
    RANDR_SCREEN_CHANGE_NOTIFY,
    RANDR_NOTIFY,
    RANDR_QUERY_VERSION,
    RANDR_QUERY_VERSION_REPLY,
    RANDR_SET_SCREEN_CONFIG,
    RANDR_SET_SCREEN_CONFIG_REPLY,
    RANDR_SELECT_INPUT,
    RANDR_GET_SCREEN_INFO,
    RANDR_GET_SCREEN_INFO_REPLY,
    RANDR_GET_SCREEN_SIZE_RANGE,
    RANDR_GET_SCREEN_SIZE_RANGE_REPLY,
    RANDR_SET_SCREEN_SIZE,
    RANDR_GET_SCREEN_RESOURCES,
    RANDR_GET_SCREEN_RESOURCES_REPLY,
    RANDR_GET_OUTPUT_INFO,
    RANDR_GET_OUTPUT_INFO_REPLY,
    RANDR_LIST_OUTPUT_PROPERTIES,
    RANDR_LIST_OUTPUT_PROPERTIES_REPLY,
    RANDR_QUERY_OUTPUT_PROPERTY,
    RANDR_QUERY_OUTPUT_PROPERTY_REPLY,
    RANDR_CONFIGURE_OUTPUT_PROPERTY,
    RANDR_CHANGE_OUTPUT_PROPERTY,
    RANDR_DELETE_OUTPUT_PROPERTY,
    RANDR_GET_OUTPUT_PROPERTY,
    RANDR_GET_OUTPUT_PROPERTY_REPLY,
    RANDR_CREATE_MODE,
    RANDR_CREATE_MODE_REPLY,
    RANDR_DESTROY_MODE,
    RANDR_ADD_OUTPUT_MODE,
    RANDR_DELETE_OUTPUT_MODE,
    RANDR_GET_CRTC_INFO,
    RANDR_GET_CRTC_INFO_REPLY,
    RANDR_SET_CRTC_CONFIG,
    RANDR_SET_CRTC_CONFIG_REPLY,
    RANDR_GET_CRTC_GAMMA_SIZE,
    RANDR_GET_CRTC_GAMMA_SIZE_REPLY,
    RANDR_GET_CRTC_GAMMA,
    RANDR_GET_CRTC_GAMMA_REPLY,
    RANDR_SET_CRTC_GAMMA,
    RANDR_GET_SCREEN_RESOURCES_CURRENT,
    RANDR_GET_SCREEN_RESOURCES_CURRENT_REPLY,
    RANDR_SET_CRTC_TRANSFORM,
    RANDR_GET_CRTC_TRANSFORM,
    RANDR_GET_CRTC_TRANSFORM_REPLY,
    RANDR_GET_PANNING,
    RANDR_GET_PANNING_REPLY,
    RANDR_SET_PANNING,
    RANDR_SET_PANNING_REPLY,
    RANDR_SET_OUTPUT_PRIMARY,
    RANDR_GET_OUTPUT_PRIMARY,
    RANDR_GET_OUTPUT_PRIMARY_REPLY,
    XINERAMA_QUERY_VERSION,
    XINERAMA_QUERY_VERSION_REPLY,
    XINERAMA_GET_STATE,
    XINERAMA_GET_STATE_REPLY,
    XINERAMA_GET_SCREEN_COUNT,
    XINERAMA_GET_SCREEN_COUNT_REPLY,
    XINERAMA_GET_SCREEN_SIZE,
    XINERAMA_GET_SCREEN_SIZE_REPLY,
    XINERAMA_IS_ACTIVE,
    XINERAMA_IS_ACTIVE_REPLY,
    XINERAMA_QUERY_SCREENS,
    XINERAMA_QUERY_SCREENS_REPLY,
    XKB_NEW_KEYBOARD_NOTIFY,
    XKB_MAP_NOTIFY,
    XKB_STATE_NOTIFY,
    XKB_CONTROLS_NOTIFY,
    XKB_INDICATOR_STATE_NOTIFY,
    XKB_INDICATOR_MAP_NOTIFY,
    XKB_NAMES_NOTIFY,
    XKB_COMPAT_MAP_NOTIFY,
    XKB_BELL_NOTIFY,
    XKB_ACTION_MESSAGE,
    XKB_ACCESS_XNOTIFY,
    XKB_EXTENSION_DEVICE_NOTIFY,
    XKB_USE_EXTENSION,
    XKB_USE_EXTENSION_REPLY,
    XKB_SELECT_EVENTS,
    XKB_BELL,
    XKB_GET_STATE,
    XKB_GET_STATE_REPLY,
    XKB_LATCH_LOCK_STATE,
    XKB_GET_CONTROLS,
    XKB_GET_CONTROLS_REPLY,
    XKB_SET_CONTROLS,
    XKB_GET_MAP,
    XKB_GET_MAP_REPLY,
    XKB_SET_MAP,
    XKB_GET_COMPAT_MAP,
    XKB_GET_COMPAT_MAP_REPLY,
    XKB_SET_COMPAT_MAP,
    XKB_GET_INDICATOR_STATE,
    XKB_GET_INDICATOR_STATE_REPLY,
    XKB_GET_INDICATOR_MAP,
    XKB_GET_INDICATOR_MAP_REPLY,
    XKB_SET_INDICATOR_MAP,
    XKB_GET_NAMED_INDICATOR,
    XKB_GET_NAMED_INDICATOR_REPLY,
    XKB_SET_NAMED_INDICATOR,
    XKB_GET_NAMES,
    XKB_GET_NAMES_REPLY,
    XKB_SET_NAMES,
    XKB_GET_GEOMETRY,
    XKB_GET_GEOMETRY_REPLY,
    XKB_SET_GEOMETRY,
    XKB_PER_CLIENT_FLAGS,
    XKB_PER_CLIENT_FLAGS_REPLY,
    XKB_LIST_COMPONENTS,
    XKB_LIST_COMPONENTS_REPLY,
    XKB_GET_KBD_BY_NAME,
    XKB_GET_KBD_BY_NAME_REPLY,
    XKB_GET_DEVICE_INFO,
    XKB_GET_DEVICE_INFO_REPLY,
    XKB_SET_DEVICE_INFO,
    XKB_SET_DEBUGGING_FLAGS,
    XKB_SET_DEBUGGING_FLAGS_REPLY,
    RENDER_QUERY_VERSION,
    RENDER_QUERY_VERSION_REPLY,
    RENDER_QUERY_PICT_FORMATS,
    RENDER_QUERY_PICT_FORMATS_REPLY,
    RENDER_QUERY_PICT_INDEX_VALUES,
    RENDER_QUERY_PICT_INDEX_VALUES_REPLY,
    RENDER_CREATE_PICTURE,
    RENDER_CHANGE_PICTURE,
    RENDER_SET_PICTURE_CLIP_RECTANGLES,
    RENDER_FREE_PICTURE,
    RENDER_COMPOSITE,
    RENDER_TRAPEZOIDS,
    RENDER_TRIANGLES,
    RENDER_TRI_STRIP,
    RENDER_TRI_FAN,
    RENDER_CREATE_GLYPH_SET,
    RENDER_REFERENCE_GLYPH_SET,
    RENDER_FREE_GLYPH_SET,
    RENDER_ADD_GLYPHS,
    RENDER_FREE_GLYPHS,
    RENDER_COMPOSITE_GLYPHS8,
    RENDER_COMPOSITE_GLYPHS16,
    RENDER_COMPOSITE_GLYPHS32,
    RENDER_FILL_RECTANGLES,
    RENDER_CREATE_CURSOR,
    RENDER_SET_PICTURE_TRANSFORM,
    RENDER_QUERY_FILTERS,
    RENDER_QUERY_FILTERS_REPLY,
    RENDER_SET_PICTURE_FILTER,
    RENDER_CREATE_ANIM_CURSOR,
    RENDER_ADD_TRAPS,
    RENDER_CREATE_SOLID_FILL,
    RENDER_CREATE_LINEAR_GRADIENT,
    RENDER_CREATE_RADIAL_GRADIENT,
    RENDER_CREATE_CONICAL_GRADIENT,
    LAST_SIGNAL
};
static guint signals[LAST_SIGNAL] = { 0 };

XigCodec *
xig_codec_new (void)
{
    return g_object_new (xig_codec_get_type (), NULL);
}

void
xig_codec_feed_data (XigCodec *codec, const guint8 *data, gsize data_length)
{
    XIG_CODEC_GET_CLASS (codec)->feed_data (codec, data, data_length);
}

void
xig_codec_feed_connect (XigCodec *codec, XigConnect *message)
{
    g_signal_emit (codec, signals[CONNECT], 0, message);
}

void
xig_codec_feed_failed (XigCodec *codec, XigFailed *message)
{
    g_signal_emit (codec, signals[FAILED], 0, message);
}

void
xig_codec_feed_authenticate (XigCodec *codec, XigAuthenticate *message)
{
    g_signal_emit (codec, signals[AUTHENTICATE], 0, message);
}

void
xig_codec_feed_success (XigCodec *codec, XigSuccess *message)
{
    g_signal_emit (codec, signals[SUCCESS], 0, message);
}

void
xig_codec_feed_error (XigCodec *codec, XigError *message)
{
    g_signal_emit (codec, signals[ERROR], 0, message);
}

void
xig_codec_feed_key_press (XigCodec *codec, XigKeyPress *message)
{
    g_signal_emit (codec, signals[KEY_PRESS], 0, message);
}

void
xig_codec_feed_button_press (XigCodec *codec, XigButtonPress *message)
{
    g_signal_emit (codec, signals[BUTTON_PRESS], 0, message);
}

void
xig_codec_feed_motion_notify (XigCodec *codec, XigMotionNotify *message)
{
    g_signal_emit (codec, signals[MOTION_NOTIFY], 0, message);
}

void
xig_codec_feed_enter_notify (XigCodec *codec, XigEnterNotify *message)
{
    g_signal_emit (codec, signals[ENTER_NOTIFY], 0, message);
}

void
xig_codec_feed_focus_in (XigCodec *codec, XigFocusIn *message)
{
    g_signal_emit (codec, signals[FOCUS_IN], 0, message);
}

void
xig_codec_feed_keymap_notify (XigCodec *codec, XigKeymapNotify *message)
{
    g_signal_emit (codec, signals[KEYMAP_NOTIFY], 0, message);
}

void
xig_codec_feed_expose (XigCodec *codec, XigExpose *message)
{
    g_signal_emit (codec, signals[EXPOSE], 0, message);
}

void
xig_codec_feed_graphics_exposure (XigCodec *codec, XigGraphicsExposure *message)
{
    g_signal_emit (codec, signals[GRAPHICS_EXPOSURE], 0, message);
}

void
xig_codec_feed_no_exposure (XigCodec *codec, XigNoExposure *message)
{
    g_signal_emit (codec, signals[NO_EXPOSURE], 0, message);
}

void
xig_codec_feed_visibility_notify (XigCodec *codec, XigVisibilityNotify *message)
{
    g_signal_emit (codec, signals[VISIBILITY_NOTIFY], 0, message);
}

void
xig_codec_feed_create_notify (XigCodec *codec, XigCreateNotify *message)
{
    g_signal_emit (codec, signals[CREATE_NOTIFY], 0, message);
}

void
xig_codec_feed_destroy_notify (XigCodec *codec, XigDestroyNotify *message)
{
    g_signal_emit (codec, signals[DESTROY_NOTIFY], 0, message);
}

void
xig_codec_feed_unmap_notify (XigCodec *codec, XigUnmapNotify *message)
{
    g_signal_emit (codec, signals[UNMAP_NOTIFY], 0, message);
}

void
xig_codec_feed_map_notify (XigCodec *codec, XigMapNotify *message)
{
    g_signal_emit (codec, signals[MAP_NOTIFY], 0, message);
}

void
xig_codec_feed_map_request (XigCodec *codec, XigMapRequest *message)
{
    g_signal_emit (codec, signals[MAP_REQUEST], 0, message);
}

void
xig_codec_feed_reparent_notify (XigCodec *codec, XigReparentNotify *message)
{
    g_signal_emit (codec, signals[REPARENT_NOTIFY], 0, message);
}

void
xig_codec_feed_configure_notify (XigCodec *codec, XigConfigureNotify *message)
{
    g_signal_emit (codec, signals[CONFIGURE_NOTIFY], 0, message);
}

void
xig_codec_feed_configure_request (XigCodec *codec, XigConfigureRequest *message)
{
    g_signal_emit (codec, signals[CONFIGURE_REQUEST], 0, message);
}

void
xig_codec_feed_gravity_notify (XigCodec *codec, XigGravityNotify *message)
{
    g_signal_emit (codec, signals[GRAVITY_NOTIFY], 0, message);
}

void
xig_codec_feed_resize_request (XigCodec *codec, XigResizeRequest *message)
{
    g_signal_emit (codec, signals[RESIZE_REQUEST], 0, message);
}

void
xig_codec_feed_circulate_notify (XigCodec *codec, XigCirculateNotify *message)
{
    g_signal_emit (codec, signals[CIRCULATE_NOTIFY], 0, message);
}

void
xig_codec_feed_circulate_request (XigCodec *codec, XigCirculateRequest *message)
{
    g_signal_emit (codec, signals[CIRCULATE_REQUEST], 0, message);
}

void
xig_codec_feed_property_notify (XigCodec *codec, XigPropertyNotify *message)
{
    g_signal_emit (codec, signals[PROPERTY_NOTIFY], 0, message);
}

void
xig_codec_feed_selection_clear (XigCodec *codec, XigSelectionClear *message)
{
    g_signal_emit (codec, signals[SELECTION_CLEAR], 0, message);
}

void
xig_codec_feed_selection_request (XigCodec *codec, XigSelectionRequest *message)
{
    g_signal_emit (codec, signals[SELECTION_REQUEST], 0, message);
}

void
xig_codec_feed_selection_notify (XigCodec *codec, XigSelectionNotify *message)
{
    g_signal_emit (codec, signals[SELECTION_NOTIFY], 0, message);
}

void
xig_codec_feed_colormap_notify (XigCodec *codec, XigColormapNotify *message)
{
    g_signal_emit (codec, signals[COLORMAP_NOTIFY], 0, message);
}

void
xig_codec_feed_client_message (XigCodec *codec, XigClientMessage *message)
{
    g_signal_emit (codec, signals[CLIENT_MESSAGE], 0, message);
}

void
xig_codec_feed_mapping_notify (XigCodec *codec, XigMappingNotify *message)
{
    g_signal_emit (codec, signals[MAPPING_NOTIFY], 0, message);
}

void
xig_codec_feed_create_window (XigCodec *codec, XigCreateWindow *message)
{
    g_signal_emit (codec, signals[CREATE_WINDOW], 0, message);
}

void
xig_codec_feed_change_window_attributes (XigCodec *codec, XigChangeWindowAttributes *message)
{
    g_signal_emit (codec, signals[CHANGE_WINDOW_ATTRIBUTES], 0, message);
}

void
xig_codec_feed_get_window_attributes (XigCodec *codec, XigGetWindowAttributes *message)
{
    g_signal_emit (codec, signals[GET_WINDOW_ATTRIBUTES], 0, message);
}

void
xig_codec_feed_get_window_attributes_reply (XigCodec *codec, XigGetWindowAttributesReply *message)
{
    g_signal_emit (codec, signals[GET_WINDOW_ATTRIBUTES_REPLY], 0, message);
}

void
xig_codec_feed_destroy_window (XigCodec *codec, XigDestroyWindow *message)
{
    g_signal_emit (codec, signals[DESTROY_WINDOW], 0, message);
}

void
xig_codec_feed_destroy_subwindows (XigCodec *codec, XigDestroySubwindows *message)
{
    g_signal_emit (codec, signals[DESTROY_SUBWINDOWS], 0, message);
}

void
xig_codec_feed_change_save_set (XigCodec *codec, XigChangeSaveSet *message)
{
    g_signal_emit (codec, signals[CHANGE_SAVE_SET], 0, message);
}

void
xig_codec_feed_reparent_window (XigCodec *codec, XigReparentWindow *message)
{
    g_signal_emit (codec, signals[REPARENT_WINDOW], 0, message);
}

void
xig_codec_feed_map_window (XigCodec *codec, XigMapWindow *message)
{
    g_signal_emit (codec, signals[MAP_WINDOW], 0, message);
}

void
xig_codec_feed_map_subwindows (XigCodec *codec, XigMapSubwindows *message)
{
    g_signal_emit (codec, signals[MAP_SUBWINDOWS], 0, message);
}

void
xig_codec_feed_unmap_window (XigCodec *codec, XigUnmapWindow *message)
{
    g_signal_emit (codec, signals[UNMAP_WINDOW], 0, message);
}

void
xig_codec_feed_unmap_subwindows (XigCodec *codec, XigUnmapSubwindows *message)
{
    g_signal_emit (codec, signals[UNMAP_SUBWINDOWS], 0, message);
}

void
xig_codec_feed_configure_window (XigCodec *codec, XigConfigureWindow *message)
{
    g_signal_emit (codec, signals[CONFIGURE_WINDOW], 0, message);
}

void
xig_codec_feed_circulate_window (XigCodec *codec, XigCirculateWindow *message)
{
    g_signal_emit (codec, signals[CIRCULATE_WINDOW], 0, message);
}

void
xig_codec_feed_get_geometry (XigCodec *codec, XigGetGeometry *message)
{
    g_signal_emit (codec, signals[GET_GEOMETRY], 0, message);
}

void
xig_codec_feed_get_geometry_reply (XigCodec *codec, XigGetGeometryReply *message)
{
    g_signal_emit (codec, signals[GET_GEOMETRY_REPLY], 0, message);
}

void
xig_codec_feed_query_tree (XigCodec *codec, XigQueryTree *message)
{
    g_signal_emit (codec, signals[QUERY_TREE], 0, message);
}

void
xig_codec_feed_query_tree_reply (XigCodec *codec, XigQueryTreeReply *message)
{
    g_signal_emit (codec, signals[QUERY_TREE_REPLY], 0, message);
}

void
xig_codec_feed_intern_atom (XigCodec *codec, XigInternAtom *message)
{
    g_signal_emit (codec, signals[INTERN_ATOM], 0, message);
}

void
xig_codec_feed_intern_atom_reply (XigCodec *codec, XigInternAtomReply *message)
{
    g_signal_emit (codec, signals[INTERN_ATOM_REPLY], 0, message);
}

void
xig_codec_feed_get_atom_name (XigCodec *codec, XigGetAtomName *message)
{
    g_signal_emit (codec, signals[GET_ATOM_NAME], 0, message);
}

void
xig_codec_feed_get_atom_name_reply (XigCodec *codec, XigGetAtomNameReply *message)
{
    g_signal_emit (codec, signals[GET_ATOM_NAME_REPLY], 0, message);
}

void
xig_codec_feed_change_property (XigCodec *codec, XigChangeProperty *message)
{
    g_signal_emit (codec, signals[CHANGE_PROPERTY], 0, message);
}

void
xig_codec_feed_delete_property (XigCodec *codec, XigDeleteProperty *message)
{
    g_signal_emit (codec, signals[DELETE_PROPERTY], 0, message);
}

void
xig_codec_feed_get_property (XigCodec *codec, XigGetProperty *message)
{
    g_signal_emit (codec, signals[GET_PROPERTY], 0, message);
}

void
xig_codec_feed_get_property_reply (XigCodec *codec, XigGetPropertyReply *message)
{
    g_signal_emit (codec, signals[GET_PROPERTY_REPLY], 0, message);
}

void
xig_codec_feed_list_properties (XigCodec *codec, XigListProperties *message)
{
    g_signal_emit (codec, signals[LIST_PROPERTIES], 0, message);
}

void
xig_codec_feed_list_properties_reply (XigCodec *codec, XigListPropertiesReply *message)
{
    g_signal_emit (codec, signals[LIST_PROPERTIES_REPLY], 0, message);
}

void
xig_codec_feed_set_selection_owner (XigCodec *codec, XigSetSelectionOwner *message)
{
    g_signal_emit (codec, signals[SET_SELECTION_OWNER], 0, message);
}

void
xig_codec_feed_get_selection_owner (XigCodec *codec, XigGetSelectionOwner *message)
{
    g_signal_emit (codec, signals[GET_SELECTION_OWNER], 0, message);
}

void
xig_codec_feed_get_selection_owner_reply (XigCodec *codec, XigGetSelectionOwnerReply *message)
{
    g_signal_emit (codec, signals[GET_SELECTION_OWNER_REPLY], 0, message);
}

void
xig_codec_feed_convert_selection (XigCodec *codec, XigConvertSelection *message)
{
    g_signal_emit (codec, signals[CONVERT_SELECTION], 0, message);
}

void
xig_codec_feed_send_event (XigCodec *codec, XigSendEvent *message)
{
    g_signal_emit (codec, signals[SEND_EVENT], 0, message);
}

void
xig_codec_feed_grab_pointer (XigCodec *codec, XigGrabPointer *message)
{
    g_signal_emit (codec, signals[GRAB_POINTER], 0, message);
}

void
xig_codec_feed_grab_pointer_reply (XigCodec *codec, XigGrabPointerReply *message)
{
    g_signal_emit (codec, signals[GRAB_POINTER_REPLY], 0, message);
}

void
xig_codec_feed_ungrab_pointer (XigCodec *codec, XigUngrabPointer *message)
{
    g_signal_emit (codec, signals[UNGRAB_POINTER], 0, message);
}

void
xig_codec_feed_grab_button (XigCodec *codec, XigGrabButton *message)
{
    g_signal_emit (codec, signals[GRAB_BUTTON], 0, message);
}

void
xig_codec_feed_ungrab_button (XigCodec *codec, XigUngrabButton *message)
{
    g_signal_emit (codec, signals[UNGRAB_BUTTON], 0, message);
}

void
xig_codec_feed_change_active_pointer_grab (XigCodec *codec, XigChangeActivePointerGrab *message)
{
    g_signal_emit (codec, signals[CHANGE_ACTIVE_POINTER_GRAB], 0, message);
}

void
xig_codec_feed_grab_keyboard (XigCodec *codec, XigGrabKeyboard *message)
{
    g_signal_emit (codec, signals[GRAB_KEYBOARD], 0, message);
}

void
xig_codec_feed_grab_keyboard_reply (XigCodec *codec, XigGrabKeyboardReply *message)
{
    g_signal_emit (codec, signals[GRAB_KEYBOARD_REPLY], 0, message);
}

void
xig_codec_feed_ungrab_keyboard (XigCodec *codec, XigUngrabKeyboard *message)
{
    g_signal_emit (codec, signals[UNGRAB_KEYBOARD], 0, message);
}

void
xig_codec_feed_grab_key (XigCodec *codec, XigGrabKey *message)
{
    g_signal_emit (codec, signals[GRAB_KEY], 0, message);
}

void
xig_codec_feed_ungrab_key (XigCodec *codec, XigUngrabKey *message)
{
    g_signal_emit (codec, signals[UNGRAB_KEY], 0, message);
}

void
xig_codec_feed_allow_events (XigCodec *codec, XigAllowEvents *message)
{
    g_signal_emit (codec, signals[ALLOW_EVENTS], 0, message);
}

void
xig_codec_feed_grab_server (XigCodec *codec, XigGrabServer *message)
{
    g_signal_emit (codec, signals[GRAB_SERVER], 0, message);
}

void
xig_codec_feed_ungrab_server (XigCodec *codec, XigUngrabServer *message)
{
    g_signal_emit (codec, signals[UNGRAB_SERVER], 0, message);
}

void
xig_codec_feed_query_pointer (XigCodec *codec, XigQueryPointer *message)
{
    g_signal_emit (codec, signals[QUERY_POINTER], 0, message);
}

void
xig_codec_feed_query_pointer_reply (XigCodec *codec, XigQueryPointerReply *message)
{
    g_signal_emit (codec, signals[QUERY_POINTER_REPLY], 0, message);
}

void
xig_codec_feed_get_motion_events (XigCodec *codec, XigGetMotionEvents *message)
{
    g_signal_emit (codec, signals[GET_MOTION_EVENTS], 0, message);
}

void
xig_codec_feed_get_motion_events_reply (XigCodec *codec, XigGetMotionEventsReply *message)
{
    g_signal_emit (codec, signals[GET_MOTION_EVENTS_REPLY], 0, message);
}

void
xig_codec_feed_translate_coordinates (XigCodec *codec, XigTranslateCoordinates *message)
{
    g_signal_emit (codec, signals[TRANSLATE_COORDINATES], 0, message);
}

void
xig_codec_feed_translate_coordinates_reply (XigCodec *codec, XigTranslateCoordinatesReply *message)
{
    g_signal_emit (codec, signals[TRANSLATE_COORDINATES_REPLY], 0, message);
}

void
xig_codec_feed_warp_pointer (XigCodec *codec, XigWarpPointer *message)
{
    g_signal_emit (codec, signals[WARP_POINTER], 0, message);
}

void
xig_codec_feed_set_input_focus (XigCodec *codec, XigSetInputFocus *message)
{
    g_signal_emit (codec, signals[SET_INPUT_FOCUS], 0, message);
}

void
xig_codec_feed_get_input_focus (XigCodec *codec, XigGetInputFocus *message)
{
    g_signal_emit (codec, signals[GET_INPUT_FOCUS], 0, message);
}

void
xig_codec_feed_get_input_focus_reply (XigCodec *codec, XigGetInputFocusReply *message)
{
    g_signal_emit (codec, signals[GET_INPUT_FOCUS_REPLY], 0, message);
}

void
xig_codec_feed_query_keymap (XigCodec *codec, XigQueryKeymap *message)
{
    g_signal_emit (codec, signals[QUERY_KEYMAP], 0, message);
}

void
xig_codec_feed_query_keymap_reply (XigCodec *codec, XigQueryKeymapReply *message)
{
    g_signal_emit (codec, signals[QUERY_KEYMAP_REPLY], 0, message);
}

void
xig_codec_feed_open_font (XigCodec *codec, XigOpenFont *message)
{
    g_signal_emit (codec, signals[OPEN_FONT], 0, message);
}

void
xig_codec_feed_close_font (XigCodec *codec, XigCloseFont *message)
{
    g_signal_emit (codec, signals[CLOSE_FONT], 0, message);
}

void
xig_codec_feed_query_font (XigCodec *codec, XigQueryFont *message)
{
    g_signal_emit (codec, signals[QUERY_FONT], 0, message);
}

void
xig_codec_feed_query_font_reply (XigCodec *codec, XigQueryFontReply *message)
{
    g_signal_emit (codec, signals[QUERY_FONT_REPLY], 0, message);
}

void
xig_codec_feed_query_text_extents (XigCodec *codec, XigQueryTextExtents *message)
{
    g_signal_emit (codec, signals[QUERY_TEXT_EXTENTS], 0, message);
}

void
xig_codec_feed_query_text_extents_reply (XigCodec *codec, XigQueryTextExtentsReply *message)
{
    g_signal_emit (codec, signals[QUERY_TEXT_EXTENTS_REPLY], 0, message);
}

void
xig_codec_feed_list_fonts (XigCodec *codec, XigListFonts *message)
{
    g_signal_emit (codec, signals[LIST_FONTS], 0, message);
}

void
xig_codec_feed_list_fonts_reply (XigCodec *codec, XigListFontsReply *message)
{
    g_signal_emit (codec, signals[LIST_FONTS_REPLY], 0, message);
}

void
xig_codec_feed_list_fonts_with_info (XigCodec *codec, XigListFontsWithInfo *message)
{
    g_signal_emit (codec, signals[LIST_FONTS_WITH_INFO], 0, message);
}

void
xig_codec_feed_list_fonts_with_info_reply (XigCodec *codec, XigListFontsWithInfoReply *message)
{
    g_signal_emit (codec, signals[LIST_FONTS_WITH_INFO_REPLY], 0, message);
}

void
xig_codec_feed_set_font_path (XigCodec *codec, XigSetFontPath *message)
{
    g_signal_emit (codec, signals[SET_FONT_PATH], 0, message);
}

void
xig_codec_feed_get_font_path (XigCodec *codec, XigGetFontPath *message)
{
    g_signal_emit (codec, signals[GET_FONT_PATH], 0, message);
}

void
xig_codec_feed_get_font_path_reply (XigCodec *codec, XigGetFontPathReply *message)
{
    g_signal_emit (codec, signals[GET_FONT_PATH_REPLY], 0, message);
}

void
xig_codec_feed_create_pixmap (XigCodec *codec, XigCreatePixmap *message)
{
    g_signal_emit (codec, signals[CREATE_PIXMAP], 0, message);
}

void
xig_codec_feed_free_pixmap (XigCodec *codec, XigFreePixmap *message)
{
    g_signal_emit (codec, signals[FREE_PIXMAP], 0, message);
}

void
xig_codec_feed_create_gc (XigCodec *codec, XigCreateGC *message)
{
    g_signal_emit (codec, signals[CREATE_GC], 0, message);
}

void
xig_codec_feed_change_gc (XigCodec *codec, XigChangeGC *message)
{
    g_signal_emit (codec, signals[CHANGE_GC], 0, message);
}

void
xig_codec_feed_copy_gc (XigCodec *codec, XigCopyGC *message)
{
    g_signal_emit (codec, signals[COPY_GC], 0, message);
}

void
xig_codec_feed_set_dashes (XigCodec *codec, XigSetDashes *message)
{
    g_signal_emit (codec, signals[SET_DASHES], 0, message);
}

void
xig_codec_feed_set_clip_rectangles (XigCodec *codec, XigSetClipRectangles *message)
{
    g_signal_emit (codec, signals[SET_CLIP_RECTANGLES], 0, message);
}

void
xig_codec_feed_free_gc (XigCodec *codec, XigFreeGC *message)
{
    g_signal_emit (codec, signals[FREE_GC], 0, message);
}

void
xig_codec_feed_clear_area (XigCodec *codec, XigClearArea *message)
{
    g_signal_emit (codec, signals[CLEAR_AREA], 0, message);
}

void
xig_codec_feed_copy_area (XigCodec *codec, XigCopyArea *message)
{
    g_signal_emit (codec, signals[COPY_AREA], 0, message);
}

void
xig_codec_feed_copy_plane (XigCodec *codec, XigCopyPlane *message)
{
    g_signal_emit (codec, signals[COPY_PLANE], 0, message);
}

void
xig_codec_feed_poly_point (XigCodec *codec, XigPolyPoint *message)
{
    g_signal_emit (codec, signals[POLY_POINT], 0, message);
}

void
xig_codec_feed_poly_line (XigCodec *codec, XigPolyLine *message)
{
    g_signal_emit (codec, signals[POLY_LINE], 0, message);
}

void
xig_codec_feed_poly_segment (XigCodec *codec, XigPolySegment *message)
{
    g_signal_emit (codec, signals[POLY_SEGMENT], 0, message);
}

void
xig_codec_feed_poly_rectangle (XigCodec *codec, XigPolyRectangle *message)
{
    g_signal_emit (codec, signals[POLY_RECTANGLE], 0, message);
}

void
xig_codec_feed_poly_arc (XigCodec *codec, XigPolyArc *message)
{
    g_signal_emit (codec, signals[POLY_ARC], 0, message);
}

void
xig_codec_feed_fill_poly (XigCodec *codec, XigFillPoly *message)
{
    g_signal_emit (codec, signals[FILL_POLY], 0, message);
}

void
xig_codec_feed_poly_fill_rectangle (XigCodec *codec, XigPolyFillRectangle *message)
{
    g_signal_emit (codec, signals[POLY_FILL_RECTANGLE], 0, message);
}

void
xig_codec_feed_poly_fill_arc (XigCodec *codec, XigPolyFillArc *message)
{
    g_signal_emit (codec, signals[POLY_FILL_ARC], 0, message);
}

void
xig_codec_feed_put_image (XigCodec *codec, XigPutImage *message)
{
    g_signal_emit (codec, signals[PUT_IMAGE], 0, message);
}

void
xig_codec_feed_get_image (XigCodec *codec, XigGetImage *message)
{
    g_signal_emit (codec, signals[GET_IMAGE], 0, message);
}

void
xig_codec_feed_get_image_reply (XigCodec *codec, XigGetImageReply *message)
{
    g_signal_emit (codec, signals[GET_IMAGE_REPLY], 0, message);
}

void
xig_codec_feed_poly_text8 (XigCodec *codec, XigPolyText8 *message)
{
    g_signal_emit (codec, signals[POLY_TEXT8], 0, message);
}

void
xig_codec_feed_poly_text16 (XigCodec *codec, XigPolyText16 *message)
{
    g_signal_emit (codec, signals[POLY_TEXT16], 0, message);
}

void
xig_codec_feed_image_text8 (XigCodec *codec, XigImageText8 *message)
{
    g_signal_emit (codec, signals[IMAGE_TEXT8], 0, message);
}

void
xig_codec_feed_image_text16 (XigCodec *codec, XigImageText16 *message)
{
    g_signal_emit (codec, signals[IMAGE_TEXT16], 0, message);
}

void
xig_codec_feed_create_colormap (XigCodec *codec, XigCreateColormap *message)
{
    g_signal_emit (codec, signals[CREATE_COLORMAP], 0, message);
}

void
xig_codec_feed_free_colormap (XigCodec *codec, XigFreeColormap *message)
{
    g_signal_emit (codec, signals[FREE_COLORMAP], 0, message);
}

void
xig_codec_feed_copy_colormap_and_free (XigCodec *codec, XigCopyColormapAndFree *message)
{
    g_signal_emit (codec, signals[COPY_COLORMAP_AND_FREE], 0, message);
}

void
xig_codec_feed_install_colormap (XigCodec *codec, XigInstallColormap *message)
{
    g_signal_emit (codec, signals[INSTALL_COLORMAP], 0, message);
}

void
xig_codec_feed_uninstall_colormap (XigCodec *codec, XigUninstallColormap *message)
{
    g_signal_emit (codec, signals[UNINSTALL_COLORMAP], 0, message);
}

void
xig_codec_feed_list_installed_colormaps (XigCodec *codec, XigListInstalledColormaps *message)
{
    g_signal_emit (codec, signals[LIST_INSTALLED_COLORMAPS], 0, message);
}

void
xig_codec_feed_list_installed_colormaps_reply (XigCodec *codec, XigListInstalledColormapsReply *message)
{
    g_signal_emit (codec, signals[LIST_INSTALLED_COLORMAPS_REPLY], 0, message);
}

void
xig_codec_feed_alloc_color (XigCodec *codec, XigAllocColor *message)
{
    g_signal_emit (codec, signals[ALLOC_COLOR], 0, message);
}

void
xig_codec_feed_alloc_color_reply (XigCodec *codec, XigAllocColorReply *message)
{
    g_signal_emit (codec, signals[ALLOC_COLOR_REPLY], 0, message);
}

void
xig_codec_feed_alloc_named_color (XigCodec *codec, XigAllocNamedColor *message)
{
    g_signal_emit (codec, signals[ALLOC_NAMED_COLOR], 0, message);
}

void
xig_codec_feed_alloc_named_color_reply (XigCodec *codec, XigAllocNamedColorReply *message)
{
    g_signal_emit (codec, signals[ALLOC_NAMED_COLOR_REPLY], 0, message);
}

void
xig_codec_feed_alloc_color_cells (XigCodec *codec, XigAllocColorCells *message)
{
    g_signal_emit (codec, signals[ALLOC_COLOR_CELLS], 0, message);
}

void
xig_codec_feed_alloc_color_cells_reply (XigCodec *codec, XigAllocColorCellsReply *message)
{
    g_signal_emit (codec, signals[ALLOC_COLOR_CELLS_REPLY], 0, message);
}

void
xig_codec_feed_alloc_color_planes (XigCodec *codec, XigAllocColorPlanes *message)
{
    g_signal_emit (codec, signals[ALLOC_COLOR_PLANES], 0, message);
}

void
xig_codec_feed_alloc_color_planes_reply (XigCodec *codec, XigAllocColorPlanesReply *message)
{
    g_signal_emit (codec, signals[ALLOC_COLOR_PLANES_REPLY], 0, message);
}

void
xig_codec_feed_free_colors (XigCodec *codec, XigFreeColors *message)
{
    g_signal_emit (codec, signals[FREE_COLORS], 0, message);
}

void
xig_codec_feed_store_colors (XigCodec *codec, XigStoreColors *message)
{
    g_signal_emit (codec, signals[STORE_COLORS], 0, message);
}

void
xig_codec_feed_store_named_color (XigCodec *codec, XigStoreNamedColor *message)
{
    g_signal_emit (codec, signals[STORE_NAMED_COLOR], 0, message);
}

void
xig_codec_feed_query_colors (XigCodec *codec, XigQueryColors *message)
{
    g_signal_emit (codec, signals[QUERY_COLORS], 0, message);
}

void
xig_codec_feed_query_colors_reply (XigCodec *codec, XigQueryColorsReply *message)
{
    g_signal_emit (codec, signals[QUERY_COLORS_REPLY], 0, message);
}

void
xig_codec_feed_lookup_color (XigCodec *codec, XigLookupColor *message)
{
    g_signal_emit (codec, signals[LOOKUP_COLOR], 0, message);
}

void
xig_codec_feed_lookup_color_reply (XigCodec *codec, XigLookupColorReply *message)
{
    g_signal_emit (codec, signals[LOOKUP_COLOR_REPLY], 0, message);
}

void
xig_codec_feed_create_cursor (XigCodec *codec, XigCreateCursor *message)
{
    g_signal_emit (codec, signals[CREATE_CURSOR], 0, message);
}

void
xig_codec_feed_create_glyph_cursor (XigCodec *codec, XigCreateGlyphCursor *message)
{
    g_signal_emit (codec, signals[CREATE_GLYPH_CURSOR], 0, message);
}

void
xig_codec_feed_free_cursor (XigCodec *codec, XigFreeCursor *message)
{
    g_signal_emit (codec, signals[FREE_CURSOR], 0, message);
}

void
xig_codec_feed_recolor_cursor (XigCodec *codec, XigRecolorCursor *message)
{
    g_signal_emit (codec, signals[RECOLOR_CURSOR], 0, message);
}

void
xig_codec_feed_query_best_size (XigCodec *codec, XigQueryBestSize *message)
{
    g_signal_emit (codec, signals[QUERY_BEST_SIZE], 0, message);
}

void
xig_codec_feed_query_best_size_reply (XigCodec *codec, XigQueryBestSizeReply *message)
{
    g_signal_emit (codec, signals[QUERY_BEST_SIZE_REPLY], 0, message);
}

void
xig_codec_feed_query_extension (XigCodec *codec, XigQueryExtension *message)
{
    g_signal_emit (codec, signals[QUERY_EXTENSION], 0, message);
}

void
xig_codec_feed_query_extension_reply (XigCodec *codec, XigQueryExtensionReply *message)
{
    g_signal_emit (codec, signals[QUERY_EXTENSION_REPLY], 0, message);
}

void
xig_codec_feed_list_extensions (XigCodec *codec, XigListExtensions *message)
{
    g_signal_emit (codec, signals[LIST_EXTENSIONS], 0, message);
}

void
xig_codec_feed_list_extensions_reply (XigCodec *codec, XigListExtensionsReply *message)
{
    g_signal_emit (codec, signals[LIST_EXTENSIONS_REPLY], 0, message);
}

void
xig_codec_feed_change_keyboard_mapping (XigCodec *codec, XigChangeKeyboardMapping *message)
{
    g_signal_emit (codec, signals[CHANGE_KEYBOARD_MAPPING], 0, message);
}

void
xig_codec_feed_get_keyboard_mapping (XigCodec *codec, XigGetKeyboardMapping *message)
{
    g_signal_emit (codec, signals[GET_KEYBOARD_MAPPING], 0, message);
}

void
xig_codec_feed_get_keyboard_mapping_reply (XigCodec *codec, XigGetKeyboardMappingReply *message)
{
    g_signal_emit (codec, signals[GET_KEYBOARD_MAPPING_REPLY], 0, message);
}

void
xig_codec_feed_change_keyboard_control (XigCodec *codec, XigChangeKeyboardControl *message)
{
    g_signal_emit (codec, signals[CHANGE_KEYBOARD_CONTROL], 0, message);
}

void
xig_codec_feed_get_keyboard_control (XigCodec *codec, XigGetKeyboardControl *message)
{
    g_signal_emit (codec, signals[GET_KEYBOARD_CONTROL], 0, message);
}

void
xig_codec_feed_get_keyboard_control_reply (XigCodec *codec, XigGetKeyboardControlReply *message)
{
    g_signal_emit (codec, signals[GET_KEYBOARD_CONTROL_REPLY], 0, message);
}

void
xig_codec_feed_bell (XigCodec *codec, XigBell *message)
{
    g_signal_emit (codec, signals[BELL], 0, message);
}

void
xig_codec_feed_change_pointer_control (XigCodec *codec, XigChangePointerControl *message)
{
    g_signal_emit (codec, signals[CHANGE_POINTER_CONTROL], 0, message);
}

void
xig_codec_feed_get_pointer_control (XigCodec *codec, XigGetPointerControl *message)
{
    g_signal_emit (codec, signals[GET_POINTER_CONTROL], 0, message);
}

void
xig_codec_feed_get_pointer_control_reply (XigCodec *codec, XigGetPointerControlReply *message)
{
    g_signal_emit (codec, signals[GET_POINTER_CONTROL_REPLY], 0, message);
}

void
xig_codec_feed_set_screen_saver (XigCodec *codec, XigSetScreenSaver *message)
{
    g_signal_emit (codec, signals[SET_SCREEN_SAVER], 0, message);
}

void
xig_codec_feed_get_screen_saver (XigCodec *codec, XigGetScreenSaver *message)
{
    g_signal_emit (codec, signals[GET_SCREEN_SAVER], 0, message);
}

void
xig_codec_feed_get_screen_saver_reply (XigCodec *codec, XigGetScreenSaverReply *message)
{
    g_signal_emit (codec, signals[GET_SCREEN_SAVER_REPLY], 0, message);
}

void
xig_codec_feed_change_hosts (XigCodec *codec, XigChangeHosts *message)
{
    g_signal_emit (codec, signals[CHANGE_HOSTS], 0, message);
}

void
xig_codec_feed_list_hosts (XigCodec *codec, XigListHosts *message)
{
    g_signal_emit (codec, signals[LIST_HOSTS], 0, message);
}

void
xig_codec_feed_list_hosts_reply (XigCodec *codec, XigListHostsReply *message)
{
    g_signal_emit (codec, signals[LIST_HOSTS_REPLY], 0, message);
}

void
xig_codec_feed_set_access_control (XigCodec *codec, XigSetAccessControl *message)
{
    g_signal_emit (codec, signals[SET_ACCESS_CONTROL], 0, message);
}

void
xig_codec_feed_set_close_down_mode (XigCodec *codec, XigSetCloseDownMode *message)
{
    g_signal_emit (codec, signals[SET_CLOSE_DOWN_MODE], 0, message);
}

void
xig_codec_feed_kill_client (XigCodec *codec, XigKillClient *message)
{
    g_signal_emit (codec, signals[KILL_CLIENT], 0, message);
}

void
xig_codec_feed_rotate_properties (XigCodec *codec, XigRotateProperties *message)
{
    g_signal_emit (codec, signals[ROTATE_PROPERTIES], 0, message);
}

void
xig_codec_feed_force_screen_saver (XigCodec *codec, XigForceScreenSaver *message)
{
    g_signal_emit (codec, signals[FORCE_SCREEN_SAVER], 0, message);
}

void
xig_codec_feed_set_pointer_mapping (XigCodec *codec, XigSetPointerMapping *message)
{
    g_signal_emit (codec, signals[SET_POINTER_MAPPING], 0, message);
}

void
xig_codec_feed_set_pointer_mapping_reply (XigCodec *codec, XigSetPointerMappingReply *message)
{
    g_signal_emit (codec, signals[SET_POINTER_MAPPING_REPLY], 0, message);
}

void
xig_codec_feed_get_pointer_mapping (XigCodec *codec, XigGetPointerMapping *message)
{
    g_signal_emit (codec, signals[GET_POINTER_MAPPING], 0, message);
}

void
xig_codec_feed_get_pointer_mapping_reply (XigCodec *codec, XigGetPointerMappingReply *message)
{
    g_signal_emit (codec, signals[GET_POINTER_MAPPING_REPLY], 0, message);
}

void
xig_codec_feed_set_modifier_mapping (XigCodec *codec, XigSetModifierMapping *message)
{
    g_signal_emit (codec, signals[SET_MODIFIER_MAPPING], 0, message);
}

void
xig_codec_feed_set_modifier_mapping_reply (XigCodec *codec, XigSetModifierMappingReply *message)
{
    g_signal_emit (codec, signals[SET_MODIFIER_MAPPING_REPLY], 0, message);
}

void
xig_codec_feed_get_modifier_mapping (XigCodec *codec, XigGetModifierMapping *message)
{
    g_signal_emit (codec, signals[GET_MODIFIER_MAPPING], 0, message);
}

void
xig_codec_feed_get_modifier_mapping_reply (XigCodec *codec, XigGetModifierMappingReply *message)
{
    g_signal_emit (codec, signals[GET_MODIFIER_MAPPING_REPLY], 0, message);
}

void
xig_codec_feed_no_operation (XigCodec *codec, XigNoOperation *message)
{
    g_signal_emit (codec, signals[NO_OPERATION], 0, message);
}

void
xig_codec_feed_BIGREQ_enable (XigCodec *codec, XigBIGREQEnable *message)
{
    g_signal_emit (codec, signals[BIGREQ_ENABLE], 0, message);
}

void
xig_codec_feed_BIGREQ_enable_reply (XigCodec *codec, XigBIGREQEnableReply *message)
{
    g_signal_emit (codec, signals[BIGREQ_ENABLE_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_counter_notify (XigCodec *codec, XigSYNCCounterNotify *message)
{
    g_signal_emit (codec, signals[SYNC_COUNTER_NOTIFY], 0, message);
}

void
xig_codec_feed_SYNC_alarm_notify (XigCodec *codec, XigSYNCAlarmNotify *message)
{
    g_signal_emit (codec, signals[SYNC_ALARM_NOTIFY], 0, message);
}

void
xig_codec_feed_SYNC_initialize (XigCodec *codec, XigSYNCInitialize *message)
{
    g_signal_emit (codec, signals[SYNC_INITIALIZE], 0, message);
}

void
xig_codec_feed_SYNC_initialize_reply (XigCodec *codec, XigSYNCInitializeReply *message)
{
    g_signal_emit (codec, signals[SYNC_INITIALIZE_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_list_system_counters (XigCodec *codec, XigSYNCListSystemCounters *message)
{
    g_signal_emit (codec, signals[SYNC_LIST_SYSTEM_COUNTERS], 0, message);
}

void
xig_codec_feed_SYNC_list_system_counters_reply (XigCodec *codec, XigSYNCListSystemCountersReply *message)
{
    g_signal_emit (codec, signals[SYNC_LIST_SYSTEM_COUNTERS_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_create_counter (XigCodec *codec, XigSYNCCreateCounter *message)
{
    g_signal_emit (codec, signals[SYNC_CREATE_COUNTER], 0, message);
}

void
xig_codec_feed_SYNC_destroy_counter (XigCodec *codec, XigSYNCDestroyCounter *message)
{
    g_signal_emit (codec, signals[SYNC_DESTROY_COUNTER], 0, message);
}

void
xig_codec_feed_SYNC_query_counter (XigCodec *codec, XigSYNCQueryCounter *message)
{
    g_signal_emit (codec, signals[SYNC_QUERY_COUNTER], 0, message);
}

void
xig_codec_feed_SYNC_query_counter_reply (XigCodec *codec, XigSYNCQueryCounterReply *message)
{
    g_signal_emit (codec, signals[SYNC_QUERY_COUNTER_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_await (XigCodec *codec, XigSYNCAwait *message)
{
    g_signal_emit (codec, signals[SYNC_AWAIT], 0, message);
}

void
xig_codec_feed_SYNC_change_counter (XigCodec *codec, XigSYNCChangeCounter *message)
{
    g_signal_emit (codec, signals[SYNC_CHANGE_COUNTER], 0, message);
}

void
xig_codec_feed_SYNC_set_counter (XigCodec *codec, XigSYNCSetCounter *message)
{
    g_signal_emit (codec, signals[SYNC_SET_COUNTER], 0, message);
}

void
xig_codec_feed_SYNC_create_alarm (XigCodec *codec, XigSYNCCreateAlarm *message)
{
    g_signal_emit (codec, signals[SYNC_CREATE_ALARM], 0, message);
}

void
xig_codec_feed_SYNC_change_alarm (XigCodec *codec, XigSYNCChangeAlarm *message)
{
    g_signal_emit (codec, signals[SYNC_CHANGE_ALARM], 0, message);
}

void
xig_codec_feed_SYNC_destroy_alarm (XigCodec *codec, XigSYNCDestroyAlarm *message)
{
    g_signal_emit (codec, signals[SYNC_DESTROY_ALARM], 0, message);
}

void
xig_codec_feed_SYNC_query_alarm (XigCodec *codec, XigSYNCQueryAlarm *message)
{
    g_signal_emit (codec, signals[SYNC_QUERY_ALARM], 0, message);
}

void
xig_codec_feed_SYNC_query_alarm_reply (XigCodec *codec, XigSYNCQueryAlarmReply *message)
{
    g_signal_emit (codec, signals[SYNC_QUERY_ALARM_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_set_priority (XigCodec *codec, XigSYNCSetPriority *message)
{
    g_signal_emit (codec, signals[SYNC_SET_PRIORITY], 0, message);
}

void
xig_codec_feed_SYNC_get_priority (XigCodec *codec, XigSYNCGetPriority *message)
{
    g_signal_emit (codec, signals[SYNC_GET_PRIORITY], 0, message);
}

void
xig_codec_feed_SYNC_get_priority_reply (XigCodec *codec, XigSYNCGetPriorityReply *message)
{
    g_signal_emit (codec, signals[SYNC_GET_PRIORITY_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_create_fence (XigCodec *codec, XigSYNCCreateFence *message)
{
    g_signal_emit (codec, signals[SYNC_CREATE_FENCE], 0, message);
}

void
xig_codec_feed_SYNC_trigger_fence (XigCodec *codec, XigSYNCTriggerFence *message)
{
    g_signal_emit (codec, signals[SYNC_TRIGGER_FENCE], 0, message);
}

void
xig_codec_feed_SYNC_reset_fence (XigCodec *codec, XigSYNCResetFence *message)
{
    g_signal_emit (codec, signals[SYNC_RESET_FENCE], 0, message);
}

void
xig_codec_feed_SYNC_destroy_fence (XigCodec *codec, XigSYNCDestroyFence *message)
{
    g_signal_emit (codec, signals[SYNC_DESTROY_FENCE], 0, message);
}

void
xig_codec_feed_SYNC_query_fence (XigCodec *codec, XigSYNCQueryFence *message)
{
    g_signal_emit (codec, signals[SYNC_QUERY_FENCE], 0, message);
}

void
xig_codec_feed_SYNC_query_fence_reply (XigCodec *codec, XigSYNCQueryFenceReply *message)
{
    g_signal_emit (codec, signals[SYNC_QUERY_FENCE_REPLY], 0, message);
}

void
xig_codec_feed_SYNC_await_fence (XigCodec *codec, XigSYNCAwaitFence *message)
{
    g_signal_emit (codec, signals[SYNC_AWAIT_FENCE], 0, message);
}

void
xig_codec_feed_RANDR_screen_change_notify (XigCodec *codec, XigRANDRScreenChangeNotify *message)
{
    g_signal_emit (codec, signals[RANDR_SCREEN_CHANGE_NOTIFY], 0, message);
}

void
xig_codec_feed_RANDR_notify (XigCodec *codec, XigRANDRNotify *message)
{
    g_signal_emit (codec, signals[RANDR_NOTIFY], 0, message);
}

void
xig_codec_feed_RANDR_query_version (XigCodec *codec, XigRANDRQueryVersion *message)
{
    g_signal_emit (codec, signals[RANDR_QUERY_VERSION], 0, message);
}

void
xig_codec_feed_RANDR_query_version_reply (XigCodec *codec, XigRANDRQueryVersionReply *message)
{
    g_signal_emit (codec, signals[RANDR_QUERY_VERSION_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_screen_config (XigCodec *codec, XigRANDRSetScreenConfig *message)
{
    g_signal_emit (codec, signals[RANDR_SET_SCREEN_CONFIG], 0, message);
}

void
xig_codec_feed_RANDR_set_screen_config_reply (XigCodec *codec, XigRANDRSetScreenConfigReply *message)
{
    g_signal_emit (codec, signals[RANDR_SET_SCREEN_CONFIG_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_select_input (XigCodec *codec, XigRANDRSelectInput *message)
{
    g_signal_emit (codec, signals[RANDR_SELECT_INPUT], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_info (XigCodec *codec, XigRANDRGetScreenInfo *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_INFO], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_info_reply (XigCodec *codec, XigRANDRGetScreenInfoReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_INFO_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_size_range (XigCodec *codec, XigRANDRGetScreenSizeRange *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_SIZE_RANGE], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_size_range_reply (XigCodec *codec, XigRANDRGetScreenSizeRangeReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_SIZE_RANGE_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_screen_size (XigCodec *codec, XigRANDRSetScreenSize *message)
{
    g_signal_emit (codec, signals[RANDR_SET_SCREEN_SIZE], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_resources (XigCodec *codec, XigRANDRGetScreenResources *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_RESOURCES], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_resources_reply (XigCodec *codec, XigRANDRGetScreenResourcesReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_RESOURCES_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_get_output_info (XigCodec *codec, XigRANDRGetOutputInfo *message)
{
    g_signal_emit (codec, signals[RANDR_GET_OUTPUT_INFO], 0, message);
}

void
xig_codec_feed_RANDR_get_output_info_reply (XigCodec *codec, XigRANDRGetOutputInfoReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_OUTPUT_INFO_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_list_output_properties (XigCodec *codec, XigRANDRListOutputProperties *message)
{
    g_signal_emit (codec, signals[RANDR_LIST_OUTPUT_PROPERTIES], 0, message);
}

void
xig_codec_feed_RANDR_list_output_properties_reply (XigCodec *codec, XigRANDRListOutputPropertiesReply *message)
{
    g_signal_emit (codec, signals[RANDR_LIST_OUTPUT_PROPERTIES_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_query_output_property (XigCodec *codec, XigRANDRQueryOutputProperty *message)
{
    g_signal_emit (codec, signals[RANDR_QUERY_OUTPUT_PROPERTY], 0, message);
}

void
xig_codec_feed_RANDR_query_output_property_reply (XigCodec *codec, XigRANDRQueryOutputPropertyReply *message)
{
    g_signal_emit (codec, signals[RANDR_QUERY_OUTPUT_PROPERTY_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_configure_output_property (XigCodec *codec, XigRANDRConfigureOutputProperty *message)
{
    g_signal_emit (codec, signals[RANDR_CONFIGURE_OUTPUT_PROPERTY], 0, message);
}

void
xig_codec_feed_RANDR_change_output_property (XigCodec *codec, XigRANDRChangeOutputProperty *message)
{
    g_signal_emit (codec, signals[RANDR_CHANGE_OUTPUT_PROPERTY], 0, message);
}

void
xig_codec_feed_RANDR_delete_output_property (XigCodec *codec, XigRANDRDeleteOutputProperty *message)
{
    g_signal_emit (codec, signals[RANDR_DELETE_OUTPUT_PROPERTY], 0, message);
}

void
xig_codec_feed_RANDR_get_output_property (XigCodec *codec, XigRANDRGetOutputProperty *message)
{
    g_signal_emit (codec, signals[RANDR_GET_OUTPUT_PROPERTY], 0, message);
}

void
xig_codec_feed_RANDR_get_output_property_reply (XigCodec *codec, XigRANDRGetOutputPropertyReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_OUTPUT_PROPERTY_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_create_mode (XigCodec *codec, XigRANDRCreateMode *message)
{
    g_signal_emit (codec, signals[RANDR_CREATE_MODE], 0, message);
}

void
xig_codec_feed_RANDR_create_mode_reply (XigCodec *codec, XigRANDRCreateModeReply *message)
{
    g_signal_emit (codec, signals[RANDR_CREATE_MODE_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_destroy_mode (XigCodec *codec, XigRANDRDestroyMode *message)
{
    g_signal_emit (codec, signals[RANDR_DESTROY_MODE], 0, message);
}

void
xig_codec_feed_RANDR_add_output_mode (XigCodec *codec, XigRANDRAddOutputMode *message)
{
    g_signal_emit (codec, signals[RANDR_ADD_OUTPUT_MODE], 0, message);
}

void
xig_codec_feed_RANDR_delete_output_mode (XigCodec *codec, XigRANDRDeleteOutputMode *message)
{
    g_signal_emit (codec, signals[RANDR_DELETE_OUTPUT_MODE], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_info (XigCodec *codec, XigRANDRGetCrtcInfo *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_INFO], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_info_reply (XigCodec *codec, XigRANDRGetCrtcInfoReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_INFO_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_crtc_config (XigCodec *codec, XigRANDRSetCrtcConfig *message)
{
    g_signal_emit (codec, signals[RANDR_SET_CRTC_CONFIG], 0, message);
}

void
xig_codec_feed_RANDR_set_crtc_config_reply (XigCodec *codec, XigRANDRSetCrtcConfigReply *message)
{
    g_signal_emit (codec, signals[RANDR_SET_CRTC_CONFIG_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_gamma_size (XigCodec *codec, XigRANDRGetCrtcGammaSize *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_GAMMA_SIZE], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_gamma_size_reply (XigCodec *codec, XigRANDRGetCrtcGammaSizeReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_GAMMA_SIZE_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_gamma (XigCodec *codec, XigRANDRGetCrtcGamma *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_GAMMA], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_gamma_reply (XigCodec *codec, XigRANDRGetCrtcGammaReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_GAMMA_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_crtc_gamma (XigCodec *codec, XigRANDRSetCrtcGamma *message)
{
    g_signal_emit (codec, signals[RANDR_SET_CRTC_GAMMA], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_resources_current (XigCodec *codec, XigRANDRGetScreenResourcesCurrent *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_RESOURCES_CURRENT], 0, message);
}

void
xig_codec_feed_RANDR_get_screen_resources_current_reply (XigCodec *codec, XigRANDRGetScreenResourcesCurrentReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_SCREEN_RESOURCES_CURRENT_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_crtc_transform (XigCodec *codec, XigRANDRSetCrtcTransform *message)
{
    g_signal_emit (codec, signals[RANDR_SET_CRTC_TRANSFORM], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_transform (XigCodec *codec, XigRANDRGetCrtcTransform *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_TRANSFORM], 0, message);
}

void
xig_codec_feed_RANDR_get_crtc_transform_reply (XigCodec *codec, XigRANDRGetCrtcTransformReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_CRTC_TRANSFORM_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_get_panning (XigCodec *codec, XigRANDRGetPanning *message)
{
    g_signal_emit (codec, signals[RANDR_GET_PANNING], 0, message);
}

void
xig_codec_feed_RANDR_get_panning_reply (XigCodec *codec, XigRANDRGetPanningReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_PANNING_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_panning (XigCodec *codec, XigRANDRSetPanning *message)
{
    g_signal_emit (codec, signals[RANDR_SET_PANNING], 0, message);
}

void
xig_codec_feed_RANDR_set_panning_reply (XigCodec *codec, XigRANDRSetPanningReply *message)
{
    g_signal_emit (codec, signals[RANDR_SET_PANNING_REPLY], 0, message);
}

void
xig_codec_feed_RANDR_set_output_primary (XigCodec *codec, XigRANDRSetOutputPrimary *message)
{
    g_signal_emit (codec, signals[RANDR_SET_OUTPUT_PRIMARY], 0, message);
}

void
xig_codec_feed_RANDR_get_output_primary (XigCodec *codec, XigRANDRGetOutputPrimary *message)
{
    g_signal_emit (codec, signals[RANDR_GET_OUTPUT_PRIMARY], 0, message);
}

void
xig_codec_feed_RANDR_get_output_primary_reply (XigCodec *codec, XigRANDRGetOutputPrimaryReply *message)
{
    g_signal_emit (codec, signals[RANDR_GET_OUTPUT_PRIMARY_REPLY], 0, message);
}

void
xig_codec_feed_XINERAMA_query_version (XigCodec *codec, XigXINERAMAQueryVersion *message)
{
    g_signal_emit (codec, signals[XINERAMA_QUERY_VERSION], 0, message);
}

void
xig_codec_feed_XINERAMA_query_version_reply (XigCodec *codec, XigXINERAMAQueryVersionReply *message)
{
    g_signal_emit (codec, signals[XINERAMA_QUERY_VERSION_REPLY], 0, message);
}

void
xig_codec_feed_XINERAMA_get_state (XigCodec *codec, XigXINERAMAGetState *message)
{
    g_signal_emit (codec, signals[XINERAMA_GET_STATE], 0, message);
}

void
xig_codec_feed_XINERAMA_get_state_reply (XigCodec *codec, XigXINERAMAGetStateReply *message)
{
    g_signal_emit (codec, signals[XINERAMA_GET_STATE_REPLY], 0, message);
}

void
xig_codec_feed_XINERAMA_get_screen_count (XigCodec *codec, XigXINERAMAGetScreenCount *message)
{
    g_signal_emit (codec, signals[XINERAMA_GET_SCREEN_COUNT], 0, message);
}

void
xig_codec_feed_XINERAMA_get_screen_count_reply (XigCodec *codec, XigXINERAMAGetScreenCountReply *message)
{
    g_signal_emit (codec, signals[XINERAMA_GET_SCREEN_COUNT_REPLY], 0, message);
}

void
xig_codec_feed_XINERAMA_get_screen_size (XigCodec *codec, XigXINERAMAGetScreenSize *message)
{
    g_signal_emit (codec, signals[XINERAMA_GET_SCREEN_SIZE], 0, message);
}

void
xig_codec_feed_XINERAMA_get_screen_size_reply (XigCodec *codec, XigXINERAMAGetScreenSizeReply *message)
{
    g_signal_emit (codec, signals[XINERAMA_GET_SCREEN_SIZE_REPLY], 0, message);
}

void
xig_codec_feed_XINERAMA_is_active (XigCodec *codec, XigXINERAMAIsActive *message)
{
    g_signal_emit (codec, signals[XINERAMA_IS_ACTIVE], 0, message);
}

void
xig_codec_feed_XINERAMA_is_active_reply (XigCodec *codec, XigXINERAMAIsActiveReply *message)
{
    g_signal_emit (codec, signals[XINERAMA_IS_ACTIVE_REPLY], 0, message);
}

void
xig_codec_feed_XINERAMA_query_screens (XigCodec *codec, XigXINERAMAQueryScreens *message)
{
    g_signal_emit (codec, signals[XINERAMA_QUERY_SCREENS], 0, message);
}

void
xig_codec_feed_XINERAMA_query_screens_reply (XigCodec *codec, XigXINERAMAQueryScreensReply *message)
{
    g_signal_emit (codec, signals[XINERAMA_QUERY_SCREENS_REPLY], 0, message);
}

void
xig_codec_feed_XKB_new_keyboard_notify (XigCodec *codec, XigXKBNewKeyboardNotify *message)
{
    g_signal_emit (codec, signals[XKB_NEW_KEYBOARD_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_map_notify (XigCodec *codec, XigXKBMapNotify *message)
{
    g_signal_emit (codec, signals[XKB_MAP_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_state_notify (XigCodec *codec, XigXKBStateNotify *message)
{
    g_signal_emit (codec, signals[XKB_STATE_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_controls_notify (XigCodec *codec, XigXKBControlsNotify *message)
{
    g_signal_emit (codec, signals[XKB_CONTROLS_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_indicator_state_notify (XigCodec *codec, XigXKBIndicatorStateNotify *message)
{
    g_signal_emit (codec, signals[XKB_INDICATOR_STATE_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_indicator_map_notify (XigCodec *codec, XigXKBIndicatorMapNotify *message)
{
    g_signal_emit (codec, signals[XKB_INDICATOR_MAP_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_names_notify (XigCodec *codec, XigXKBNamesNotify *message)
{
    g_signal_emit (codec, signals[XKB_NAMES_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_compat_map_notify (XigCodec *codec, XigXKBCompatMapNotify *message)
{
    g_signal_emit (codec, signals[XKB_COMPAT_MAP_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_bell_notify (XigCodec *codec, XigXKBBellNotify *message)
{
    g_signal_emit (codec, signals[XKB_BELL_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_action_message (XigCodec *codec, XigXKBActionMessage *message)
{
    g_signal_emit (codec, signals[XKB_ACTION_MESSAGE], 0, message);
}

void
xig_codec_feed_XKB_access_xnotify (XigCodec *codec, XigXKBAccessXNotify *message)
{
    g_signal_emit (codec, signals[XKB_ACCESS_XNOTIFY], 0, message);
}

void
xig_codec_feed_XKB_extension_device_notify (XigCodec *codec, XigXKBExtensionDeviceNotify *message)
{
    g_signal_emit (codec, signals[XKB_EXTENSION_DEVICE_NOTIFY], 0, message);
}

void
xig_codec_feed_XKB_use_extension (XigCodec *codec, XigXKBUseExtension *message)
{
    g_signal_emit (codec, signals[XKB_USE_EXTENSION], 0, message);
}

void
xig_codec_feed_XKB_use_extension_reply (XigCodec *codec, XigXKBUseExtensionReply *message)
{
    g_signal_emit (codec, signals[XKB_USE_EXTENSION_REPLY], 0, message);
}

void
xig_codec_feed_XKB_select_events (XigCodec *codec, XigXKBSelectEvents *message)
{
    g_signal_emit (codec, signals[XKB_SELECT_EVENTS], 0, message);
}

void
xig_codec_feed_XKB_bell (XigCodec *codec, XigXKBBell *message)
{
    g_signal_emit (codec, signals[XKB_BELL], 0, message);
}

void
xig_codec_feed_XKB_get_state (XigCodec *codec, XigXKBGetState *message)
{
    g_signal_emit (codec, signals[XKB_GET_STATE], 0, message);
}

void
xig_codec_feed_XKB_get_state_reply (XigCodec *codec, XigXKBGetStateReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_STATE_REPLY], 0, message);
}

void
xig_codec_feed_XKB_latch_lock_state (XigCodec *codec, XigXKBLatchLockState *message)
{
    g_signal_emit (codec, signals[XKB_LATCH_LOCK_STATE], 0, message);
}

void
xig_codec_feed_XKB_get_controls (XigCodec *codec, XigXKBGetControls *message)
{
    g_signal_emit (codec, signals[XKB_GET_CONTROLS], 0, message);
}

void
xig_codec_feed_XKB_get_controls_reply (XigCodec *codec, XigXKBGetControlsReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_CONTROLS_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_controls (XigCodec *codec, XigXKBSetControls *message)
{
    g_signal_emit (codec, signals[XKB_SET_CONTROLS], 0, message);
}

void
xig_codec_feed_XKB_get_map (XigCodec *codec, XigXKBGetMap *message)
{
    g_signal_emit (codec, signals[XKB_GET_MAP], 0, message);
}

void
xig_codec_feed_XKB_get_map_reply (XigCodec *codec, XigXKBGetMapReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_MAP_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_map (XigCodec *codec, XigXKBSetMap *message)
{
    g_signal_emit (codec, signals[XKB_SET_MAP], 0, message);
}

void
xig_codec_feed_XKB_get_compat_map (XigCodec *codec, XigXKBGetCompatMap *message)
{
    g_signal_emit (codec, signals[XKB_GET_COMPAT_MAP], 0, message);
}

void
xig_codec_feed_XKB_get_compat_map_reply (XigCodec *codec, XigXKBGetCompatMapReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_COMPAT_MAP_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_compat_map (XigCodec *codec, XigXKBSetCompatMap *message)
{
    g_signal_emit (codec, signals[XKB_SET_COMPAT_MAP], 0, message);
}

void
xig_codec_feed_XKB_get_indicator_state (XigCodec *codec, XigXKBGetIndicatorState *message)
{
    g_signal_emit (codec, signals[XKB_GET_INDICATOR_STATE], 0, message);
}

void
xig_codec_feed_XKB_get_indicator_state_reply (XigCodec *codec, XigXKBGetIndicatorStateReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_INDICATOR_STATE_REPLY], 0, message);
}

void
xig_codec_feed_XKB_get_indicator_map (XigCodec *codec, XigXKBGetIndicatorMap *message)
{
    g_signal_emit (codec, signals[XKB_GET_INDICATOR_MAP], 0, message);
}

void
xig_codec_feed_XKB_get_indicator_map_reply (XigCodec *codec, XigXKBGetIndicatorMapReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_INDICATOR_MAP_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_indicator_map (XigCodec *codec, XigXKBSetIndicatorMap *message)
{
    g_signal_emit (codec, signals[XKB_SET_INDICATOR_MAP], 0, message);
}

void
xig_codec_feed_XKB_get_named_indicator (XigCodec *codec, XigXKBGetNamedIndicator *message)
{
    g_signal_emit (codec, signals[XKB_GET_NAMED_INDICATOR], 0, message);
}

void
xig_codec_feed_XKB_get_named_indicator_reply (XigCodec *codec, XigXKBGetNamedIndicatorReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_NAMED_INDICATOR_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_named_indicator (XigCodec *codec, XigXKBSetNamedIndicator *message)
{
    g_signal_emit (codec, signals[XKB_SET_NAMED_INDICATOR], 0, message);
}

void
xig_codec_feed_XKB_get_names (XigCodec *codec, XigXKBGetNames *message)
{
    g_signal_emit (codec, signals[XKB_GET_NAMES], 0, message);
}

void
xig_codec_feed_XKB_get_names_reply (XigCodec *codec, XigXKBGetNamesReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_NAMES_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_names (XigCodec *codec, XigXKBSetNames *message)
{
    g_signal_emit (codec, signals[XKB_SET_NAMES], 0, message);
}

void
xig_codec_feed_XKB_get_geometry (XigCodec *codec, XigXKBGetGeometry *message)
{
    g_signal_emit (codec, signals[XKB_GET_GEOMETRY], 0, message);
}

void
xig_codec_feed_XKB_get_geometry_reply (XigCodec *codec, XigXKBGetGeometryReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_GEOMETRY_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_geometry (XigCodec *codec, XigXKBSetGeometry *message)
{
    g_signal_emit (codec, signals[XKB_SET_GEOMETRY], 0, message);
}

void
xig_codec_feed_XKB_per_client_flags (XigCodec *codec, XigXKBPerClientFlags *message)
{
    g_signal_emit (codec, signals[XKB_PER_CLIENT_FLAGS], 0, message);
}

void
xig_codec_feed_XKB_per_client_flags_reply (XigCodec *codec, XigXKBPerClientFlagsReply *message)
{
    g_signal_emit (codec, signals[XKB_PER_CLIENT_FLAGS_REPLY], 0, message);
}

void
xig_codec_feed_XKB_list_components (XigCodec *codec, XigXKBListComponents *message)
{
    g_signal_emit (codec, signals[XKB_LIST_COMPONENTS], 0, message);
}

void
xig_codec_feed_XKB_list_components_reply (XigCodec *codec, XigXKBListComponentsReply *message)
{
    g_signal_emit (codec, signals[XKB_LIST_COMPONENTS_REPLY], 0, message);
}

void
xig_codec_feed_XKB_get_kbd_by_name (XigCodec *codec, XigXKBGetKbdByName *message)
{
    g_signal_emit (codec, signals[XKB_GET_KBD_BY_NAME], 0, message);
}

void
xig_codec_feed_XKB_get_kbd_by_name_reply (XigCodec *codec, XigXKBGetKbdByNameReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_KBD_BY_NAME_REPLY], 0, message);
}

void
xig_codec_feed_XKB_get_device_info (XigCodec *codec, XigXKBGetDeviceInfo *message)
{
    g_signal_emit (codec, signals[XKB_GET_DEVICE_INFO], 0, message);
}

void
xig_codec_feed_XKB_get_device_info_reply (XigCodec *codec, XigXKBGetDeviceInfoReply *message)
{
    g_signal_emit (codec, signals[XKB_GET_DEVICE_INFO_REPLY], 0, message);
}

void
xig_codec_feed_XKB_set_device_info (XigCodec *codec, XigXKBSetDeviceInfo *message)
{
    g_signal_emit (codec, signals[XKB_SET_DEVICE_INFO], 0, message);
}

void
xig_codec_feed_XKB_set_debugging_flags (XigCodec *codec, XigXKBSetDebuggingFlags *message)
{
    g_signal_emit (codec, signals[XKB_SET_DEBUGGING_FLAGS], 0, message);
}

void
xig_codec_feed_XKB_set_debugging_flags_reply (XigCodec *codec, XigXKBSetDebuggingFlagsReply *message)
{
    g_signal_emit (codec, signals[XKB_SET_DEBUGGING_FLAGS_REPLY], 0, message);
}

void
xig_codec_feed_RENDER_query_version (XigCodec *codec, XigRENDERQueryVersion *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_VERSION], 0, message);
}

void
xig_codec_feed_RENDER_query_version_reply (XigCodec *codec, XigRENDERQueryVersionReply *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_VERSION_REPLY], 0, message);
}

void
xig_codec_feed_RENDER_query_pict_formats (XigCodec *codec, XigRENDERQueryPictFormats *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_PICT_FORMATS], 0, message);
}

void
xig_codec_feed_RENDER_query_pict_formats_reply (XigCodec *codec, XigRENDERQueryPictFormatsReply *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_PICT_FORMATS_REPLY], 0, message);
}

void
xig_codec_feed_RENDER_query_pict_index_values (XigCodec *codec, XigRENDERQueryPictIndexValues *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_PICT_INDEX_VALUES], 0, message);
}

void
xig_codec_feed_RENDER_query_pict_index_values_reply (XigCodec *codec, XigRENDERQueryPictIndexValuesReply *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_PICT_INDEX_VALUES_REPLY], 0, message);
}

void
xig_codec_feed_RENDER_create_picture (XigCodec *codec, XigRENDERCreatePicture *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_PICTURE], 0, message);
}

void
xig_codec_feed_RENDER_change_picture (XigCodec *codec, XigRENDERChangePicture *message)
{
    g_signal_emit (codec, signals[RENDER_CHANGE_PICTURE], 0, message);
}

void
xig_codec_feed_RENDER_set_picture_clip_rectangles (XigCodec *codec, XigRENDERSetPictureClipRectangles *message)
{
    g_signal_emit (codec, signals[RENDER_SET_PICTURE_CLIP_RECTANGLES], 0, message);
}

void
xig_codec_feed_RENDER_free_picture (XigCodec *codec, XigRENDERFreePicture *message)
{
    g_signal_emit (codec, signals[RENDER_FREE_PICTURE], 0, message);
}

void
xig_codec_feed_RENDER_composite (XigCodec *codec, XigRENDERComposite *message)
{
    g_signal_emit (codec, signals[RENDER_COMPOSITE], 0, message);
}

void
xig_codec_feed_RENDER_trapezoids (XigCodec *codec, XigRENDERTrapezoids *message)
{
    g_signal_emit (codec, signals[RENDER_TRAPEZOIDS], 0, message);
}

void
xig_codec_feed_RENDER_triangles (XigCodec *codec, XigRENDERTriangles *message)
{
    g_signal_emit (codec, signals[RENDER_TRIANGLES], 0, message);
}

void
xig_codec_feed_RENDER_tri_strip (XigCodec *codec, XigRENDERTriStrip *message)
{
    g_signal_emit (codec, signals[RENDER_TRI_STRIP], 0, message);
}

void
xig_codec_feed_RENDER_tri_fan (XigCodec *codec, XigRENDERTriFan *message)
{
    g_signal_emit (codec, signals[RENDER_TRI_FAN], 0, message);
}

void
xig_codec_feed_RENDER_create_glyph_set (XigCodec *codec, XigRENDERCreateGlyphSet *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_GLYPH_SET], 0, message);
}

void
xig_codec_feed_RENDER_reference_glyph_set (XigCodec *codec, XigRENDERReferenceGlyphSet *message)
{
    g_signal_emit (codec, signals[RENDER_REFERENCE_GLYPH_SET], 0, message);
}

void
xig_codec_feed_RENDER_free_glyph_set (XigCodec *codec, XigRENDERFreeGlyphSet *message)
{
    g_signal_emit (codec, signals[RENDER_FREE_GLYPH_SET], 0, message);
}

void
xig_codec_feed_RENDER_add_glyphs (XigCodec *codec, XigRENDERAddGlyphs *message)
{
    g_signal_emit (codec, signals[RENDER_ADD_GLYPHS], 0, message);
}

void
xig_codec_feed_RENDER_free_glyphs (XigCodec *codec, XigRENDERFreeGlyphs *message)
{
    g_signal_emit (codec, signals[RENDER_FREE_GLYPHS], 0, message);
}

void
xig_codec_feed_RENDER_composite_glyphs8 (XigCodec *codec, XigRENDERCompositeGlyphs8 *message)
{
    g_signal_emit (codec, signals[RENDER_COMPOSITE_GLYPHS8], 0, message);
}

void
xig_codec_feed_RENDER_composite_glyphs16 (XigCodec *codec, XigRENDERCompositeGlyphs16 *message)
{
    g_signal_emit (codec, signals[RENDER_COMPOSITE_GLYPHS16], 0, message);
}

void
xig_codec_feed_RENDER_composite_glyphs32 (XigCodec *codec, XigRENDERCompositeGlyphs32 *message)
{
    g_signal_emit (codec, signals[RENDER_COMPOSITE_GLYPHS32], 0, message);
}

void
xig_codec_feed_RENDER_fill_rectangles (XigCodec *codec, XigRENDERFillRectangles *message)
{
    g_signal_emit (codec, signals[RENDER_FILL_RECTANGLES], 0, message);
}

void
xig_codec_feed_RENDER_create_cursor (XigCodec *codec, XigRENDERCreateCursor *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_CURSOR], 0, message);
}

void
xig_codec_feed_RENDER_set_picture_transform (XigCodec *codec, XigRENDERSetPictureTransform *message)
{
    g_signal_emit (codec, signals[RENDER_SET_PICTURE_TRANSFORM], 0, message);
}

void
xig_codec_feed_RENDER_query_filters (XigCodec *codec, XigRENDERQueryFilters *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_FILTERS], 0, message);
}

void
xig_codec_feed_RENDER_query_filters_reply (XigCodec *codec, XigRENDERQueryFiltersReply *message)
{
    g_signal_emit (codec, signals[RENDER_QUERY_FILTERS_REPLY], 0, message);
}

void
xig_codec_feed_RENDER_set_picture_filter (XigCodec *codec, XigRENDERSetPictureFilter *message)
{
    g_signal_emit (codec, signals[RENDER_SET_PICTURE_FILTER], 0, message);
}

void
xig_codec_feed_RENDER_create_anim_cursor (XigCodec *codec, XigRENDERCreateAnimCursor *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_ANIM_CURSOR], 0, message);
}

void
xig_codec_feed_RENDER_add_traps (XigCodec *codec, XigRENDERAddTraps *message)
{
    g_signal_emit (codec, signals[RENDER_ADD_TRAPS], 0, message);
}

void
xig_codec_feed_RENDER_create_solid_fill (XigCodec *codec, XigRENDERCreateSolidFill *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_SOLID_FILL], 0, message);
}

void
xig_codec_feed_RENDER_create_linear_gradient (XigCodec *codec, XigRENDERCreateLinearGradient *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_LINEAR_GRADIENT], 0, message);
}

void
xig_codec_feed_RENDER_create_radial_gradient (XigCodec *codec, XigRENDERCreateRadialGradient *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_RADIAL_GRADIENT], 0, message);
}

void
xig_codec_feed_RENDER_create_conical_gradient (XigCodec *codec, XigRENDERCreateConicalGradient *message)
{
    g_signal_emit (codec, signals[RENDER_CREATE_CONICAL_GRADIENT], 0, message);
}

static void
xig_codec_real_feed_data (XigCodec *codec, const guint8 *data, gsize data_length)
{
}

static void
xig_codec_real_write (XigCodec *codec, const guint8 *data, gsize data_length)
{
}

static void
xig_codec_init (XigCodec *codec)
{
}

static void
xig_codec_class_init (XigCodecClass *klass)
{
    klass->feed_data = xig_codec_real_feed_data;
    klass->write = xig_codec_real_write;

    signals[CONNECT] =
        g_signal_new ("connect",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, connect),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FAILED] =
        g_signal_new ("failed",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, failed),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[AUTHENTICATE] =
        g_signal_new ("authenticate",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, authenticate),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SUCCESS] =
        g_signal_new ("success",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, success),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ERROR] =
        g_signal_new ("error",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, error),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[KEY_PRESS] =
        g_signal_new ("key-press",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, key_press),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[BUTTON_PRESS] =
        g_signal_new ("button-press",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, button_press),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[MOTION_NOTIFY] =
        g_signal_new ("motion-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, motion_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ENTER_NOTIFY] =
        g_signal_new ("enter-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, enter_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FOCUS_IN] =
        g_signal_new ("focus-in",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, focus_in),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[KEYMAP_NOTIFY] =
        g_signal_new ("keymap-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, keymap_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[EXPOSE] =
        g_signal_new ("expose",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, expose),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAPHICS_EXPOSURE] =
        g_signal_new ("graphics-exposure",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, graphics_exposure),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[NO_EXPOSURE] =
        g_signal_new ("no-exposure",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, no_exposure),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[VISIBILITY_NOTIFY] =
        g_signal_new ("visibility-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, visibility_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_NOTIFY] =
        g_signal_new ("create-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[DESTROY_NOTIFY] =
        g_signal_new ("destroy-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, destroy_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNMAP_NOTIFY] =
        g_signal_new ("unmap-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, unmap_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[MAP_NOTIFY] =
        g_signal_new ("map-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, map_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[MAP_REQUEST] =
        g_signal_new ("map-request",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, map_request),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[REPARENT_NOTIFY] =
        g_signal_new ("reparent-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, reparent_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CONFIGURE_NOTIFY] =
        g_signal_new ("configure-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, configure_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CONFIGURE_REQUEST] =
        g_signal_new ("configure-request",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, configure_request),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAVITY_NOTIFY] =
        g_signal_new ("gravity-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, gravity_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RESIZE_REQUEST] =
        g_signal_new ("resize-request",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, resize_request),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CIRCULATE_NOTIFY] =
        g_signal_new ("circulate-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, circulate_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CIRCULATE_REQUEST] =
        g_signal_new ("circulate-request",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, circulate_request),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[PROPERTY_NOTIFY] =
        g_signal_new ("property-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, property_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SELECTION_CLEAR] =
        g_signal_new ("selection-clear",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, selection_clear),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SELECTION_REQUEST] =
        g_signal_new ("selection-request",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, selection_request),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SELECTION_NOTIFY] =
        g_signal_new ("selection-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, selection_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[COLORMAP_NOTIFY] =
        g_signal_new ("colormap-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, colormap_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CLIENT_MESSAGE] =
        g_signal_new ("client-message",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, client_message),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[MAPPING_NOTIFY] =
        g_signal_new ("mapping-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, mapping_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_WINDOW] =
        g_signal_new ("create-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_WINDOW_ATTRIBUTES] =
        g_signal_new ("change-window-attributes",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_window_attributes),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_WINDOW_ATTRIBUTES] =
        g_signal_new ("get-window-attributes",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_window_attributes),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_WINDOW_ATTRIBUTES_REPLY] =
        g_signal_new ("get-window-attributes-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_window_attributes_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[DESTROY_WINDOW] =
        g_signal_new ("destroy-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, destroy_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[DESTROY_SUBWINDOWS] =
        g_signal_new ("destroy-subwindows",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, destroy_subwindows),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_SAVE_SET] =
        g_signal_new ("change-save-set",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_save_set),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[REPARENT_WINDOW] =
        g_signal_new ("reparent-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, reparent_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[MAP_WINDOW] =
        g_signal_new ("map-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, map_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[MAP_SUBWINDOWS] =
        g_signal_new ("map-subwindows",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, map_subwindows),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNMAP_WINDOW] =
        g_signal_new ("unmap-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, unmap_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNMAP_SUBWINDOWS] =
        g_signal_new ("unmap-subwindows",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, unmap_subwindows),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CONFIGURE_WINDOW] =
        g_signal_new ("configure-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, configure_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CIRCULATE_WINDOW] =
        g_signal_new ("circulate-window",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, circulate_window),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_GEOMETRY] =
        g_signal_new ("get-geometry",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_geometry),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_GEOMETRY_REPLY] =
        g_signal_new ("get-geometry-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_geometry_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_TREE] =
        g_signal_new ("query-tree",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_tree),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_TREE_REPLY] =
        g_signal_new ("query-tree-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_tree_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[INTERN_ATOM] =
        g_signal_new ("intern-atom",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, intern_atom),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[INTERN_ATOM_REPLY] =
        g_signal_new ("intern-atom-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, intern_atom_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_ATOM_NAME] =
        g_signal_new ("get-atom-name",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_atom_name),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_ATOM_NAME_REPLY] =
        g_signal_new ("get-atom-name-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_atom_name_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_PROPERTY] =
        g_signal_new ("change-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[DELETE_PROPERTY] =
        g_signal_new ("delete-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, delete_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_PROPERTY] =
        g_signal_new ("get-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_PROPERTY_REPLY] =
        g_signal_new ("get-property-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_property_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_PROPERTIES] =
        g_signal_new ("list-properties",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_properties),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_PROPERTIES_REPLY] =
        g_signal_new ("list-properties-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_properties_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_SELECTION_OWNER] =
        g_signal_new ("set-selection-owner",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_selection_owner),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_SELECTION_OWNER] =
        g_signal_new ("get-selection-owner",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_selection_owner),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_SELECTION_OWNER_REPLY] =
        g_signal_new ("get-selection-owner-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_selection_owner_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CONVERT_SELECTION] =
        g_signal_new ("convert-selection",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, convert_selection),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SEND_EVENT] =
        g_signal_new ("send-event",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, send_event),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_POINTER] =
        g_signal_new ("grab-pointer",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_pointer),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_POINTER_REPLY] =
        g_signal_new ("grab-pointer-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_pointer_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNGRAB_POINTER] =
        g_signal_new ("ungrab-pointer",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, ungrab_pointer),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_BUTTON] =
        g_signal_new ("grab-button",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_button),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNGRAB_BUTTON] =
        g_signal_new ("ungrab-button",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, ungrab_button),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_ACTIVE_POINTER_GRAB] =
        g_signal_new ("change-active-pointer-grab",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_active_pointer_grab),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_KEYBOARD] =
        g_signal_new ("grab-keyboard",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_keyboard),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_KEYBOARD_REPLY] =
        g_signal_new ("grab-keyboard-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_keyboard_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNGRAB_KEYBOARD] =
        g_signal_new ("ungrab-keyboard",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, ungrab_keyboard),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_KEY] =
        g_signal_new ("grab-key",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_key),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNGRAB_KEY] =
        g_signal_new ("ungrab-key",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, ungrab_key),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOW_EVENTS] =
        g_signal_new ("allow-events",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, allow_events),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GRAB_SERVER] =
        g_signal_new ("grab-server",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, grab_server),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNGRAB_SERVER] =
        g_signal_new ("ungrab-server",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, ungrab_server),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_POINTER] =
        g_signal_new ("query-pointer",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_pointer),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_POINTER_REPLY] =
        g_signal_new ("query-pointer-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_pointer_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_MOTION_EVENTS] =
        g_signal_new ("get-motion-events",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_motion_events),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_MOTION_EVENTS_REPLY] =
        g_signal_new ("get-motion-events-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_motion_events_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[TRANSLATE_COORDINATES] =
        g_signal_new ("translate-coordinates",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, translate_coordinates),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[TRANSLATE_COORDINATES_REPLY] =
        g_signal_new ("translate-coordinates-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, translate_coordinates_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[WARP_POINTER] =
        g_signal_new ("warp-pointer",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, warp_pointer),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_INPUT_FOCUS] =
        g_signal_new ("set-input-focus",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_input_focus),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_INPUT_FOCUS] =
        g_signal_new ("get-input-focus",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_input_focus),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_INPUT_FOCUS_REPLY] =
        g_signal_new ("get-input-focus-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_input_focus_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_KEYMAP] =
        g_signal_new ("query-keymap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_keymap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_KEYMAP_REPLY] =
        g_signal_new ("query-keymap-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_keymap_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[OPEN_FONT] =
        g_signal_new ("open-font",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, open_font),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CLOSE_FONT] =
        g_signal_new ("close-font",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, close_font),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_FONT] =
        g_signal_new ("query-font",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_font),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_FONT_REPLY] =
        g_signal_new ("query-font-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_font_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_TEXT_EXTENTS] =
        g_signal_new ("query-text-extents",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_text_extents),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_TEXT_EXTENTS_REPLY] =
        g_signal_new ("query-text-extents-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_text_extents_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_FONTS] =
        g_signal_new ("list-fonts",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_fonts),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_FONTS_REPLY] =
        g_signal_new ("list-fonts-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_fonts_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_FONTS_WITH_INFO] =
        g_signal_new ("list-fonts-with-info",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_fonts_with_info),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_FONTS_WITH_INFO_REPLY] =
        g_signal_new ("list-fonts-with-info-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_fonts_with_info_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_FONT_PATH] =
        g_signal_new ("set-font-path",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_font_path),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_FONT_PATH] =
        g_signal_new ("get-font-path",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_font_path),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_FONT_PATH_REPLY] =
        g_signal_new ("get-font-path-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_font_path_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_PIXMAP] =
        g_signal_new ("create-pixmap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_pixmap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FREE_PIXMAP] =
        g_signal_new ("free-pixmap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, free_pixmap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_GC] =
        g_signal_new ("create-gc",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_gc),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_GC] =
        g_signal_new ("change-gc",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_gc),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[COPY_GC] =
        g_signal_new ("copy-gc",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, copy_gc),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_DASHES] =
        g_signal_new ("set-dashes",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_dashes),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_CLIP_RECTANGLES] =
        g_signal_new ("set-clip-rectangles",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_clip_rectangles),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FREE_GC] =
        g_signal_new ("free-gc",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, free_gc),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CLEAR_AREA] =
        g_signal_new ("clear-area",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, clear_area),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[COPY_AREA] =
        g_signal_new ("copy-area",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, copy_area),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[COPY_PLANE] =
        g_signal_new ("copy-plane",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, copy_plane),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_POINT] =
        g_signal_new ("poly-point",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_point),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_LINE] =
        g_signal_new ("poly-line",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_line),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_SEGMENT] =
        g_signal_new ("poly-segment",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_segment),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_RECTANGLE] =
        g_signal_new ("poly-rectangle",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_rectangle),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_ARC] =
        g_signal_new ("poly-arc",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_arc),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FILL_POLY] =
        g_signal_new ("fill-poly",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, fill_poly),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_FILL_RECTANGLE] =
        g_signal_new ("poly-fill-rectangle",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_fill_rectangle),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_FILL_ARC] =
        g_signal_new ("poly-fill-arc",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_fill_arc),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[PUT_IMAGE] =
        g_signal_new ("put-image",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, put_image),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_IMAGE] =
        g_signal_new ("get-image",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_image),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_IMAGE_REPLY] =
        g_signal_new ("get-image-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_image_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_TEXT8] =
        g_signal_new ("poly-text8",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_text8),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[POLY_TEXT16] =
        g_signal_new ("poly-text16",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, poly_text16),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[IMAGE_TEXT8] =
        g_signal_new ("image-text8",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, image_text8),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[IMAGE_TEXT16] =
        g_signal_new ("image-text16",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, image_text16),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_COLORMAP] =
        g_signal_new ("create-colormap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_colormap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FREE_COLORMAP] =
        g_signal_new ("free-colormap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, free_colormap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[COPY_COLORMAP_AND_FREE] =
        g_signal_new ("copy-colormap-and-free",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, copy_colormap_and_free),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[INSTALL_COLORMAP] =
        g_signal_new ("install-colormap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, install_colormap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[UNINSTALL_COLORMAP] =
        g_signal_new ("uninstall-colormap",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, uninstall_colormap),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_INSTALLED_COLORMAPS] =
        g_signal_new ("list-installed-colormaps",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_installed_colormaps),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_INSTALLED_COLORMAPS_REPLY] =
        g_signal_new ("list-installed-colormaps-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_installed_colormaps_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_COLOR] =
        g_signal_new ("alloc-color",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_color),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_COLOR_REPLY] =
        g_signal_new ("alloc-color-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_color_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_NAMED_COLOR] =
        g_signal_new ("alloc-named-color",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_named_color),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_NAMED_COLOR_REPLY] =
        g_signal_new ("alloc-named-color-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_named_color_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_COLOR_CELLS] =
        g_signal_new ("alloc-color-cells",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_color_cells),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_COLOR_CELLS_REPLY] =
        g_signal_new ("alloc-color-cells-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_color_cells_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_COLOR_PLANES] =
        g_signal_new ("alloc-color-planes",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_color_planes),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ALLOC_COLOR_PLANES_REPLY] =
        g_signal_new ("alloc-color-planes-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, alloc_color_planes_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FREE_COLORS] =
        g_signal_new ("free-colors",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, free_colors),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[STORE_COLORS] =
        g_signal_new ("store-colors",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, store_colors),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[STORE_NAMED_COLOR] =
        g_signal_new ("store-named-color",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, store_named_color),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_COLORS] =
        g_signal_new ("query-colors",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_colors),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_COLORS_REPLY] =
        g_signal_new ("query-colors-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_colors_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LOOKUP_COLOR] =
        g_signal_new ("lookup-color",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, lookup_color),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LOOKUP_COLOR_REPLY] =
        g_signal_new ("lookup-color-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, lookup_color_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_CURSOR] =
        g_signal_new ("create-cursor",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_cursor),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CREATE_GLYPH_CURSOR] =
        g_signal_new ("create-glyph-cursor",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, create_glyph_cursor),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FREE_CURSOR] =
        g_signal_new ("free-cursor",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, free_cursor),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RECOLOR_CURSOR] =
        g_signal_new ("recolor-cursor",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, recolor_cursor),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_BEST_SIZE] =
        g_signal_new ("query-best-size",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_best_size),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_BEST_SIZE_REPLY] =
        g_signal_new ("query-best-size-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_best_size_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_EXTENSION] =
        g_signal_new ("query-extension",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_extension),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[QUERY_EXTENSION_REPLY] =
        g_signal_new ("query-extension-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, query_extension_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_EXTENSIONS] =
        g_signal_new ("list-extensions",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_extensions),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_EXTENSIONS_REPLY] =
        g_signal_new ("list-extensions-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_extensions_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_KEYBOARD_MAPPING] =
        g_signal_new ("change-keyboard-mapping",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_keyboard_mapping),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_KEYBOARD_MAPPING] =
        g_signal_new ("get-keyboard-mapping",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_keyboard_mapping),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_KEYBOARD_MAPPING_REPLY] =
        g_signal_new ("get-keyboard-mapping-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_keyboard_mapping_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_KEYBOARD_CONTROL] =
        g_signal_new ("change-keyboard-control",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_keyboard_control),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_KEYBOARD_CONTROL] =
        g_signal_new ("get-keyboard-control",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_keyboard_control),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_KEYBOARD_CONTROL_REPLY] =
        g_signal_new ("get-keyboard-control-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_keyboard_control_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[BELL] =
        g_signal_new ("bell",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, bell),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_POINTER_CONTROL] =
        g_signal_new ("change-pointer-control",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_pointer_control),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_POINTER_CONTROL] =
        g_signal_new ("get-pointer-control",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_pointer_control),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_POINTER_CONTROL_REPLY] =
        g_signal_new ("get-pointer-control-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_pointer_control_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_SCREEN_SAVER] =
        g_signal_new ("set-screen-saver",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_screen_saver),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_SCREEN_SAVER] =
        g_signal_new ("get-screen-saver",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_screen_saver),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_SCREEN_SAVER_REPLY] =
        g_signal_new ("get-screen-saver-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_screen_saver_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[CHANGE_HOSTS] =
        g_signal_new ("change-hosts",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, change_hosts),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_HOSTS] =
        g_signal_new ("list-hosts",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_hosts),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[LIST_HOSTS_REPLY] =
        g_signal_new ("list-hosts-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, list_hosts_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_ACCESS_CONTROL] =
        g_signal_new ("set-access-control",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_access_control),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_CLOSE_DOWN_MODE] =
        g_signal_new ("set-close-down-mode",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_close_down_mode),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[KILL_CLIENT] =
        g_signal_new ("kill-client",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, kill_client),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[ROTATE_PROPERTIES] =
        g_signal_new ("rotate-properties",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, rotate_properties),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[FORCE_SCREEN_SAVER] =
        g_signal_new ("force-screen-saver",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, force_screen_saver),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_POINTER_MAPPING] =
        g_signal_new ("set-pointer-mapping",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_pointer_mapping),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_POINTER_MAPPING_REPLY] =
        g_signal_new ("set-pointer-mapping-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_pointer_mapping_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_POINTER_MAPPING] =
        g_signal_new ("get-pointer-mapping",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_pointer_mapping),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_POINTER_MAPPING_REPLY] =
        g_signal_new ("get-pointer-mapping-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_pointer_mapping_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_MODIFIER_MAPPING] =
        g_signal_new ("set-modifier-mapping",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_modifier_mapping),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SET_MODIFIER_MAPPING_REPLY] =
        g_signal_new ("set-modifier-mapping-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, set_modifier_mapping_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_MODIFIER_MAPPING] =
        g_signal_new ("get-modifier-mapping",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_modifier_mapping),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[GET_MODIFIER_MAPPING_REPLY] =
        g_signal_new ("get-modifier-mapping-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, get_modifier_mapping_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[NO_OPERATION] =
        g_signal_new ("no-operation",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, no_operation),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[BIGREQ_ENABLE] =
        g_signal_new ("BIGREQ-enable",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, BIGREQ_enable),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[BIGREQ_ENABLE_REPLY] =
        g_signal_new ("BIGREQ-enable-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, BIGREQ_enable_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_COUNTER_NOTIFY] =
        g_signal_new ("SYNC-counter-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_counter_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_ALARM_NOTIFY] =
        g_signal_new ("SYNC-alarm-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_alarm_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_INITIALIZE] =
        g_signal_new ("SYNC-initialize",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_initialize),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_INITIALIZE_REPLY] =
        g_signal_new ("SYNC-initialize-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_initialize_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_LIST_SYSTEM_COUNTERS] =
        g_signal_new ("SYNC-list-system-counters",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_list_system_counters),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_LIST_SYSTEM_COUNTERS_REPLY] =
        g_signal_new ("SYNC-list-system-counters-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_list_system_counters_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_CREATE_COUNTER] =
        g_signal_new ("SYNC-create-counter",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_create_counter),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_DESTROY_COUNTER] =
        g_signal_new ("SYNC-destroy-counter",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_destroy_counter),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_QUERY_COUNTER] =
        g_signal_new ("SYNC-query-counter",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_query_counter),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_QUERY_COUNTER_REPLY] =
        g_signal_new ("SYNC-query-counter-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_query_counter_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_AWAIT] =
        g_signal_new ("SYNC-await",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_await),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_CHANGE_COUNTER] =
        g_signal_new ("SYNC-change-counter",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_change_counter),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_SET_COUNTER] =
        g_signal_new ("SYNC-set-counter",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_set_counter),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_CREATE_ALARM] =
        g_signal_new ("SYNC-create-alarm",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_create_alarm),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_CHANGE_ALARM] =
        g_signal_new ("SYNC-change-alarm",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_change_alarm),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_DESTROY_ALARM] =
        g_signal_new ("SYNC-destroy-alarm",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_destroy_alarm),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_QUERY_ALARM] =
        g_signal_new ("SYNC-query-alarm",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_query_alarm),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_QUERY_ALARM_REPLY] =
        g_signal_new ("SYNC-query-alarm-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_query_alarm_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_SET_PRIORITY] =
        g_signal_new ("SYNC-set-priority",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_set_priority),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_GET_PRIORITY] =
        g_signal_new ("SYNC-get-priority",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_get_priority),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_GET_PRIORITY_REPLY] =
        g_signal_new ("SYNC-get-priority-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_get_priority_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_CREATE_FENCE] =
        g_signal_new ("SYNC-create-fence",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_create_fence),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_TRIGGER_FENCE] =
        g_signal_new ("SYNC-trigger-fence",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_trigger_fence),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_RESET_FENCE] =
        g_signal_new ("SYNC-reset-fence",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_reset_fence),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_DESTROY_FENCE] =
        g_signal_new ("SYNC-destroy-fence",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_destroy_fence),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_QUERY_FENCE] =
        g_signal_new ("SYNC-query-fence",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_query_fence),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_QUERY_FENCE_REPLY] =
        g_signal_new ("SYNC-query-fence-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_query_fence_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[SYNC_AWAIT_FENCE] =
        g_signal_new ("SYNC-await-fence",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, SYNC_await_fence),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SCREEN_CHANGE_NOTIFY] =
        g_signal_new ("RANDR-screen-change-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_screen_change_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_NOTIFY] =
        g_signal_new ("RANDR-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_QUERY_VERSION] =
        g_signal_new ("RANDR-query-version",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_query_version),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_QUERY_VERSION_REPLY] =
        g_signal_new ("RANDR-query-version-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_query_version_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_SCREEN_CONFIG] =
        g_signal_new ("RANDR-set-screen-config",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_screen_config),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_SCREEN_CONFIG_REPLY] =
        g_signal_new ("RANDR-set-screen-config-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_screen_config_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SELECT_INPUT] =
        g_signal_new ("RANDR-select-input",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_select_input),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_INFO] =
        g_signal_new ("RANDR-get-screen-info",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_info),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_INFO_REPLY] =
        g_signal_new ("RANDR-get-screen-info-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_info_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_SIZE_RANGE] =
        g_signal_new ("RANDR-get-screen-size-range",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_size_range),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_SIZE_RANGE_REPLY] =
        g_signal_new ("RANDR-get-screen-size-range-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_size_range_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_SCREEN_SIZE] =
        g_signal_new ("RANDR-set-screen-size",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_screen_size),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_RESOURCES] =
        g_signal_new ("RANDR-get-screen-resources",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_resources),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_RESOURCES_REPLY] =
        g_signal_new ("RANDR-get-screen-resources-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_resources_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_OUTPUT_INFO] =
        g_signal_new ("RANDR-get-output-info",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_output_info),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_OUTPUT_INFO_REPLY] =
        g_signal_new ("RANDR-get-output-info-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_output_info_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_LIST_OUTPUT_PROPERTIES] =
        g_signal_new ("RANDR-list-output-properties",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_list_output_properties),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_LIST_OUTPUT_PROPERTIES_REPLY] =
        g_signal_new ("RANDR-list-output-properties-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_list_output_properties_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_QUERY_OUTPUT_PROPERTY] =
        g_signal_new ("RANDR-query-output-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_query_output_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_QUERY_OUTPUT_PROPERTY_REPLY] =
        g_signal_new ("RANDR-query-output-property-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_query_output_property_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_CONFIGURE_OUTPUT_PROPERTY] =
        g_signal_new ("RANDR-configure-output-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_configure_output_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_CHANGE_OUTPUT_PROPERTY] =
        g_signal_new ("RANDR-change-output-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_change_output_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_DELETE_OUTPUT_PROPERTY] =
        g_signal_new ("RANDR-delete-output-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_delete_output_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_OUTPUT_PROPERTY] =
        g_signal_new ("RANDR-get-output-property",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_output_property),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_OUTPUT_PROPERTY_REPLY] =
        g_signal_new ("RANDR-get-output-property-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_output_property_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_CREATE_MODE] =
        g_signal_new ("RANDR-create-mode",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_create_mode),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_CREATE_MODE_REPLY] =
        g_signal_new ("RANDR-create-mode-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_create_mode_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_DESTROY_MODE] =
        g_signal_new ("RANDR-destroy-mode",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_destroy_mode),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_ADD_OUTPUT_MODE] =
        g_signal_new ("RANDR-add-output-mode",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_add_output_mode),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_DELETE_OUTPUT_MODE] =
        g_signal_new ("RANDR-delete-output-mode",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_delete_output_mode),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_INFO] =
        g_signal_new ("RANDR-get-crtc-info",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_info),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_INFO_REPLY] =
        g_signal_new ("RANDR-get-crtc-info-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_info_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_CRTC_CONFIG] =
        g_signal_new ("RANDR-set-crtc-config",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_crtc_config),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_CRTC_CONFIG_REPLY] =
        g_signal_new ("RANDR-set-crtc-config-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_crtc_config_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_GAMMA_SIZE] =
        g_signal_new ("RANDR-get-crtc-gamma-size",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_gamma_size),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_GAMMA_SIZE_REPLY] =
        g_signal_new ("RANDR-get-crtc-gamma-size-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_gamma_size_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_GAMMA] =
        g_signal_new ("RANDR-get-crtc-gamma",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_gamma),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_GAMMA_REPLY] =
        g_signal_new ("RANDR-get-crtc-gamma-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_gamma_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_CRTC_GAMMA] =
        g_signal_new ("RANDR-set-crtc-gamma",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_crtc_gamma),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_RESOURCES_CURRENT] =
        g_signal_new ("RANDR-get-screen-resources-current",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_resources_current),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_SCREEN_RESOURCES_CURRENT_REPLY] =
        g_signal_new ("RANDR-get-screen-resources-current-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_screen_resources_current_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_CRTC_TRANSFORM] =
        g_signal_new ("RANDR-set-crtc-transform",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_crtc_transform),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_TRANSFORM] =
        g_signal_new ("RANDR-get-crtc-transform",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_transform),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_CRTC_TRANSFORM_REPLY] =
        g_signal_new ("RANDR-get-crtc-transform-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_crtc_transform_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_PANNING] =
        g_signal_new ("RANDR-get-panning",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_panning),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_PANNING_REPLY] =
        g_signal_new ("RANDR-get-panning-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_panning_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_PANNING] =
        g_signal_new ("RANDR-set-panning",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_panning),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_PANNING_REPLY] =
        g_signal_new ("RANDR-set-panning-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_panning_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_SET_OUTPUT_PRIMARY] =
        g_signal_new ("RANDR-set-output-primary",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_set_output_primary),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_OUTPUT_PRIMARY] =
        g_signal_new ("RANDR-get-output-primary",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_output_primary),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RANDR_GET_OUTPUT_PRIMARY_REPLY] =
        g_signal_new ("RANDR-get-output-primary-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RANDR_get_output_primary_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_QUERY_VERSION] =
        g_signal_new ("XINERAMA-query-version",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_query_version),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_QUERY_VERSION_REPLY] =
        g_signal_new ("XINERAMA-query-version-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_query_version_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_GET_STATE] =
        g_signal_new ("XINERAMA-get-state",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_get_state),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_GET_STATE_REPLY] =
        g_signal_new ("XINERAMA-get-state-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_get_state_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_GET_SCREEN_COUNT] =
        g_signal_new ("XINERAMA-get-screen-count",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_get_screen_count),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_GET_SCREEN_COUNT_REPLY] =
        g_signal_new ("XINERAMA-get-screen-count-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_get_screen_count_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_GET_SCREEN_SIZE] =
        g_signal_new ("XINERAMA-get-screen-size",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_get_screen_size),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_GET_SCREEN_SIZE_REPLY] =
        g_signal_new ("XINERAMA-get-screen-size-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_get_screen_size_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_IS_ACTIVE] =
        g_signal_new ("XINERAMA-is-active",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_is_active),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_IS_ACTIVE_REPLY] =
        g_signal_new ("XINERAMA-is-active-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_is_active_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_QUERY_SCREENS] =
        g_signal_new ("XINERAMA-query-screens",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_query_screens),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XINERAMA_QUERY_SCREENS_REPLY] =
        g_signal_new ("XINERAMA-query-screens-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XINERAMA_query_screens_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_NEW_KEYBOARD_NOTIFY] =
        g_signal_new ("XKB-new-keyboard-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_new_keyboard_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_MAP_NOTIFY] =
        g_signal_new ("XKB-map-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_map_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_STATE_NOTIFY] =
        g_signal_new ("XKB-state-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_state_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_CONTROLS_NOTIFY] =
        g_signal_new ("XKB-controls-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_controls_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_INDICATOR_STATE_NOTIFY] =
        g_signal_new ("XKB-indicator-state-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_indicator_state_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_INDICATOR_MAP_NOTIFY] =
        g_signal_new ("XKB-indicator-map-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_indicator_map_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_NAMES_NOTIFY] =
        g_signal_new ("XKB-names-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_names_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_COMPAT_MAP_NOTIFY] =
        g_signal_new ("XKB-compat-map-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_compat_map_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_BELL_NOTIFY] =
        g_signal_new ("XKB-bell-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_bell_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_ACTION_MESSAGE] =
        g_signal_new ("XKB-action-message",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_action_message),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_ACCESS_XNOTIFY] =
        g_signal_new ("XKB-access-xnotify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_access_xnotify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_EXTENSION_DEVICE_NOTIFY] =
        g_signal_new ("XKB-extension-device-notify",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_extension_device_notify),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_USE_EXTENSION] =
        g_signal_new ("XKB-use-extension",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_use_extension),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_USE_EXTENSION_REPLY] =
        g_signal_new ("XKB-use-extension-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_use_extension_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SELECT_EVENTS] =
        g_signal_new ("XKB-select-events",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_select_events),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_BELL] =
        g_signal_new ("XKB-bell",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_bell),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_STATE] =
        g_signal_new ("XKB-get-state",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_state),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_STATE_REPLY] =
        g_signal_new ("XKB-get-state-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_state_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_LATCH_LOCK_STATE] =
        g_signal_new ("XKB-latch-lock-state",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_latch_lock_state),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_CONTROLS] =
        g_signal_new ("XKB-get-controls",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_controls),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_CONTROLS_REPLY] =
        g_signal_new ("XKB-get-controls-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_controls_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_CONTROLS] =
        g_signal_new ("XKB-set-controls",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_controls),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_MAP] =
        g_signal_new ("XKB-get-map",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_map),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_MAP_REPLY] =
        g_signal_new ("XKB-get-map-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_map_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_MAP] =
        g_signal_new ("XKB-set-map",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_map),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_COMPAT_MAP] =
        g_signal_new ("XKB-get-compat-map",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_compat_map),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_COMPAT_MAP_REPLY] =
        g_signal_new ("XKB-get-compat-map-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_compat_map_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_COMPAT_MAP] =
        g_signal_new ("XKB-set-compat-map",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_compat_map),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_INDICATOR_STATE] =
        g_signal_new ("XKB-get-indicator-state",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_indicator_state),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_INDICATOR_STATE_REPLY] =
        g_signal_new ("XKB-get-indicator-state-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_indicator_state_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_INDICATOR_MAP] =
        g_signal_new ("XKB-get-indicator-map",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_indicator_map),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_INDICATOR_MAP_REPLY] =
        g_signal_new ("XKB-get-indicator-map-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_indicator_map_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_INDICATOR_MAP] =
        g_signal_new ("XKB-set-indicator-map",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_indicator_map),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_NAMED_INDICATOR] =
        g_signal_new ("XKB-get-named-indicator",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_named_indicator),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_NAMED_INDICATOR_REPLY] =
        g_signal_new ("XKB-get-named-indicator-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_named_indicator_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_NAMED_INDICATOR] =
        g_signal_new ("XKB-set-named-indicator",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_named_indicator),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_NAMES] =
        g_signal_new ("XKB-get-names",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_names),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_NAMES_REPLY] =
        g_signal_new ("XKB-get-names-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_names_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_NAMES] =
        g_signal_new ("XKB-set-names",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_names),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_GEOMETRY] =
        g_signal_new ("XKB-get-geometry",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_geometry),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_GEOMETRY_REPLY] =
        g_signal_new ("XKB-get-geometry-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_geometry_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_GEOMETRY] =
        g_signal_new ("XKB-set-geometry",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_geometry),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_PER_CLIENT_FLAGS] =
        g_signal_new ("XKB-per-client-flags",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_per_client_flags),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_PER_CLIENT_FLAGS_REPLY] =
        g_signal_new ("XKB-per-client-flags-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_per_client_flags_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_LIST_COMPONENTS] =
        g_signal_new ("XKB-list-components",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_list_components),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_LIST_COMPONENTS_REPLY] =
        g_signal_new ("XKB-list-components-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_list_components_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_KBD_BY_NAME] =
        g_signal_new ("XKB-get-kbd-by-name",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_kbd_by_name),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_KBD_BY_NAME_REPLY] =
        g_signal_new ("XKB-get-kbd-by-name-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_kbd_by_name_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_DEVICE_INFO] =
        g_signal_new ("XKB-get-device-info",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_device_info),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_GET_DEVICE_INFO_REPLY] =
        g_signal_new ("XKB-get-device-info-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_get_device_info_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_DEVICE_INFO] =
        g_signal_new ("XKB-set-device-info",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_device_info),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_DEBUGGING_FLAGS] =
        g_signal_new ("XKB-set-debugging-flags",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_debugging_flags),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[XKB_SET_DEBUGGING_FLAGS_REPLY] =
        g_signal_new ("XKB-set-debugging-flags-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, XKB_set_debugging_flags_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_VERSION] =
        g_signal_new ("RENDER-query-version",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_version),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_VERSION_REPLY] =
        g_signal_new ("RENDER-query-version-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_version_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_PICT_FORMATS] =
        g_signal_new ("RENDER-query-pict-formats",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_pict_formats),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_PICT_FORMATS_REPLY] =
        g_signal_new ("RENDER-query-pict-formats-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_pict_formats_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_PICT_INDEX_VALUES] =
        g_signal_new ("RENDER-query-pict-index-values",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_pict_index_values),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_PICT_INDEX_VALUES_REPLY] =
        g_signal_new ("RENDER-query-pict-index-values-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_pict_index_values_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_PICTURE] =
        g_signal_new ("RENDER-create-picture",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_picture),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CHANGE_PICTURE] =
        g_signal_new ("RENDER-change-picture",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_change_picture),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_SET_PICTURE_CLIP_RECTANGLES] =
        g_signal_new ("RENDER-set-picture-clip-rectangles",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_set_picture_clip_rectangles),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_FREE_PICTURE] =
        g_signal_new ("RENDER-free-picture",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_free_picture),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_COMPOSITE] =
        g_signal_new ("RENDER-composite",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_composite),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_TRAPEZOIDS] =
        g_signal_new ("RENDER-trapezoids",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_trapezoids),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_TRIANGLES] =
        g_signal_new ("RENDER-triangles",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_triangles),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_TRI_STRIP] =
        g_signal_new ("RENDER-tri-strip",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_tri_strip),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_TRI_FAN] =
        g_signal_new ("RENDER-tri-fan",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_tri_fan),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_GLYPH_SET] =
        g_signal_new ("RENDER-create-glyph-set",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_glyph_set),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_REFERENCE_GLYPH_SET] =
        g_signal_new ("RENDER-reference-glyph-set",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_reference_glyph_set),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_FREE_GLYPH_SET] =
        g_signal_new ("RENDER-free-glyph-set",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_free_glyph_set),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_ADD_GLYPHS] =
        g_signal_new ("RENDER-add-glyphs",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_add_glyphs),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_FREE_GLYPHS] =
        g_signal_new ("RENDER-free-glyphs",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_free_glyphs),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_COMPOSITE_GLYPHS8] =
        g_signal_new ("RENDER-composite-glyphs8",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_composite_glyphs8),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_COMPOSITE_GLYPHS16] =
        g_signal_new ("RENDER-composite-glyphs16",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_composite_glyphs16),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_COMPOSITE_GLYPHS32] =
        g_signal_new ("RENDER-composite-glyphs32",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_composite_glyphs32),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_FILL_RECTANGLES] =
        g_signal_new ("RENDER-fill-rectangles",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_fill_rectangles),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_CURSOR] =
        g_signal_new ("RENDER-create-cursor",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_cursor),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_SET_PICTURE_TRANSFORM] =
        g_signal_new ("RENDER-set-picture-transform",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_set_picture_transform),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_FILTERS] =
        g_signal_new ("RENDER-query-filters",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_filters),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_QUERY_FILTERS_REPLY] =
        g_signal_new ("RENDER-query-filters-reply",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_query_filters_reply),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_SET_PICTURE_FILTER] =
        g_signal_new ("RENDER-set-picture-filter",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_set_picture_filter),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_ANIM_CURSOR] =
        g_signal_new ("RENDER-create-anim-cursor",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_anim_cursor),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_ADD_TRAPS] =
        g_signal_new ("RENDER-add-traps",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_add_traps),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_SOLID_FILL] =
        g_signal_new ("RENDER-create-solid-fill",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_solid_fill),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_LINEAR_GRADIENT] =
        g_signal_new ("RENDER-create-linear-gradient",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_linear_gradient),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_RADIAL_GRADIENT] =
        g_signal_new ("RENDER-create-radial-gradient",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_radial_gradient),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
    signals[RENDER_CREATE_CONICAL_GRADIENT] =
        g_signal_new ("RENDER-create-conical-gradient",
                      G_TYPE_FROM_CLASS (klass),
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET (XigCodecClass, RENDER_create_conical_gradient),
                      NULL, NULL,
                      g_cclosure_marshal_VOID__POINTER,
                      G_TYPE_NONE, 1, G_TYPE_POINTER);
}
